@@ -1,6 +1,54 @@
 ha:cschem-sheet-v1 {
 	ha:obj_indirect.1 {
 		li:objects {
+			ha:group.1 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABC;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABD; loclib_name=lm358_so8;
+						li:objects {
+						}
+						ha:attrib {
+							footprint=so(8)
+							li:portmap {
+								{1/in- -> pcb/pinnum=2}
+								{1/in+ -> pcb/pinnum=3}
+								{1/out -> pcb/pinnum=1}
+								{1/V+ -> pcb/pinnum=8}
+								{1/V- -> pcb/pinnum=4}
+								{2/in- -> pcb/pinnum=6}
+								{2/in+ -> pcb/pinnum=5}
+								{2/out -> pcb/pinnum=7}
+								{2/V+ -> pcb/pinnum=8}
+								{2/V- -> pcb/pinnum=4}
+							}
+						}
+					}
+					ha:group.2 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABE; loclib_name=lm358_so8;
+						li:objects {
+						}
+						ha:attrib {
+							footprint=so(8)
+							li:portmap {
+								{1/in- -> pcb/pinnum=2}
+								{1/in+ -> pcb/pinnum=3}
+								{1/out -> pcb/pinnum=1}
+								{1/V+ -> pcb/pinnum=8}
+								{1/V- -> pcb/pinnum=4}
+								{2/in- -> pcb/pinnum=6}
+								{2/in+ -> pcb/pinnum=5}
+								{2/out -> pcb/pinnum=7}
+								{2/V+ -> pcb/pinnum=8}
+								{2/V- -> pcb/pinnum=4}
+							}
+						}
+					}
+				}
+				ha:attrib {
+					ha:purpose = { value=devmap; prio=0; }
+				}
+			}
 		}
 	}
 	ha:obj_direct.2 {
@@ -54,172 +102,6 @@ ha:cschem-sheet-v1 {
 					purpose=titlebox
 				}
 			}
-			ha:group.2 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAEn;
-				x=88000; y=84000;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEo;
-						x=-20000; y=4000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=in+
-							role=terminal
-						}
-					}
-					ha:group.2 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEp;
-						x=-20000; y=-4000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=in-
-							role=terminal
-						}
-					}
-					ha:group.3 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEq;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=out
-							role=terminal
-						}
-					}
-					ha:line.4 { x1=-20000; y1=-8000; x2=-20000; y2=8000; stroke=sym-decor; }
-					ha:line.5 { x1=-20000; y1=8000; x2=-4000; y2=0; stroke=sym-decor; }
-					ha:line.6 { x1=-4000; y1=0; x2=-20000; y2=-8000; stroke=sym-decor; }
-					ha:line.7 { x1=-18000; y1=5000; x2=-18000; y2=3000; stroke=sym-decor; }
-					ha:line.8 { x1=-19000; y1=4000; x2=-17000; y2=4000; stroke=sym-decor; }
-					ha:line.9 { x1=-19000; y1=-4000; x2=-17000; y2=-4000; stroke=sym-decor; }
-					ha:group.10 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEr;
-						x=-12000; y=-8000; rot=270.000000; mirx=1;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=0; y1=-1000; rot=180.000000; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=V-
-							role=terminal
-						}
-					}
-					ha:group.11 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEs;
-						x=-12000; y=8000; rot=90.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=-4000; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=V+
-							role=terminal
-						}
-					}
-					ha:text.12 { x1=-21000; y1=9000; dyntext=1; stroke=sym-primary; text=%../A.name%; floater=1; }
-					ha:text.13 { x1=-21000; y1=13000; dyntext=1; stroke=sym-secondary; text=%../A.-slot%; floater=1; }
-				}
-				ha:attrib {
-					devmap=lm358_so8
-					name=U1
-					role=symbol
-					-slot=1
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
-			ha:group.3 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAEt;
-				x=168000; y=84000;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEu;
-						x=-20000; y=4000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=in+
-							role=terminal
-						}
-					}
-					ha:group.2 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEv;
-						x=-20000; y=-4000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=in-
-							role=terminal
-						}
-					}
-					ha:group.3 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEw;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=out
-							role=terminal
-						}
-					}
-					ha:line.4 { x1=-20000; y1=-8000; x2=-20000; y2=8000; stroke=sym-decor; }
-					ha:line.5 { x1=-20000; y1=8000; x2=-4000; y2=0; stroke=sym-decor; }
-					ha:line.6 { x1=-4000; y1=0; x2=-20000; y2=-8000; stroke=sym-decor; }
-					ha:line.7 { x1=-18000; y1=5000; x2=-18000; y2=3000; stroke=sym-decor; }
-					ha:line.8 { x1=-19000; y1=4000; x2=-17000; y2=4000; stroke=sym-decor; }
-					ha:line.9 { x1=-19000; y1=-4000; x2=-17000; y2=-4000; stroke=sym-decor; }
-					ha:group.10 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEx;
-						x=-12000; y=-8000; rot=270.000000; mirx=1;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=0; y1=-1000; rot=180.000000; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=V-
-							role=terminal
-						}
-					}
-					ha:group.11 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAEy;
-						x=-12000; y=8000; rot=90.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-							ha:text.2 { x1=-4000; y1=-4000; dyntext=1; stroke=term-primary; text=%../a.display/name%; floater=1; }
-						}
-						ha:attrib {
-							name=V+
-							role=terminal
-						}
-					}
-					ha:text.12 { x1=-21000; y1=9000; dyntext=1; stroke=sym-primary; text=%../A.name%; floater=1; }
-					ha:text.13 { x1=-21000; y1=13000; dyntext=1; stroke=sym-secondary; text=%../A.-slot%; floater=1; }
-				}
-				ha:attrib {
-					devmap=lm358_so8
-					name=U1
-					role=symbol
-					-slot=2
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
 			ha:group.4 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAEz;
 				li:objects {
@@ -230,52 +112,13 @@ ha:cschem-sheet-v1 {
 					ha:line.9 { x1=88000; y1=84000; x2=100000; y2=84000; stroke=wire; }
 					ha:line.10 { x1=96000; y1=84000; x2=96000; y2=84000; stroke=junction; }
 					ha:line.11 { x1=24000; y1=80000; x2=64000; y2=80000; stroke=wire; }
+					ha:text.12 { x1=38000; y1=80000; dyntext=1; stroke=wire; text=%../A.name%; floater=1; }
 				}
 				ha:attrib {
+					name=in
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.5 {
-				li:conn {
-					/2/2/3/1
-					/2/4/9
-				}
-			}
-			ha:connection.6 {
-				li:conn {
-					/2/2/2/1
-					/2/4/11
-				}
-			}
-			ha:group.9 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAE0;
-				x=76000; y=100000;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAE1;
-						rot=270.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-						}
-						ha:attrib {
-							ha:name = { value=1; prio=220; }
-							role=terminal
-						}
-					}
-					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
-					ha:text.3 { x1=-4000; y1=4000; dyntext=0; stroke=sym-primary; text=Vcc; }
-				}
-				ha:attrib {
-					li:connect {
-						{1:Vcc}
-					}
-					role=symbol
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
 			ha:group.10 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAE2;
 				li:objects {
@@ -285,18 +128,6 @@ ha:cschem-sheet-v1 {
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.11 {
-				li:conn {
-					/2/10/1
-					/2/2/11/1
-				}
-			}
-			ha:connection.12 {
-				li:conn {
-					/2/10/1
-					/2/9/1/1
-				}
-			}
 			ha:group.13 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAE3;
 				x=76000; y=68000;
@@ -336,12 +167,6 @@ ha:cschem-sheet-v1 {
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.15 {
-				li:conn {
-					/2/14/1
-					/2/2/10/1
-				}
-			}
 			ha:connection.16 {
 				li:conn {
 					/2/14/1
@@ -387,12 +212,6 @@ ha:cschem-sheet-v1 {
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.19 {
-				li:conn {
-					/2/18/1
-					/2/2/1/1
-				}
-			}
 			ha:connection.20 {
 				li:conn {
 					/2/18/1
@@ -645,47 +464,12 @@ ha:cschem-sheet-v1 {
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.39 {
-				li:conn {
-					/2/38/1
-					/2/3/1/1
-				}
-			}
 			ha:connection.40 {
 				li:conn {
 					/2/38/1
 					/2/36/1/1
 				}
 			}
-			ha:group.59 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFM;
-				x=128000; y=124000;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAFN;
-						rot=270.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-						}
-						ha:attrib {
-							ha:name = { value=1; prio=220; }
-							role=terminal
-						}
-					}
-					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
-					ha:text.3 { x1=-4000; y1=4000; dyntext=0; stroke=sym-primary; text=Vcc; }
-				}
-				ha:attrib {
-					li:connect {
-						{1:Vcc}
-					}
-					role=symbol
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
 			ha:group.60 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFO;
 				li:objects {
@@ -701,12 +485,6 @@ ha:cschem-sheet-v1 {
 					/2/23/2/1
 				}
 			}
-			ha:connection.62 {
-				li:conn {
-					/2/60/1
-					/2/59/1/1
-				}
-			}
 			ha:group.63 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFP;
 				x=196000; y=80000;
@@ -802,17 +580,14 @@ ha:cschem-sheet-v1 {
 					ha:line.11 { x1=128000; y1=76000; x2=128000; y2=96000; stroke=wire; }
 					ha:line.12 { x1=176000; y1=84000; x2=168000; y2=84000; stroke=wire; }
 					ha:line.13 { x1=120000; y1=84000; x2=128000; y2=84000; stroke=wire; }
+					ha:text.14 { x1=178000; y1=84000; dyntext=1; stroke=wire; text=%../A.name%; floater=1; }
+					ha:text.15 { x1=124000; y1=84000; dyntext=1; stroke=wire; text=%../A.name%; floater=1; }
 				}
 				ha:attrib {
+					name=mid
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.68 {
-				li:conn {
-					/2/67/7
-					/2/3/2/1
-				}
-			}
 			ha:connection.69 {
 				li:conn {
 					/2/67/8
@@ -831,12 +606,6 @@ ha:cschem-sheet-v1 {
 					/2/27/2/1
 				}
 			}
-			ha:connection.72 {
-				li:conn {
-					/2/67/12
-					/2/3/3/1
-				}
-			}
 			ha:connection.73 {
 				li:conn {
 					/2/67/13
@@ -878,35 +647,6 @@ ha:cschem-sheet-v1 {
 					sym-source=sch-rnd default symbol lib
 				}
 			}
-			ha:group.76 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFZ;
-				x=188000; y=92000;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAFa;
-						rot=270.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-						}
-						ha:attrib {
-							ha:name = { value=1; prio=220; }
-							role=terminal
-						}
-					}
-					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
-					ha:text.3 { x1=-4000; y1=4000; dyntext=0; stroke=sym-primary; text=Vcc; }
-				}
-				ha:attrib {
-					li:connect {
-						{1:Vcc}
-					}
-					role=symbol
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
 			ha:group.77 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFb;
 				li:objects {
@@ -945,41 +685,6 @@ ha:cschem-sheet-v1 {
 					/2/63/4/1
 				}
 			}
-			ha:connection.82 {
-				li:conn {
-					/2/80/2
-					/2/76/1/1
-				}
-			}
-			ha:group.90 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFd;
-				x=28000; y=88000; mirx=1;
-				li:objects {
-					ha:group.1 {
-						uuid=iNOQfJpO6hT/HFDFGjoAAAFe;
-						rot=270.000000;
-						li:objects {
-							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
-						}
-						ha:attrib {
-							ha:name = { value=1; prio=220; }
-							role=terminal
-						}
-					}
-					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
-					ha:text.3 { x1=-4000; y1=4000; dyntext=0; stroke=sym-primary; text=Vcc; }
-				}
-				ha:attrib {
-					li:connect {
-						{1:Vcc}
-					}
-					role=symbol
-					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
-					sym-license-dist=GPLv2+
-					sym-license-use=Public Domain
-					sym-source=sch-rnd default symbol lib
-				}
-			}
 			ha:line.93 { x1=24000; y1=84000; x2=28000; y2=84000; stroke=wire; }
 			ha:group.95 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFf;
@@ -1097,12 +802,6 @@ ha:cschem-sheet-v1 {
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
-			ha:connection.102 {
-				li:conn {
-					/2/101/1
-					/2/90/1/1
-				}
-			}
 			ha:group.103 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFm;
 				li:objects {
@@ -1125,6 +824,390 @@ ha:cschem-sheet-v1 {
 					/2/98/1/1
 				}
 			}
+			ha:group.106 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABR; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAH;
+				x=88000; y=84000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABS; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAI;
+						x=-20000; y=4000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=in+
+							role=terminal
+							ha:spice/pinnum = { value=2; prio=31050; }
+						}
+					}
+					ha:group.2 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABT; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAJ;
+						x=-20000; y=-4000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=in-
+							role=terminal
+							ha:spice/pinnum = { value=1; prio=31050; }
+						}
+					}
+					ha:group.3 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABU; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAK;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=out
+							role=terminal
+							ha:spice/pinnum = { value=3; prio=31050; }
+						}
+					}
+					ha:line.4 { x1=-20000; y1=-8000; x2=-20000; y2=8000; stroke=sym-decor; }
+					ha:line.5 { x1=-20000; y1=8000; x2=-4000; y2=0; stroke=sym-decor; }
+					ha:line.6 { x1=-4000; y1=0; x2=-20000; y2=-8000; stroke=sym-decor; }
+					ha:line.7 { x1=-18000; y1=5000; x2=-18000; y2=3000; stroke=sym-decor; }
+					ha:line.8 { x1=-19000; y1=4000; x2=-17000; y2=4000; stroke=sym-decor; }
+					ha:line.9 { x1=-19000; y1=-4000; x2=-17000; y2=-4000; stroke=sym-decor; }
+					ha:group.10 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABV; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAL;
+						x=-12000; y=-4000; rot=270.000000; mirx=1; miry=1;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=0; y1=-1000; rot=180.000000; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=V-
+							role=terminal
+							ha:spice/pinnum = { value=5; prio=31050; }
+						}
+					}
+					ha:group.11 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABW; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAM;
+						x=-12000; y=8000; rot=90.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=-4000; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=V+
+							role=terminal
+							ha:spice/pinnum = { value=4; prio=31050; }
+						}
+					}
+					ha:text.12 { x1=-21000; y1=9000; dyntext=1; stroke=sym-primary; text=%../A.name%; floater=1; }
+					ha:text.13 { x1=-21000; y1=12000; dyntext=1; stroke=sym-secondary; text=%../A.-slot%; floater=1; }
+				}
+				ha:attrib {
+					-slot=1
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					devmap=lm358_so8
+					name=U1
+					role=symbol
+					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					sym-license-dist=GPLv2+
+					sym-license-use=Public Domain
+					sym-source=sch-rnd default symbol lib
+				}
+			}
+			ha:connection.107 {
+				li:conn {
+					/2/106/1/1
+					/2/18/1
+				}
+			}
+			ha:connection.108 {
+				li:conn {
+					/2/106/2/1
+					/2/4/11
+				}
+			}
+			ha:connection.109 {
+				li:conn {
+					/2/106/3/1
+					/2/4/9
+				}
+			}
+			ha:connection.110 {
+				li:conn {
+					/2/106/10/1
+					/2/14/1
+				}
+			}
+			ha:connection.111 {
+				li:conn {
+					/2/106/11/1
+					/2/10/1
+				}
+			}
+			ha:group.112 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABX; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAH;
+				x=168000; y=84000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABY; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAI;
+						x=-20000; y=4000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=in+
+							role=terminal
+							ha:spice/pinnum = { value=2; prio=31050; }
+						}
+					}
+					ha:group.2 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABZ; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAJ;
+						x=-20000; y=-4000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=in-
+							role=terminal
+							ha:spice/pinnum = { value=1; prio=31050; }
+						}
+					}
+					ha:group.3 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABa; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAK;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=0; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=out
+							role=terminal
+							ha:spice/pinnum = { value=3; prio=31050; }
+						}
+					}
+					ha:line.4 { x1=-20000; y1=-8000; x2=-20000; y2=8000; stroke=sym-decor; }
+					ha:line.5 { x1=-20000; y1=8000; x2=-4000; y2=0; stroke=sym-decor; }
+					ha:line.6 { x1=-4000; y1=0; x2=-20000; y2=-8000; stroke=sym-decor; }
+					ha:line.7 { x1=-18000; y1=5000; x2=-18000; y2=3000; stroke=sym-decor; }
+					ha:line.8 { x1=-19000; y1=4000; x2=-17000; y2=4000; stroke=sym-decor; }
+					ha:line.9 { x1=-19000; y1=-4000; x2=-17000; y2=-4000; stroke=sym-decor; }
+					ha:group.10 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABb; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAL;
+						x=-12000; y=-4000; rot=270.000000; mirx=1; miry=1;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=0; y1=-1000; rot=180.000000; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=V-
+							role=terminal
+							ha:spice/pinnum = { value=5; prio=31050; }
+						}
+					}
+					ha:group.11 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABc; src_uuid=iNOQfJpO6hT/HFDFGjoAAAAM;
+						x=-12000; y=8000; rot=90.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+							ha:text.2 { x1=-4000; y1=-4000; dyntext=1; stroke=term-primary; text=%../a.display/name%; }
+						}
+						ha:attrib {
+							name=V+
+							role=terminal
+							ha:spice/pinnum = { value=4; prio=31050; }
+						}
+					}
+					ha:text.12 { x1=-21000; y1=9000; dyntext=1; stroke=sym-primary; text=%../A.name%; floater=1; }
+					ha:text.13 { x1=-21000; y1=12000; dyntext=1; stroke=sym-secondary; text=%../A.-slot%; floater=1; }
+				}
+				ha:attrib {
+					-slot=2
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					devmap=lm358_so8
+					name=U1
+					role=symbol
+					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					sym-license-dist=GPLv2+
+					sym-license-use=Public Domain
+					sym-source=sch-rnd default symbol lib
+				}
+			}
+			ha:connection.113 {
+				li:conn {
+					/2/112/1/1
+					/2/38/1
+				}
+			}
+			ha:connection.114 {
+				li:conn {
+					/2/112/2/1
+					/2/67/7
+				}
+			}
+			ha:connection.115 {
+				li:conn {
+					/2/112/3/1
+					/2/67/12
+				}
+			}
+			ha:group.116 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABh; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB6;
+				x=28000; y=88000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABi; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB7;
+						rot=270.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+						}
+						ha:attrib {
+							ha:name = { value=1; prio=220; }
+							role=terminal
+						}
+					}
+					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
+					ha:text.3 { x1=-4000; y1=4000; x2=4000; y2=7000; halign=center; dyntext=0; stroke=sym-primary; text=Vcc; }
+				}
+				ha:attrib {
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					li:connect {
+						{1:Vcc}
+					}
+					role=symbol
+				}
+			}
+			ha:connection.117 {
+				li:conn {
+					/2/116/1/1
+					/2/101/1
+				}
+			}
+			ha:group.118 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABj; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB6;
+				x=76000; y=100000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABk; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB7;
+						rot=270.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+						}
+						ha:attrib {
+							ha:name = { value=1; prio=220; }
+							role=terminal
+						}
+					}
+					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
+					ha:text.3 { x1=-4000; y1=4000; x2=4000; y2=7000; halign=center; dyntext=0; stroke=sym-primary; text=Vcc; }
+				}
+				ha:attrib {
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					li:connect {
+						{1:Vcc}
+					}
+					role=symbol
+					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					sym-license-dist=GPLv2+
+					sym-license-use=Public Domain
+					sym-source=sch-rnd default symbol lib
+				}
+			}
+			ha:connection.119 {
+				li:conn {
+					/2/118/1/1
+					/2/10/1
+				}
+			}
+			ha:group.120 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABl; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB6;
+				x=128000; y=124000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABm; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB7;
+						rot=270.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+						}
+						ha:attrib {
+							ha:name = { value=1; prio=220; }
+							role=terminal
+						}
+					}
+					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
+					ha:text.3 { x1=-4000; y1=4000; x2=4000; y2=7000; halign=center; dyntext=0; stroke=sym-primary; text=Vcc; }
+				}
+				ha:attrib {
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					li:connect {
+						{1:Vcc}
+					}
+					role=symbol
+					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					sym-license-dist=GPLv2+
+					sym-license-use=Public Domain
+					sym-source=sch-rnd default symbol lib
+				}
+			}
+			ha:connection.121 {
+				li:conn {
+					/2/120/1/1
+					/2/60/1
+				}
+			}
+			ha:group.122 {
+				uuid=bOwQFqA7m2jl+cvU6t4AAABn; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB6;
+				x=188000; y=92000;
+				li:objects {
+					ha:group.1 {
+						uuid=bOwQFqA7m2jl+cvU6t4AAABo; src_uuid=iNOQfJpO6hT/HFDFGjoAAAB7;
+						rot=270.000000;
+						li:objects {
+							ha:line.1 { x1=0; y1=0; x2=-4000; y2=0; stroke=term-decor; }
+						}
+						ha:attrib {
+							ha:name = { value=1; prio=220; }
+							role=terminal
+						}
+					}
+					ha:line.2 { x1=2500; y1=4000; x2=-2500; y2=4000; stroke=sym-decor; }
+					ha:text.3 { x1=-4000; y1=4000; x2=4000; y2=7000; halign=center; dyntext=0; stroke=sym-primary; text=Vcc; }
+				}
+				ha:attrib {
+					-sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					-sym-license-dist=GPLv2+
+					-sym-license-use=Public Domain
+					-sym-source=sch-rnd default symbol lib
+					li:connect {
+						{1:Vcc}
+					}
+					role=symbol
+					sym-copyright=(C) 2022 Tibor 'Igor2' Palinkas
+					sym-license-dist=GPLv2+
+					sym-license-use=Public Domain
+					sym-source=sch-rnd default symbol lib
+				}
+			}
+			ha:connection.123 {
+				li:conn {
+					/2/122/1/1
+					/2/80/2
+				}
+			}
 		}
 		ha:attrib {
 			drawing_min_height=200000
@@ -1132,7 +1215,15 @@ ha:cschem-sheet-v1 {
 			maintainer=Tibor 'Igor2' Palinkas
 			page=1 of 1
 			print_page=A/4
-			title={Slot + devmap example}
+			title=Slot + devmap example
 		}
 	}
+  li:sch-rnd-conf-v1 {
+   ha:overwrite {
+    ha:editor {
+     grids_idx = 1
+     grid = 2.0480 mm
+    }
+   }
+  }
 }
