@@ -291,6 +291,13 @@ int csch_attrib_prepend(csch_attribs_t *attribs, int prio, const char *key, cons
 	return res;
 }
 
+int csch_attrib_append_val(csch_attribs_t *attribs, int prio, const char *key, const csch_attrib_t *srca, csch_source_arg_t *source)
+{
+	if (srca->val != NULL)
+		return csch_attrib_append(attribs, prio, key, srca->val, source);
+
+	return csch_attrib_set_arr_nofree(attribs, prio, key, &srca->arr, source, NULL, 1);
+}
 
 int csch_attrib_set_arr_c(csch_attribs_t *attribs, int prio, const char *key, const char **val, csch_source_arg_t *source, csch_attrib_t **attr_out)
 {
@@ -445,7 +452,7 @@ void csch_attr_side_effects(csch_cgrp_t *grp, const char *key)
 	}
 }
 
-csch_inline void notify(csch_chdr_t *obj)
+RND_INLINE void notify(csch_chdr_t *obj)
 {
 	rnd_event(&obj->sheet->hidlib, CSCH_EVENT_OBJ_ATTR_EDITED, "p", obj);
 	csch_cobj_redraw(obj);
@@ -640,6 +647,61 @@ void csch_attr_modify_rename(csch_sheet_t *sheet, csch_cgrp_t *grp, csch_attrib_
 	}
 }
 
+typedef struct {
+	csch_chdr_t *obj;
+	csch_attrib_t *a;
+	short int prio;
+} undo_attr_modify_prio_t;
+
+
+static int undo_attr_modify_prio_swap(void *udata)
+{
+	undo_attr_modify_prio_t *u = udata;
+	short int tmp;
+
+	tmp = u->a->prio;
+	u->a->prio = u->prio;
+	u->prio = tmp;
+
+	csch_sheet_set_changed(u->obj->sheet, 1);
+	notify(u->obj);
+	return 0;
+}
+
+static void undo_attr_modify_prio_print(void *udata, char *dst, size_t dst_len)
+{
+	undo_attr_modify_prio_t *u = udata;
+
+	rnd_snprintf(dst, dst_len, "attr prio change, key=%s %d %d", u->a->key, u->a->prio, u->prio);
+}
+
+static const uundo_oper_t undo_attr_modify_prio = {
+	core_attr_cookie,
+	/*undo_attr_modify_free*/ NULL,
+	undo_attr_modify_prio_swap,
+	undo_attr_modify_prio_swap,
+	undo_attr_modify_prio_print
+};
+
+
+void csch_attr_modify_prio(csch_sheet_t *sheet, csch_cgrp_t *grp, csch_attrib_t *a, int prio, csch_source_arg_t *source, int undoable)
+{
+	undo_attr_modify_prio_t utmp, *u = &utmp;
+
+	if (undoable) u = uundo_append(&sheet->undo, &undo_attr_modify_prio, sizeof(undo_attr_modify_prio_t));
+
+	u->obj = &grp->hdr;
+	u->a = a;
+	u->prio = prio;
+	append_src(u->a, prio, source, 0);
+
+	undo_attr_modify_prio_swap(u);
+	if (undoable) csch_undo_inc_serial(sheet);
+
+	csch_attr_src_free(source);
+}
+
+
 
 static const char *NEWVAL_DEL = "NEWVAL_DEL";
 typedef struct {
@@ -653,7 +715,7 @@ typedef struct {
 } undo_attr_arr_modify_t;
 
 /* returns delta achieved */
-csch_inline long attr_arr_move(csch_attrib_t *a, long idx, long delta)
+RND_INLINE long attr_arr_move(csch_attrib_t *a, long idx, long delta)
 {
 	long n, end, res = 0;
 	char *save;
@@ -687,7 +749,7 @@ csch_inline long attr_arr_move(csch_attrib_t *a, long idx, long delta)
 	return res;
 }
 
-csch_inline void attr_arr_del(csch_attrib_t *a, long idx)
+RND_INLINE void attr_arr_del(csch_attrib_t *a, long idx)
 {
 	long n, end = a->arr.used-1;
 
@@ -700,7 +762,7 @@ csch_inline void attr_arr_del(csch_attrib_t *a, long idx)
 /* create a new, empty slot at [idx], oving all items starting from
    idx to +1. Effectively inserts an empty slot at idx, before the
    item that was at idx. */
-csch_inline void attr_arr_ins_before(csch_attrib_t *a, long idx)
+RND_INLINE void attr_arr_ins_before(csch_attrib_t *a, long idx)
 {
 	long n, end = a->arr.used;
 
