@@ -91,8 +91,8 @@ void csch_attrib_uninit(csch_attribs_t *attribs);
 
 /* Returns the string value (or arr value) of an attribute or NULL if
    the attribute doesn't exist or is not a string (or arr) */
-csch_inline const char *csch_attrib_get_str(const csch_attribs_t *attribs, const char *key);
-csch_inline const vts0_t *csch_attrib_get_arr(const csch_attribs_t *attribs, const char *key);
+RND_INLINE const char *csch_attrib_get_str(const csch_attribs_t *attribs, const char *key);
+RND_INLINE const vts0_t *csch_attrib_get_arr(const csch_attribs_t *attribs, const char *key);
 
 
 /* Set a scalar attribute; the ptr version takes malloc()'d val and source;
@@ -114,6 +114,10 @@ int csch_attrib_prependptr(csch_attribs_t *attribs, int prio, const char *key, c
 int csch_attrib_append(csch_attribs_t *attribs, int prio, const char *key, const char *val, csch_source_arg_t *source);
 int csch_attrib_appendptr(csch_attribs_t *attribs, int prio, const char *key, char *val, csch_source_arg_t *source);
 
+/* Append the value of srca; if it's an array, append all elements in order */
+int csch_attrib_append_val(csch_attribs_t *attribs, int prio, const char *key, const csch_attrib_t *srca, csch_source_arg_t *source);
+
+
 /* Del a key from an attribute hash; if history is not NULL, the key is kept
    and the value is emptied so source history is preserved.
    src is always free'd. */
@@ -147,6 +151,10 @@ int csch_attrib_eq_(const csch_attrib_t *a1, const csch_attrib_t *a2);
 void csch_attr_modify_str(csch_sheet_t *sheet, csch_cgrp_t *obj, int prio, const char *key, const char *val, csch_source_arg_t *source, int undoable);
 void csch_attr_modify_del(csch_sheet_t *sheet, csch_cgrp_t *obj, const char *key, int undoable);
 
+/* Undoable modification of attribute priority */
+void csch_attr_modify_prio(csch_sheet_t *sheet, csch_cgrp_t *obj, csch_attrib_t *a, int prio, csch_source_arg_t *source, int undoable);
+
+
 /* Rename an attribute (by creating a new one and removing the old one);
    new_name must not be the same as a->key */
 void csch_attr_modify_rename(csch_sheet_t *sheet, csch_cgrp_t *grp, csch_attrib_t *a, const char *new_name, csch_source_arg_t *src, int undoable);
@@ -174,14 +182,14 @@ void csch_attr_side_effects(csch_cgrp_t *grp, const char *key);
 void csch_attr_free(csch_attrib_t *a);
 
 /*** implementation ***/
-csch_inline const char *csch_attrib_get_str(const csch_attribs_t *attribs, const char *key)
+RND_INLINE const char *csch_attrib_get_str(const csch_attribs_t *attribs, const char *key)
 {
 	csch_attrib_t *a = csch_attrib_get(attribs, key);
 	if ((a == NULL) || (a->deleted)) return NULL;
 	return a->val;
 }
 
-csch_inline const vts0_t *csch_attrib_get_arr(const csch_attribs_t *attribs, const char *key)
+RND_INLINE const vts0_t *csch_attrib_get_arr(const csch_attribs_t *attribs, const char *key)
 {
 	csch_attrib_t *a = csch_attrib_get(attribs, key);
 	if ((a == NULL) || (a->deleted) || (a->val != NULL)) return NULL;
