@@ -121,6 +121,13 @@ void csch_arc_update_bbox(csch_sheet_t *sheet, csch_arc_t *arc)
 	arc->hdr.bbox.x2 = gb.p2.x; arc->hdr.bbox.y2 = gb.p2.y;
 }
 
+void csch_arc_center_bbox(csch_sheet_t *sheet, const csch_arc_t *arc, csch_rtree_box_t *dst)
+{
+	g2d_box_t gb = g2d_carc_bbox(&arc->inst.c);
+	dst->x1 = gb.p1.x; dst->y1 = gb.p1.y;
+	dst->x2 = gb.p2.x; dst->y2 = gb.p2.y;
+}
+
 void csch_arc_update(csch_sheet_t *sheet, csch_arc_t *arc, int do_xform)
 {
 
