@@ -108,7 +108,7 @@ void csch_conn_text2ptr(csch_sheet_t *sheet, csch_conn_t *conn)
 }
 
 /* append one or more connection points of o to tmp in x;y form */
-csch_inline void conn_append_pts(csch_conn_t *conn, csch_chdr_t *o, vtl0_t *tmp)
+RND_INLINE void conn_append_pts(csch_conn_t *conn, csch_chdr_t *o, vtl0_t *tmp)
 {
 	switch(o->type) {
 		case CSCH_CTYPE_LINE:
@@ -149,7 +149,7 @@ csch_inline void conn_append_pts(csch_conn_t *conn, csch_chdr_t *o, vtl0_t *tmp)
 
 /* append a single line of shortest connection between o1 and o2 notable points
    to tmp in x1;y1;x2;y2 line form */
-csch_inline void conn_recalc_add_line_npts(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
+RND_INLINE void conn_recalc_add_line_npts(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
 {
 	int o2_start, besti1 = -1, besti2 = -1, i1, i2;
 	double best = (double)CSCH_COORD_MAX * (double)CSCH_COORD_MAX;
@@ -192,7 +192,7 @@ csch_inline void conn_recalc_add_line_npts(csch_conn_t *conn, csch_chdr_t *o1, c
 
 /* Search for centerline intersections between o1 and o2, create zero-length
    conn lines in those points and return the number of points found. */
-csch_inline int conn_recalc_add_line_cent_isc(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
+RND_INLINE int conn_recalc_add_line_cent_isc(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
 {
 	csch_sheet_t *sheet = o1->sheet;
 	g2d_vect_t iscp[32];
@@ -221,7 +221,7 @@ csch_inline int conn_recalc_add_line_cent_isc(csch_conn_t *conn, csch_chdr_t *o1
 /* Append new connection line(s) between o1 and o2; prefer zero-length conns at
    center-line intersections, fall back to non-zero-length conns between
    notable points when there's no centerline intersection */
-csch_inline void conn_recalc_add_line(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
+RND_INLINE void conn_recalc_add_line(csch_conn_t *conn, csch_chdr_t *o1, csch_chdr_t *o2, vtl0_t *tmp)
 {
 	if (o1->parent == o2->parent)
 		return; /* corner case: never indicate connection within the same group */
@@ -262,6 +262,7 @@ void csch_conn_update(csch_sheet_t *sheet, csch_conn_t *conn, int do_xform)
 	csch_cobj_rtree_add(sheet, &conn->hdr);
 
 	csch_cobj_bbox_changed(sheet, &conn->hdr);
+	conn->dirty = 0;
 }
 
 static long find_obj_in_conn(const csch_chdr_t *obj, const csch_conn_t *conn)
@@ -282,7 +283,7 @@ static long find_conn_in_obj(const csch_conn_t *conn, const csch_chdr_t *obj)
 	return -1;
 }
 
-csch_inline long csch_conn_add_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj, long *cidx)
+RND_INLINE long csch_conn_add_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj, long *cidx)
 {
 	long ci, gi;
 
@@ -307,7 +308,7 @@ csch_inline long csch_conn_add_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch
 }
 
 
-csch_inline int csch_conn_del_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj)
+RND_INLINE int csch_conn_del_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj)
 {
 	long ci, gi;
 	
@@ -320,6 +321,23 @@ csch_inline int csch_conn_del_obj_(csch_sheet_t *sheet, csch_conn_t *conn, csch_
 	return 0;
 }
 
+void csch_conn_ptr2text(csch_sheet_t *sheet, csch_conn_t *conn)
+{
+	long n;
+
+	csch_vtoidpath_enlarge(&conn->conn_path, conn->conn.used);
+	conn->conn_path.used = conn->conn.used;
+	for(n = 0; n < conn->conn.used; n++)
+		csch_oidpath_from_obj(&conn->conn_path.array[n], conn->conn.array[n]);
+
+	/* this changes conn->conn, so go backward */
+	for(n = conn->conn.used-1; n >= 0; n--)
+		csch_conn_del_obj_(sheet, conn, conn->conn.array[n]);
+
+	conn->conn.used = 0; /* just in case... to make sure the code resolves the oidpaths */
+	conn->dirty = 1;
+}
+
 /*** undoable conn-obj add/del ***/
 typedef struct {
 	csch_sheet_t *sheet;
@@ -383,7 +401,7 @@ static const uundo_oper_t undo_conn_obj_modify = {
 };
 
 
-csch_inline int csch_conn_do_obj(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj, int add, long *cidx, int undoable)
+RND_INLINE int csch_conn_do_obj(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj, int add, long *cidx, int undoable)
 {
 	int res;
 	undo_conn_obj_t utmp, *u = &utmp;
@@ -424,7 +442,7 @@ long csch_conn_add_obji(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *obj
 /* Return conn where:
    obj1 is in the connection and another object from obj2's parent is in too
    (or return NULL if not found) */
-csch_inline csch_conn_t *conn_find_common(csch_chdr_t *obj1, csch_chdr_t *obj2, long *o1i, csch_conn_t *ignore)
+RND_INLINE csch_conn_t *conn_find_common(csch_chdr_t *obj1, csch_chdr_t *obj2, long *o1i, csch_conn_t *ignore)
 {
 	long n, m;
 	csch_conn_t *conn;
@@ -462,7 +480,7 @@ csch_conn_t *csch_conn_find_mergable(csch_sheet_t *sheet, csch_conn_t *conn, csc
 	return NULL;
 }
 
-csch_inline csch_conn_t *csch_conn_auto_add_(csch_sheet_t *sheet, csch_chdr_t *obj1, csch_chdr_t *obj2, long *obj1i)
+RND_INLINE csch_conn_t *csch_conn_auto_add_(csch_sheet_t *sheet, csch_chdr_t *obj1, csch_chdr_t *obj2, long *obj1i)
 {
 	csch_conn_t *conn;
 
@@ -673,7 +691,8 @@ void csch_recalc_obj_conn(csch_sheet_t *sheet, csch_chdr_t *wobj, csch_displayer
 	for(n = ctx.keep.used-1; n >= 0; n--) {
 		if (ctx.keep.array[n]) {
 			csch_conn_remove_disconnected_objs(sheet, wobj->conn.array[n], wobj);
-			csch_conn_update(sheet, wobj->conn.array[n], 1);
+			if (wobj->conn.used > n)
+				csch_conn_update(sheet, wobj->conn.array[n], 1);
 			continue;
 		}
 		rnd_trace("! remove conn %ld\n", n);
@@ -727,5 +746,16 @@ void csch_conn_auto_recalc_geo(csch_sheet_t *sheet, csch_chdr_t *obj)
 		csch_conn_recalc_coords((csch_conn_t *)obj);
 }
 
+void csch_conn_update_dirties(csch_sheet_t *sheet, csch_cgrp_t *grp, int do_xform)
+{
+	htip_entry_t *e;
 
-
+	for(e = htip_first(&grp->id2obj); e != NULL; e = htip_next(&grp->id2obj, e)) {
+		csch_cgrp_t *g = e->value;
+		csch_conn_t *c = e->value;
+		if ((c->hdr.type == CSCH_CTYPE_CONN) && c->dirty)
+			csch_conn_update(sheet, c, do_xform);
+		else if (csch_obj_is_grp(&g->hdr))
+			csch_conn_update_dirties(sheet, g, do_xform);
+	}
+}
