@@ -58,7 +58,7 @@
 #include "abstract.h"
 #include "libcschem.h"
 
-csch_inline csch_role_t csch_role_str2role(const char *str)
+RND_INLINE csch_role_t csch_role_str2role(const char *str)
 {
 	if ((str == NULL) || (*str == '\0'))  return CSCH_ROLE_empty;
 	if (strcmp(str, "bus-net") == 0)      return CSCH_ROLE_BUS_NET;
@@ -71,7 +71,7 @@ csch_inline csch_role_t csch_role_str2role(const char *str)
 	return CSCH_ROLE_invalid;
 }
 
-csch_inline void csch_role_set(csch_cgrp_t *grp, const char *val)
+RND_INLINE void csch_role_set(csch_cgrp_t *grp, const char *val)
 {
 	grp->srole = val;
 	grp->role = csch_role_str2role(val);
@@ -241,13 +241,22 @@ void csch_cgrp_bbox_update(csch_sheet_t *sheet, csch_cgrp_t *grp)
 	csch_grpo_iter_t it;
 
 	csch_bbox_reset(&grp->hdr.bbox);
+	csch_bbox_reset(&grp->bbox_flt);
 	for(h = csch_grpo_first(&it, sheet, grp); h != NULL; h = csch_grpo_next(&it)) {
 		if (csch_bbox_is_invalid(&h->bbox))
 			continue;
-		csch_bbox_bump(&grp->hdr.bbox, x, h->bbox.x1);
-		csch_bbox_bump(&grp->hdr.bbox, x, h->bbox.x2);
-		csch_bbox_bump(&grp->hdr.bbox, y, h->bbox.y1);
-		csch_bbox_bump(&grp->hdr.bbox, y, h->bbox.y2);
+
+		csch_bbox_bump(&grp->bbox_flt, x, h->bbox.x1);
+		csch_bbox_bump(&grp->bbox_flt, x, h->bbox.x2);
+		csch_bbox_bump(&grp->bbox_flt, y, h->bbox.y1);
+		csch_bbox_bump(&grp->bbox_flt, y, h->bbox.y2);
+
+		if (!h->floater) {
+			csch_bbox_bump(&grp->hdr.bbox, x, h->bbox.x1);
+			csch_bbox_bump(&grp->hdr.bbox, x, h->bbox.x2);
+			csch_bbox_bump(&grp->hdr.bbox, y, h->bbox.y1);
+			csch_bbox_bump(&grp->hdr.bbox, y, h->bbox.y2);
+		}
 	}
 }
 
@@ -298,6 +307,8 @@ void csch_cgrp_render_all(csch_sheet_t *sheet, csch_cgrp_t *grp)
 		else if (g->hdr.type == CSCH_CTYPE_GRP)
 			csch_cgrp_render_all(sheet, g); /* need to recurse to find sub-group-refs */
 	}
+
+	csch_conn_update_dirties(sheet, grp, 0);
 }
 
 void csch_cgrp_attrib_update(csch_sheet_t *sheet, csch_cgrp_t *grp, int prio, const char *key, const char *val)
@@ -427,7 +438,7 @@ static void cgrp_remove_alloc(csch_undo_remove_t *slot)
 
 static void cgrp_remove_redo(csch_undo_remove_t *slot)
 {
-	csch_rtree_remove_recursive(slot->sheet, slot->obj); /* need to manually remove from retree because children are also added */
+	csch_rtree_remove_recursive(slot->sheet, slot->obj); /* need to manually remove from rtree because children are also added */
 	csch_cnc_common_remove_redo(slot, CSCH_REM_FROM_PARENT | CSCH_REM_DEL_EMPTY_PARENT);
 }
 
@@ -463,7 +474,7 @@ static void cgrp_copy(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t dx, cs
 	}
 }
 
-csch_inline double cgrp_rotdir(csch_cgrp_t *cgrp)
+RND_INLINE double cgrp_rotdir(csch_cgrp_t *cgrp)
 {
 	return cgrp->mirx ^ cgrp->miry ? -1.0 : 1.0;
 }
@@ -538,7 +549,7 @@ static g2d_xform_t mx33adj(g2d_xform_t mx)
 	return res;
 }
 
-csch_inline void csch_cgrp_inverse_matrix_(g2d_xform_t *dst, const csch_cgrp_t *cgrp)
+RND_INLINE void csch_cgrp_inverse_matrix_(g2d_xform_t *dst, const csch_cgrp_t *cgrp)
 {
 	double det = mx33det(cgrp->xform.mx);
 	g2d_xform_t mx = mx33adj(cgrp->xform.mx);
