@@ -76,6 +76,25 @@ csch_cgrp_t *csch_cgrp_refget(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid
 	return grp;
 }
 
+/* convert all connections back to oidpath format because the object is
+   free'd but will be re-created later */
+static void csch_cgrp_ref_clean_conns(csch_sheet_t *sheet, csch_chdr_t *o)
+{
+	long n;
+
+	for(n = o->conn.used-1; n >= 0; n--) /* go backward because csch_conn_ptr2text() removes from this list */
+		if (o->conn.array[n] != NULL)
+			csch_conn_ptr2text(sheet, o->conn.array[n]);
+
+	if (csch_obj_is_grp(o)) {
+		htip_entry_t *e;
+		csch_cgrp_t *g = o;
+
+		for(e = htip_first(&g->id2obj); e != NULL; e = htip_next(&g->id2obj, e))
+			csch_cgrp_ref_clean_conns(sheet, e->value);
+	}
+
+}
 
 void csch_cgrp_ref_clean(csch_sheet_t *sheet, csch_cgrp_t *grpref)
 {
@@ -85,6 +104,7 @@ void csch_cgrp_ref_clean(csch_sheet_t *sheet, csch_cgrp_t *grpref)
 
 	for(e = htip_first(&grpref->id2obj); e != NULL; e = htip_next(&grpref->id2obj, e)) {
 		csch_chdr_t *o = e->value;
+		csch_cgrp_ref_clean_conns(sheet, o);
 		csch_cobj_free(o);
 	}
 }
@@ -161,13 +181,13 @@ int csch_cgrp_ref_ptr2text(csch_sheet_t *sheet, csch_cgrp_t *grpref)
 }
 
 
-csch_inline void csch_cgrp_childr_xform_apply(csch_sheet_t *sheet, csch_cgrp_t *grpref, csch_child_xform_t *cx, csch_chdr_t *child, long cx_idx)
+RND_INLINE void csch_cgrp_childr_xform_apply(csch_sheet_t *sheet, csch_cgrp_t *grpref, csch_child_xform_t *cx, csch_chdr_t *child, long cx_idx)
 {
 	child->grp_ref_xform.g = grpref;
 	child->grp_ref_xform.idx = cx_idx;
 }
 
-csch_inline void csch_cgrp_children_xform_apply(csch_sheet_t *sheet, csch_cgrp_t *grpref)
+RND_INLINE void csch_cgrp_children_xform_apply(csch_sheet_t *sheet, csch_cgrp_t *grpref)
 {
 	long n;
 	for(n = 0; n < grpref->data.ref.child_xform.used; n++) {
@@ -390,7 +410,7 @@ void csch_child_xform_modify(csch_sheet_t *sheet, csch_cgrp_t *grpref, long idx,
 	u->cx.miry = CSCH_UNDO_MODIFY(cx, miry);
 	u->cx.remove = CSCH_UNDO_MODIFY(cx, remove);
 	u->cx.cache = CSCH_UNDO_MODIFY(cx, cache);
-	u->cx.remove = cx->removed;
+	u->cx.removed = cx->removed;
 
 	undo_child_xform_modify_swap(u);
 	if (undoable) csch_undo_inc_serial(sheet);
