@@ -33,9 +33,9 @@
 #include "undo.h"
 
 #include "cnc_obj.h"
+#include "cnc_poly.h"
 
-
-csch_inline csch_displayer_t role2ly(csch_role_t role, csch_chdr_t *obj)
+RND_INLINE csch_displayer_t role2ly(csch_role_t role, csch_chdr_t *obj)
 {
 	switch(role) {
 		case CSCH_ROLE_BUS_NET:       return CSCH_DSPLY_BUS;
@@ -129,10 +129,11 @@ void csch_cobj_bbox_changed(csch_sheet_t *sheet, csch_chdr_t *obj)
 {
 	csch_cgrp_t *prn = obj->parent;
 	csch_chdr_t *phd;
+	int changed = 0;
 
 	if (prn == NULL) {
-		if (obj == &sheet->direct.hdr) {
-			sheet->bbox = sheet->direct.hdr.bbox;
+		if (!sheet->non_graphical && (obj == &sheet->direct.hdr)) {
+			sheet->bbox = sheet->direct.bbox_flt;
 			sheet->bbox_changed = 1;
 		}
 		return; /* happens in top groups, like direct or indirect */
@@ -140,18 +141,30 @@ void csch_cobj_bbox_changed(csch_sheet_t *sheet, csch_chdr_t *obj)
 
 	phd = &prn->hdr;
 
-	/* no-op if did not grow */
-	if ((obj->bbox.x1 >= phd->bbox.x1) && (obj->bbox.y1 >= phd->bbox.y1) && (obj->bbox.x2 <= phd->bbox.x2) && (obj->bbox.y2 <= phd->bbox.y2))
-		return;
+		/* only if it did grow */
+	if ((obj->bbox.x1 < prn->bbox_flt.x1) || (obj->bbox.y1 < prn->bbox_flt.y1) || (obj->bbox.x2 > prn->bbox_flt.x2) || (obj->bbox.y2 > prn->bbox_flt.y2)) {
+		if (obj->bbox.x1 < prn->bbox_flt.x1) prn->bbox_flt.x1 = obj->bbox.x1;
+		if (obj->bbox.y1 < prn->bbox_flt.y1) prn->bbox_flt.y1 = obj->bbox.y1;
+		if (obj->bbox.x2 > prn->bbox_flt.x2) prn->bbox_flt.x2 = obj->bbox.x2;
+		if (obj->bbox.y2 > prn->bbox_flt.y2) prn->bbox_flt.y2 = obj->bbox.y2;
+		changed = 1;
+	}
 
-	csch_cobj_rtree_del(sheet, phd);
-	if (obj->bbox.x1 < phd->bbox.x1) phd->bbox.x1 = obj->bbox.x1;
-	if (obj->bbox.y1 < phd->bbox.y1) phd->bbox.y1 = obj->bbox.y1;
-	if (obj->bbox.x2 > phd->bbox.x2) phd->bbox.x2 = obj->bbox.x2;
-	if (obj->bbox.y2 > phd->bbox.y2) phd->bbox.y2 = obj->bbox.y2;
-	csch_cobj_rtree_add(sheet, phd);
+	if (!obj->floater) {
+		/* only if it did grow */
+		if ((obj->bbox.x1 < phd->bbox.x1) || (obj->bbox.y1 < phd->bbox.y1) || (obj->bbox.x2 > phd->bbox.x2) || (obj->bbox.y2 > phd->bbox.y2)) {
+			csch_cobj_rtree_del(sheet, phd);
+			if (obj->bbox.x1 < phd->bbox.x1) phd->bbox.x1 = obj->bbox.x1;
+			if (obj->bbox.y1 < phd->bbox.y1) phd->bbox.y1 = obj->bbox.y1;
+			if (obj->bbox.x2 > phd->bbox.x2) phd->bbox.x2 = obj->bbox.x2;
+			if (obj->bbox.y2 > phd->bbox.y2) phd->bbox.y2 = obj->bbox.y2;
+			csch_cobj_rtree_add(sheet, phd);
+			changed = 1;
+		}
+	}
 
-	csch_cobj_bbox_changed(sheet, phd);
+	if (changed)
+		csch_cobj_bbox_changed(sheet, phd);
 }
 
 static const char core_commprp_cookie[] = "libcschem/core/cnc_obj.c";
@@ -244,3 +257,8 @@ unsigned csch_chdr_eq(const csch_chdr_t *hdr1, const csch_chdr_t *hdr2)
 	return 1;
 }
 
+int csch_cobj_has_fill_(csch_chdr_t *obj)
+{
+	return csch_cpoly_has_fill((csch_cpoly_t *)obj);
+}
+
