@@ -40,12 +40,6 @@
 
 #define csch_obj_bbox_reset(obj) csch_bbox_reset(&((obj)->hdr.bbox))
 
-#define csch_obj_bbox_bump(obj, coord, value) \
-do { \
-	if (value < obj->hdr.bbox.coord ## 1) { obj->hdr.bbox.coord ## 1 = value; obj->hdr.sheet->bbox.x1 = CSCH_COORD_INV; } \
-	if (value > obj->hdr.bbox.coord ## 2) { obj->hdr.bbox.coord ## 2 = value; obj->hdr.sheet->bbox.x1 = CSCH_COORD_INV; } \
-} while(0)
-
 #define csch_cobj_redraw(obj) \
 do { \
 	csch_chdr_t *__obj__ = (csch_chdr_t *)obj; \
@@ -58,8 +52,8 @@ do { \
 } while(0)
 
 /* Stop generating redraw events on object changes */
-csch_inline void csch_cobj_redraw_freeze(csch_sheet_t *sheet);
-csch_inline void csch_cobj_redraw_unfreeze(csch_sheet_t *sheet);
+RND_INLINE void csch_cobj_redraw_freeze(csch_sheet_t *sheet);
+RND_INLINE void csch_cobj_redraw_unfreeze(csch_sheet_t *sheet);
 
 /* implement heuristics to figure on which display layer an object is supposed to go */
 csch_displayer_t csch_cobj_dsply(csch_chdr_t *obj);
@@ -71,23 +65,23 @@ int csch_cobj_update_dsply(csch_sheet_t *sheet, csch_chdr_t *obj);
 
 /* Object rtree management; del returns 0 on success (object got removed
    from the tree) and non-zero when the object was not in the tree. */
-csch_inline int  csch_cobj_rtree_del(csch_sheet_t *sheet, csch_chdr_t *obj);
-csch_inline void csch_cobj_rtree_add(csch_sheet_t *sheet, csch_chdr_t *obj);
+RND_INLINE int  csch_cobj_rtree_del(csch_sheet_t *sheet, csch_chdr_t *obj);
+RND_INLINE void csch_cobj_rtree_add(csch_sheet_t *sheet, csch_chdr_t *obj);
 
 /* Insert an object in a group by setting the common header fields; do not use
    directly, use csch_cobj_insert() */
-csch_inline void csch_cobj_insert_(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid);
+RND_INLINE void csch_cobj_insert_(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid);
 
 /* Initialize an object by setting the common header fields; the only purpose
    of this function is to get compiler warnings at every caller when the header
    is extended (because the number of args would be extended here) */
-csch_inline void csch_cobj_init(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid, csch_ctype_t type);
+RND_INLINE void csch_cobj_init(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid, csch_ctype_t type);
 
 /* free common fields */
-csch_inline void csch_cobj_uninit(csch_chdr_t *dst);
+RND_INLINE void csch_cobj_uninit(csch_chdr_t *dst);
 
 /* Recalculate stroke/fill cache in dst */
-csch_inline void csch_cobj_update_pen(csch_chdr_t *dst);
+RND_INLINE void csch_cobj_update_pen(csch_chdr_t *dst);
 
 /* Insert an object in parent group, using new oid, if the object is not
    already in a group (so obj->parent must be NULL). Sheet is (the new)
@@ -95,25 +89,25 @@ csch_inline void csch_cobj_update_pen(csch_chdr_t *dst);
 int csch_cobj_insert(csch_sheet_t *sheet, csch_cgrp_t *parent, csch_chdr_t *obj, csch_oid_t oid);
 
 /* Returns whether the group is atomic (group parts are not directly editable) */
-csch_inline int csch_grp_is_atomic(csch_sheet_t *sheet, csch_cgrp_t *grp);
+RND_INLINE int csch_grp_is_atomic(csch_sheet_t *sheet, csch_cgrp_t *grp);
 
 /* Returns 1 if obj is locked for any reason (lock property, group-lock); this
    means obj should not be edited directly. */
-csch_inline int csch_cobj_is_locked(csch_chdr_t *obj);
+RND_INLINE int csch_cobj_is_locked(csch_chdr_t *obj);
 
 /* Returns 1 if obj is locked with the lock property directly or through
    parent, but ignores group locking */
-csch_inline int csch_cobj_is_explicit_locked(csch_chdr_t *obj);
+RND_INLINE int csch_cobj_is_explicit_locked(csch_chdr_t *obj);
 
 /* Similar to csch_cobj_is_locked() but returns the first parent that is
    not locked; doesn't return sheet->direct; returns NULL if no such
    parent found */
-csch_inline csch_chdr_t *csch_cobj_first_unlocked(csch_chdr_t *obj);
+RND_INLINE csch_chdr_t *csch_cobj_first_unlocked(csch_chdr_t *obj);
 
 /* Similar to csch_cobj_is_locked() but returns the first parent that is
    explicitly locked using the lock attr; doesn't return sheet->direct;
    returns NULL if no such parent found */
-csch_inline csch_chdr_t *csch_cobj_first_explicit_locked(csch_chdr_t *obj);
+RND_INLINE csch_chdr_t *csch_cobj_first_explicit_locked(csch_chdr_t *obj);
 
 /* Modify common properties (doc: {des3:81}) of any object */
 void csch_commprp_modify(csch_sheet_t *sheet, csch_chdr_t *obj, int *lock, int *floater, int undoable);
@@ -125,11 +119,11 @@ void csch_cobj_bbox_changed(csch_sheet_t *sheet, csch_chdr_t *obj);
 /*** Hash ***/
 
 unsigned csch_chdr_hash(const csch_chdr_t *hdr);
-csch_inline unsigned csch_coord_hash(csch_coord_t crd);
-csch_inline unsigned csch_angle_hash(double angle);
+RND_INLINE unsigned csch_coord_hash(csch_coord_t crd);
+RND_INLINE unsigned csch_angle_hash(double angle);
 
 unsigned csch_chdr_eq(const csch_chdr_t *hdr1, const csch_chdr_t *hdr2);
-csch_inline unsigned csch_angle_eq(double angle1, double angle2);
+RND_INLINE unsigned csch_angle_eq(double angle1, double angle2);
 
 
 
@@ -137,7 +131,7 @@ csch_inline unsigned csch_angle_eq(double angle1, double angle2);
 
 /* Internal call for csch_cobj_redraw(): add box to the redraw bbox
    (sheet->inbbox) without any immediate redraw */
-csch_inline void csch_sheet_inval_lr(csch_sheet_t *sheet, csch_rtree_box_t *box)
+RND_INLINE void csch_sheet_inval_lr(csch_sheet_t *sheet, csch_rtree_box_t *box)
 {
 	if (box->x1 < sheet->invbox.x1) sheet->invbox.x1 = box->x1;
 	if (box->x2 > sheet->invbox.x2) sheet->invbox.x2 = box->x2;
@@ -146,7 +140,7 @@ csch_inline void csch_sheet_inval_lr(csch_sheet_t *sheet, csch_rtree_box_t *box)
 	sheet->invbox_valid = 1;
 }
 
-csch_inline void csch_cobj_redraw_freeze(csch_sheet_t *sheet)
+RND_INLINE void csch_cobj_redraw_freeze(csch_sheet_t *sheet)
 {
 	sheet->redraw_inhibit++;
 	if (sheet->redraw_inhibit == 1) {
@@ -156,7 +150,7 @@ csch_inline void csch_cobj_redraw_freeze(csch_sheet_t *sheet)
 	}
 }
 
-csch_inline void csch_cobj_redraw_unfreeze(csch_sheet_t *sheet)
+RND_INLINE void csch_cobj_redraw_unfreeze(csch_sheet_t *sheet)
 {
 	assert(sheet->redraw_inhibit > 0);
 	if (sheet->redraw_inhibit > 0) {
@@ -168,23 +162,36 @@ csch_inline void csch_cobj_redraw_unfreeze(csch_sheet_t *sheet)
 	}
 }
 
+int csch_cobj_has_fill_(csch_chdr_t *obj);
+RND_INLINE int csch_cobj_has_fill(csch_chdr_t *obj)
+{
+	if (obj->type != CSCH_CTYPE_POLY) return 0;
+	return csch_cobj_has_fill_(obj);
+}
 
-csch_inline int csch_cobj_rtree_del(csch_sheet_t *sheet, csch_chdr_t *obj)
+
+RND_INLINE int csch_cobj_rtree_del(csch_sheet_t *sheet, csch_chdr_t *obj)
 {
 	if ((obj->dsply < 0) || (obj->dsply >= CSCH_DSPLY_max) || (csch_bbox_is_invalid(&obj->bbox)))
 		return -1;
+
+	if (csch_cobj_has_fill(obj))
+		csch_rtree_delete(&sheet->dsply_fill[obj->dsply], obj, &obj->bbox);
+
 	return csch_rtree_delete(&sheet->dsply[obj->dsply], obj, &obj->bbox);
 }
 
-csch_inline void csch_cobj_rtree_add(csch_sheet_t *sheet, csch_chdr_t *obj)
+RND_INLINE void csch_cobj_rtree_add(csch_sheet_t *sheet, csch_chdr_t *obj)
 {
 	if ((obj->dsply < 0) || (obj->dsply >= CSCH_DSPLY_max) || (csch_bbox_is_invalid(&obj->bbox)) || obj->indirect)
 		return;
+	if (csch_cobj_has_fill(obj))
+		csch_rtree_insert(&sheet->dsply_fill[obj->dsply], obj, &obj->bbox);
 	csch_rtree_insert(&sheet->dsply[obj->dsply], obj, &obj->bbox);
 }
 
 
-csch_inline void csch_cobj_insert_(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid)
+RND_INLINE void csch_cobj_insert_(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid)
 {
 	csch_cgrp_t *p;
 
@@ -205,14 +212,14 @@ csch_inline void csch_cobj_insert_(csch_chdr_t *dst, csch_sheet_t *sheet, csch_c
 	}
 }
 
-csch_inline void csch_cobj_init(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid, csch_ctype_t type)
+RND_INLINE void csch_cobj_init(csch_chdr_t *dst, csch_sheet_t *sheet, csch_cgrp_t *parent, csch_oid_t oid, csch_ctype_t type)
 {
 	dst->type = type;
 	csch_cobj_insert_(dst, sheet, parent, oid);
 	csch_bbox_reset(&dst->bbox);
 }
 
-csch_inline void csch_cobj_uninit(csch_chdr_t *dst)
+RND_INLINE void csch_cobj_uninit(csch_chdr_t *dst)
 {
 	csch_chdr_t *o;
 
@@ -229,7 +236,7 @@ csch_inline void csch_cobj_uninit(csch_chdr_t *dst)
 	vtp0_uninit(&dst->conn);
 }
 
-csch_inline void csch_cobj_update_pen(csch_chdr_t *dst)
+RND_INLINE void csch_cobj_update_pen(csch_chdr_t *dst)
 {
 	csch_cobj_redraw(dst);
 	csch_stroke_(dst);
@@ -240,7 +247,7 @@ csch_inline void csch_cobj_update_pen(csch_chdr_t *dst)
 }
 
 
-csch_inline int csch_grp_is_atomic(csch_sheet_t *sheet, csch_cgrp_t *grp)
+RND_INLINE int csch_grp_is_atomic(csch_sheet_t *sheet, csch_cgrp_t *grp)
 {
 	if ((grp == NULL) || (grp == &sheet->direct) || (grp == &sheet->indirect))
 		return 0;
@@ -261,7 +268,7 @@ csch_inline int csch_grp_is_atomic(csch_sheet_t *sheet, csch_cgrp_t *grp)
 	return 0;
 }
 
-csch_inline int csch_cobj_is_explicit_locked(csch_chdr_t *obj)
+RND_INLINE int csch_cobj_is_explicit_locked(csch_chdr_t *obj)
 {
 	csch_chdr_t *o;
 
@@ -273,7 +280,7 @@ csch_inline int csch_cobj_is_explicit_locked(csch_chdr_t *obj)
 	return 0;
 }
 
-csch_inline int csch_cobj_is_locked(csch_chdr_t *obj)
+RND_INLINE int csch_cobj_is_locked(csch_chdr_t *obj)
 {
 	/* group lock */
 	if (csch_grp_is_atomic(obj->sheet, obj->parent) && !obj->floater)
@@ -283,7 +290,7 @@ csch_inline int csch_cobj_is_locked(csch_chdr_t *obj)
 }
 
 
-csch_inline csch_chdr_t *csch_cobj_first_unlocked(csch_chdr_t *obj)
+RND_INLINE csch_chdr_t *csch_cobj_first_unlocked(csch_chdr_t *obj)
 {
 	csch_chdr_t *o;
 
@@ -300,7 +307,7 @@ csch_inline csch_chdr_t *csch_cobj_first_unlocked(csch_chdr_t *obj)
 }
 
 
-csch_inline csch_chdr_t *csch_cobj_first_explicit_locked(csch_chdr_t *obj)
+RND_INLINE csch_chdr_t *csch_cobj_first_explicit_locked(csch_chdr_t *obj)
 {
 	csch_chdr_t *o;
 
@@ -315,17 +322,17 @@ csch_inline csch_chdr_t *csch_cobj_first_explicit_locked(csch_chdr_t *obj)
 	return NULL;
 }
 
-csch_inline unsigned csch_coord_hash(csch_coord_t crd)
+RND_INLINE unsigned csch_coord_hash(csch_coord_t crd)
 {
 	return crd;
 }
 
-csch_inline unsigned csch_angle_hash(double angle)
+RND_INLINE unsigned csch_angle_hash(double angle)
 {
 	return floor(angle * 100.0);
 }
 
-csch_inline unsigned csch_angle_eq(double angle1, double angle2)
+RND_INLINE unsigned csch_angle_eq(double angle1, double angle2)
 {
 	double diff = angle1 - angle2;
 	return ((diff >= -0.01) && (diff <= +0.01));
