@@ -103,7 +103,7 @@ csch_cpen_t *csch_pen_dup(csch_sheet_t *sheet, csch_cgrp_t *parent, const csch_c
 
 void (*csch_cb_pen_invalidate_font)(csch_sheet_t *sheet, csch_cpen_t *pen);
 
-csch_inline int csch_pen_same(csch_cpen_t *pen, csch_chdr_t *hdr, int is_fill)
+RND_INLINE int csch_pen_same(csch_cpen_t *pen, csch_chdr_t *hdr, int is_fill)
 {
 	csch_comm_str_t *target;
 
