@@ -84,7 +84,7 @@ csch_cpen_t *csch_pen_resolve(csch_cgrp_t *grp, const char *pen_name);
 
 
 /* Return the object pen falling back to the "unknown pen" when not available */
-csch_inline csch_cpen_t *csch_stroke_(csch_chdr_t *hdr)
+RND_INLINE csch_cpen_t *csch_stroke_(csch_chdr_t *hdr)
 {
 	if (hdr->stroke == NULL) {
 		csch_cgrp_t *grp = hdr->parent;
@@ -100,7 +100,7 @@ csch_inline csch_cpen_t *csch_stroke_(csch_chdr_t *hdr)
 #define csch_stroke(sheet, obj) csch_stroke_(&(obj->hdr))
 
 /* same as csch_stroke_() but with an option to use fallback pens from a group */
-csch_inline csch_cpen_t *csch_stroke_fallback_(csch_chdr_t *hdr, csch_cgrp_t *fallback)
+RND_INLINE csch_cpen_t *csch_stroke_fallback_(csch_chdr_t *hdr, csch_cgrp_t *fallback)
 {
 	csch_cpen_t *res = csch_stroke_(hdr);
 	if ((res == &csch_pen_default_unknown) && (fallback != NULL)) {
@@ -113,7 +113,7 @@ csch_inline csch_cpen_t *csch_stroke_fallback_(csch_chdr_t *hdr, csch_cgrp_t *fa
 #define csch_stroke_fallback(sheet, obj, fb) csch_stroke_fallback_(&(obj->hdr), fb)
 
 /* Return the object pen falling back to the "unknown pen" when not available */
-csch_inline csch_cpen_t *csch_fill_(csch_chdr_t *hdr)
+RND_INLINE csch_cpen_t *csch_fill_(csch_chdr_t *hdr)
 {
 	if (hdr->fill == NULL) {
 		csch_cgrp_t *grp = hdr->parent;
@@ -130,7 +130,7 @@ csch_inline csch_cpen_t *csch_fill_(csch_chdr_t *hdr)
 
 
 /* same as csch_stroke_() but with an option to use fallback pens from a group */
-csch_inline csch_cpen_t *csch_fill_fallback_(csch_chdr_t *hdr, csch_cgrp_t *fallback)
+RND_INLINE csch_cpen_t *csch_fill_fallback_(csch_chdr_t *hdr, csch_cgrp_t *fallback)
 {
 	csch_cpen_t *res = csch_fill_(hdr);
 	if ((res == &csch_pen_default_unknown) && (fallback != NULL)) {
