@@ -91,6 +91,27 @@ csch_cpoly_t *csch_cpoly_get(csch_sheet_t *sheet, csch_cgrp_t *grp, csch_oid_t o
 	return poly;
 }
 
+void csch_cpoly_center_bbox(csch_sheet_t *sheet, const csch_cpoly_t *poly, csch_rtree_box_t *dst)
+{
+	long n;
+	csch_coutline_t *o;
+	csch_rtree_box_t tmp;
+
+	csch_bbox_reset(dst);
+
+	for(n = 0, o = poly->outline.array; n < poly->outline.used; n++, o++) {
+		switch(o->hdr.type) {
+			case CSCH_CTYPE_LINE: csch_line_center_bbox(sheet, &o->line, &tmp); break;
+			case CSCH_CTYPE_ARC: csch_arc_center_bbox(sheet, &o->arc, &tmp); break;
+			default: break; /* already warned */
+		}
+		csch_bbox_bump(dst, x, tmp.x1);
+		csch_bbox_bump(dst, x, tmp.x2);
+		csch_bbox_bump(dst, y, tmp.y1);
+		csch_bbox_bump(dst, y, tmp.y2);
+	}
+}
+
 void csch_poly_update(csch_sheet_t *sheet, csch_cpoly_t *poly, int do_xform)
 {
 	long n;
@@ -98,6 +119,8 @@ void csch_poly_update(csch_sheet_t *sheet, csch_cpoly_t *poly, int do_xform)
 
 	csch_cobj_update_pen(&poly->hdr);
 
+	poly->area = -1;
+
 	if (do_xform) {
 		for(n = 0, o = poly->outline.array; n < poly->outline.used; n++, o++) {
 			csch_ctype_t type_save = o->hdr.type;
@@ -132,6 +155,11 @@ void csch_poly_update(csch_sheet_t *sheet, csch_cpoly_t *poly, int do_xform)
 	csch_cobj_bbox_changed(sheet, &poly->hdr);
 }
 
+int csch_cpoly_has_fill(csch_cpoly_t *poly)
+{
+	return poly->has_fill;
+}
+
 static csch_chdr_t *poly_create(csch_sheet_t *sheet, csch_cgrp_t *parent)
 {
 	csch_cpoly_t *poly = csch_cpoly_alloc(sheet, parent, csch_oid_new(sheet, parent));
@@ -360,7 +388,7 @@ const csch_ops_t csch_ops_poly = {
 	poly_inst2spec
 };
 
-csch_inline unsigned csch_contour_hash(const csch_chdr_t *obj)
+RND_INLINE unsigned csch_contour_hash(const csch_chdr_t *obj)
 {
 	switch(obj->type) {
 		case CSCH_CTYPE_LINE: return csch_line_hash_((const csch_line_t *)obj, 0, 1);
@@ -370,7 +398,7 @@ csch_inline unsigned csch_contour_hash(const csch_chdr_t *obj)
 	return 0;
 }
 
-csch_inline int csch_contour_keyeq(const csch_chdr_t *p1, const csch_chdr_t *p2)
+RND_INLINE int csch_contour_keyeq(const csch_chdr_t *p1, const csch_chdr_t *p2)
 {
 	if (p1->type != p2->type) return 0;
 	switch(p1->type) {
