@@ -41,7 +41,7 @@
 #include "project.h"
 #include "util_path.h"
 
-csch_inline const csch_chdr_t *get_attrib_obj(char **path, const csch_text_t *text)
+RND_INLINE const csch_chdr_t *get_attrib_obj(char **path, const csch_text_t *text)
 {
 	const csch_chdr_t *hdr = &text->hdr;
 	for(;;) {
