@@ -30,6 +30,8 @@
 
 #include <stdio.h>
 
+#include <librnd/core/compat_misc.h>
+
 #include "abstract.h"
 #include "actions_csch.h"
 #include "concrete.h"
@@ -48,75 +50,107 @@
 #include "util_compile.h"
 #include "util_project.h"
 #include "libcschem.h"
+#include "non_graphical.h"
+
 #include "compile.h"
 
+int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, int referee, int append, csch_attrib_t **dsta_out)
+{
+	csch_attrib_t *dsta = NULL;
+	const char *key = (dstkey == NULL ? srca->key : dstkey);
+
+	if (key[0] == '-') {
+		if (dsta_out != NULL) *dsta_out = NULL;
+		return 0;
+	}
+
+	if (key[0] == '+') {
+		key++;
+		append = 1;
+	}
+
+	dsta = csch_attrib_get(&dst->attr, key);
+	if (dsta_out != NULL) *dsta_out = dsta;
+
+	/* attribute merging logic */
+	if (srca->val != NULL) {
+		if (append)
+			return csch_attrib_append_val(&dst->attr, srca->prio, key, srca, src);
+		if (dsta != NULL) {
+			if (dsta->val != NULL) {
+				if (strcmp(srca->val, dsta->val) == 0) {
+					/* both set, same value, remember lowest prio */
+					if (srca->prio >= dsta->prio) {
+						csch_attrib_append_src(dsta, srca->prio, src, 1);
+						return 0; /* ignore new */
+					}
+				}
+				else {
+					/* different values, look at prios */
+					if (srca->prio > dsta->prio) {
+						csch_attrib_append_src(dsta, srca->prio, src, 1);
+						return 0; /* lower prio, ignore */
+					}
+					if (srca->prio == dsta->prio) {
+						if (!referee) /* it's okay if a group ref's referee had it - we are overwriting it from the group ref */
+							rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: attribute collision for '%s'\n", err1, err2, srca->key);
+						csch_attr_src_free(src);
+						return -1;
+					}
+					/* else set */
+				}
+			}
+		}
+		csch_attrib_set(&dst->attr, srca->prio, key, srca->val, src, dsta_out);
+	}
+	else {
+		if (append) {
+			if ((dsta != NULL) && (dsta->val != NULL)) {
+				csch_attr_src_free(src);
+				rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: can not append to destination attribute '%s', it is a string not an array\n", err1, err2, key);
+				return -1;
+			}
+			return csch_attrib_append_val(&dst->attr, srca->prio, key, srca, src);
+		}
+		else
+			csch_attrib_set_arr(&dst->attr, srca->prio, key, &srca->arr, src, dsta_out);
+	}
+
+	return 0;
+}
+
+/* Copy all sources from srca in front of the sources in dst */
+static void compile_attribute_copy_srcs_front(csch_attrib_t *dst, const csch_attrib_t *srca)
+{
+	long n;
+
+	if (srca->source.used <= 0)
+		return;
+
+	vts0_alloc_insert(&dst->source, 0, srca->source.used);
+	for(n = 0; n < srca->source.used; n++)
+		dst->source.array[n] = rnd_strdup(srca->source.array[n]);
+}
+
 static int compile_attributes(csch_ahdr_t *dst, const csch_attribs_t *src, csch_cgrp_t *cgrp, const char *err1, const char *err2, int referee)
 {
 	htsp_entry_t *e;
+	int res = 0, r1;
+
 	for(e = htsp_first(src); e; e = htsp_next(src, e)) {
-		const csch_attrib_t *a = e->value;
-		csch_attrib_t *aa;
-		csch_source_arg_t *src;
-		int append = 0;
-		const char *key = a->key;
+		const csch_attrib_t *srca = e->value;
+		csch_source_arg_t *src = csch_attrib_src_ac(&cgrp->hdr, srca->key, "compile_attributes()");
+		csch_attrib_t *dsta;
 
-		if (key[0] == '-')
-			continue;
+		r1 = csch_compile_attribute(dst, NULL, srca, src, err1, err2, referee, 0, &dsta);
 
-		if (key[0] == '+') {
-			key++;
-			append = 1;
-		}
+		if ((r1 == 0) && (dsta != NULL))
+			compile_attribute_copy_srcs_front(dsta, srca);
 
-		aa = csch_attrib_get(&dst->attr, key);
-
-		src = csch_attrib_src_ac(&cgrp->hdr, a->key, "compile_attributes()");
-
-		/* attribute merging logic */
-		if (a->val != NULL) {
-			if (append) {
-				rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: can not append source attribute '%s', it is a string not an array\n", err1, err2, a->key);
-				continue;
-			}
-			if (aa != NULL) {
-				if (aa->val != NULL) {
-					if (strcmp(a->val, aa->val) == 0) {
-						/* both set, same value, remember lowest prio */
-						if (a->prio >= aa->prio) {
-							csch_attrib_append_src(aa, a->prio, src, 1);
-							continue; /* ignore new */
-						}
-					}
-					else {
-						/* different values, look at prios */
-						if (a->prio > aa->prio) {
-							csch_attrib_append_src(aa, a->prio, src, 1);
-							continue; /* lower prio, ignore */
-						}
-						if (a->prio == aa->prio) {
-							if (!referee) /* it's okay if a group ref's referee had it - we are overwriting it from the group ref */
-								rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: attribute collision for '%s'\n", err1, err2, a->key);
-							continue;
-						}
-						/* else set */
-					}
-				}
-			}
-			csch_attrib_set(&dst->attr, a->prio, key, a->val, src, NULL);
-		}
-		else {
-			if (append) {
-				if ((aa != NULL) && (aa->val != NULL)) {
-					rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: can not append to destination attribute '%s', it is a string not an array\n", err1, err2, key);
-					continue;
-				}
-				rnd_message(RND_MSG_ERROR, "compile_attributes(): %s %s: can not append to destination attribute '%s': not yet implemented (file a bugreport!)\n", err1, err2, key);
-				continue;
-			}
-			else
-				csch_attrib_set_arr(&dst->attr, a->prio, key, &a->arr, src, NULL);
-		}
+		res |= r1;
 	}
+
+	TODO("this should return res");
 	return 0;
 }
 
@@ -221,8 +255,10 @@ static int compile_symbol(csch_abstract_t *dst, int viewid, const csch_sheet_t *
 
 	if (name_tmp != NULL)
 		comp = csch_acomp_get(dst, name_tmp, 1);
-	else
+	else if (name != NULL)
 		comp = csch_acomp_get(dst, name, 1);
+	else
+		return 0; /* comp has no name -> do not compile */
 
 	if (comp == NULL) {
 		csch_eng_free_strmod(&name_tmp, name);
@@ -253,20 +289,29 @@ int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_rec
 		csch_anet_t *new_net;
 
 		if (ap->conn.net != NULL) {
-			if (!allow_reconn) {
+			int allowed = 0;
+
+			/* special case: resistor term overlap with vcc term and a wire is
+			   also connected; this means we have a term-term net and a wirenet
+			   and this shouldn't be considered as a reconn because the
+			   term-term connection is really invisible */
+			if (ap->conn.net->term_term || (*net)->term_term)
+				allowed = 1;
+
+			if (!allow_reconn && !allowed) {
 				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): port %s:%s already connected\n(This error is generated because multiport_net_merge is disabled in the config)\n", ap->parent->name, ap->name);
 				return -1;
 			}
 			new_net = csch_cmp_merge_nets(*net, ap->conn.net);
 			if (new_net == NULL) {
-				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s\n", *net, ap->conn.net, ap->parent->name, ap->name);
+				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s\n", (*net)->name, ap->conn.net->name, ap->parent->name, ap->name);
 				return -1;
 			}
 			*net = new_net;
 		}
 		ap->conn.net = *net;
 
-		TODO("do the same for buses and bus ports? Or do we put nets in buses?");
+		TODO("bus: do the same for buses and bus ports? Or do we put nets in buses?");
 		vtp0_append(&(*net)->conns, a);
 		return 0;
 	}
@@ -275,6 +320,31 @@ int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_rec
 	return -1;
 }
 
+int csch_compile_disconnect(csch_ahdr_t *a)
+{
+	if (a->type == CSCH_ATYPE_PORT) {
+		csch_aport_t *ap = (csch_aport_t *)a;
+		csch_anet_t *net = ap->conn.net;
+		long n;
+
+		if (net == NULL)
+			return 0; /* already disconnected */
+
+		ap->conn.net = NULL;
+		for(n = 0; n < net->conns.used; n++) {
+			if (net->conns.array[n] == ap) {
+				vtp0_remove(&net->conns, n, 1);
+				break;
+			}
+		}
+
+		return 0;
+	}
+	rnd_message(RND_MSG_ERROR, "csch_compile_disconnect(): unsupported object type\n");
+	return -1;
+}
+
+
 static int compile_conn(csch_abstract_t *dst, const csch_sheet_t *sheet, const csch_conn_t *src)
 {
 	long n;
@@ -299,13 +369,13 @@ static int compile_conn(csch_abstract_t *dst, const csch_sheet_t *sheet, const c
 			continue;
 
 		if (grp->aid.used < 1) {
-			rnd_msg_error("Invalid object on the conn list (empty)\n");
+			rnd_msg_error("Invalid object on the conn list (empty); conn id: #%ld\n", src->hdr.oid);
 			return -1;
 		}
 
 		a = htip_get(&dst->aid2obj, grp->aid.array[0]);
 		if (a == NULL) {
-			rnd_msg_error("Invalid object on the conn list (NULL)\n");
+			rnd_msg_error("Invalid object on the conn list (NULL); conn id: #%ld\n", src->hdr.oid);
 			return -1;
 		}
 		switch(a->type) {
@@ -335,6 +405,7 @@ static int compile_conn(csch_abstract_t *dst, const csch_sheet_t *sheet, const c
 			rnd_msg_error("failed to create anon net for terminal-terminal connection\n");
 			return -1;
 		}
+		net->term_term = 1;
 	}
 
 	/* second pass: make the connections */
@@ -368,6 +439,7 @@ static void compile_reset_abstract(csch_abstract_t *dst)
 	dst->ucnt.wirenet = 0;
 	dst->ucnt.comp = 0;
 	dst->ucnt.port = 0;
+	dst->ucnt.target_tmp = 0;
 }
 
 static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_sheet_t *src)
@@ -375,6 +447,14 @@ static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_shee
 	int res = 0;
 	const csch_chdr_t *h;
 
+	if (src->non_graphical) {
+		if ((src->non_graphical_impl == NULL) || (src->non_graphical_impl->compile_sheet == NULL)) {
+			rnd_message(RND_MSG_ERROR, "Don't know how to compile non-graphical sheet %s\n", src->hidlib.fullpath);
+			return -1;
+		}
+		return src->non_graphical_impl->compile_sheet(dst, viewid, src);
+	}
+
 	/* reset aid */
 	for(h = gdl_first(&src->active); h != NULL; h = gdl_next(&src->active, h)) {
 		if (csch_obj_is_grp(h)) {
@@ -416,6 +496,10 @@ static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_shee
 		}
 	}
 
+
+	csch_eng_call((csch_project_t *)src->hidlib.project, viewid, CSCH_ENGHK_CONNS_BEFORE,
+		FGW_PTR, dst, FGW_INVALID);
+
 	/* compile connections between nets and components (the "netlist" part) */
 	for(h = gdl_first(&src->active); h != NULL; h = gdl_next(&src->active, h)) {
 		const csch_conn_t *conn = (const csch_conn_t *)h;
@@ -428,6 +512,9 @@ static int csch_compile_sheet_(csch_abstract_t *dst, int viewid, const csch_shee
 		res |= compile_conn(dst, src, conn);
 	}
 
+	csch_eng_call((csch_project_t *)src->hidlib.project, viewid, CSCH_ENGHK_CONNS_AFTER,
+		FGW_PTR, dst, FGW_INVALID);
+
 	return res;
 }
 
@@ -437,25 +524,71 @@ int csch_compile_sheet(csch_abstract_t *dst, int viewid, const csch_sheet_t *src
 	return csch_compile_sheet_(dst, viewid, src);
 }
 
+/* Returns whether the loop should be restarted because of new components added */
+RND_INLINE int csch_compile_post_port(csch_project_t *proj, int viewid, csch_abstract_t *dst, csch_aport_t *port)
+{
+	if (port->hdr.compiled) return 0;
+	port->hdr.compiled = 1;
+
+	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_PORT, FGW_AOBJ, port, FGW_INVALID);
+
+	return dst->new_ports;
+}
+
+
+/* Returns whether the loop should be restarted because of new components added */
+RND_INLINE int csch_compile_post_comp(csch_project_t *proj, int viewid, csch_abstract_t *dst, csch_acomp_t *comp)
+{
+	htsp_entry_t *p;
+
+	if (comp->hdr.compiled) return 0;
+	comp->hdr.compiled = 1;
+
+	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT1, FGW_AOBJ, comp, FGW_INVALID);
+
+	restart_port:;
+	dst->new_ports = 0;
+	for(p = htsp_first(&comp->ports); p != NULL; p = htsp_next(&comp->ports, p))
+		if (csch_compile_post_port(proj, viewid, dst, p->value))
+			goto restart_port; /* if new components are created restart the loop because genht gets confused */
+
+	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT2, FGW_AOBJ, comp, FGW_INVALID);
+	return dst->new_comps;
+}
+
+/* Returns whether the loop should be restarted because of new components added */
+RND_INLINE int csch_compile_post_net(csch_project_t *proj, int viewid, csch_abstract_t *dst, csch_anet_t *net)
+{
+	if (net->hdr.compiled) return 0;
+	net->hdr.compiled = 1;
+
+	csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_NET, FGW_AOBJ, net, FGW_INVALID);
+
+	return dst->new_nets;
+}
+
 int csch_compile_post(csch_project_t *proj, int viewid, csch_abstract_t *dst)
 {
-	htsp_entry_t *e, *p;
+	htsp_entry_t *e;
 	csch_sheet_t *sheet;
 
-	for(e = htsp_first(&dst->comps); e != NULL; e = htsp_next(&dst->comps, e)) {
-		csch_acomp_t *comp = e->value;
-		csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT1, FGW_AOBJ, comp, FGW_INVALID);
-		for(p = htsp_first(&comp->ports); p != NULL; p = htsp_next(&comp->ports, p))
-			csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_PORT, FGW_AOBJ, p->value, FGW_INVALID);
-		csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_COMPONENT2, FGW_AOBJ, comp, FGW_INVALID);
-	}
+	restart_comp:;
+	dst->new_comps = 0;
+	for(e = htsp_first(&dst->comps); e != NULL; e = htsp_next(&dst->comps, e))
+		if (csch_compile_post_comp(proj, viewid, dst, e->value))
+			goto restart_comp; /* if new components are created restart the loop because genht gets confused */
 
+	restart_net:;
+	dst->new_nets = 0;
 	for(e = htsp_first(&dst->nets); e != NULL; e = htsp_next(&dst->nets, e))
-		csch_eng_call(proj, viewid, CSCH_ENGHK_COMPILE_NET, FGW_AOBJ, e->value, FGW_INVALID);
-
+		if (csch_compile_post_net(proj, viewid, dst, e->value))
+			goto restart_net; /* if new components are created restart the loop because genht gets confused */
 
 	csch_text_invalidate_all_project(proj, 1);
 
+	csch_eng_call(proj, viewid, CSCH_ENGHK_PROJECT_AFTER,
+		FGW_PTR, dst, FGW_PTR, proj, FGW_INVALID);
+
 	sheet = *vtp0_get(&proj->hdr.designs, 0, 0);
 	rnd_event(&sheet->hidlib, CSCH_EVENT_PRJ_COMPILED, NULL);
 	return 0;
@@ -471,6 +604,9 @@ int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst,
 	if (csch_project_is_partial(prj))
 		rnd_message(RND_MSG_ERROR, "*** PARTIAL PROJECT ***\nNot all root sheets are loaded, the resulting abstract model\nwill be partial too.\n");
 
+	csch_eng_call(prj, viewid, CSCH_ENGHK_PROJECT_BEFORE,
+		FGW_PTR, dst, FGW_PTR, prj, FGW_INVALID);
+
 	for(n = 0; n < vtp0_len(&prj->hdr.designs); n++) {
 		csch_sheet_t *sheet = *vtp0_get(&prj->hdr.designs, n, 0);
 
