@@ -37,10 +37,27 @@ int csch_compile_post(csch_project_t *proj, int viewid, csch_abstract_t *dst);
 int csch_compile_project(csch_project_t *prj, int viewid, csch_abstract_t *dst, int quiet);
 
 
-/*** for lib itnernal use ***/
-int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_reconn);
+/*** utility for plugins ***/
 
-csch_inline void csch_compile_add_source(csch_cgrp_t *src, csch_ahdr_t *abst)
+/* Compile attribute src of cgrp into dst. If dstkey is NULL, srca's
+   key is used. src is used for history and is always freed.
+   Err1 and err2 are two strings printed in error messages
+   for location, with space in between. If referee is 1, src is a group
+   ref. If append is 1, append src array to dst array (fails if either
+   src or dst attrib is not an array). If append is 0, but src key starts
+   with '+', append is set to 1 internally. If dsta_out is not NULL,
+   destination attribute (abstract model) is returned there.
+   Returns 0 on success. */
+int csch_compile_attribute(csch_ahdr_t *dst, const char *dstkey, const csch_attrib_t *srca, csch_source_arg_t *src, const char *err1, const char *err2, int referee, int append, csch_attrib_t **dsta_out);
+
+
+/* For compiler hooks in plugins */
+int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_reconn);
+int csch_compile_disconnect(csch_ahdr_t *a);
+
+/*** for lib itnernal use ***/
+
+RND_INLINE void csch_compile_add_source(csch_cgrp_t *src, csch_ahdr_t *abst)
 {
 	vtl0_append(&src->aid, abst->aid);
 	vtp0_append(&abst->srcs, src);
