@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2018 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2018,2023 Tibor 'Igor2' Palinkas
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -34,6 +34,7 @@
 #include "event.h"
 #include "cnc_obj.h"
 #include "cnc_grp.h"
+#include "non_graphical.h"
 #include "project.h"
 #include "plug_library.h"
 
@@ -86,8 +87,10 @@ csch_sheet_t *csch_sheet_init(csch_sheet_t *sheet, csch_project_t *parent)
 	sheet->util_wirenet.recalc_inhibit = 0;
 	htpi_init(&sheet->util_wirenet.recalc_wn, ptrhash, ptrkeyeq);
 
-	for(n = 0; n < CSCH_DSPLY_max; n++)
+	for(n = 0; n < CSCH_DSPLY_max; n++) {
 		csch_rtree_init(&sheet->dsply[n]);
+		csch_rtree_init(&sheet->dsply_fill[n]);
+	}
 
 	csch_cgrp_init(sheet, &sheet->direct, NULL, CSCH_TOP_OID_DIRECT);
 	csch_cgrp_init(sheet, &sheet->indirect, NULL, CSCH_TOP_OID_INDIRECT);
@@ -110,6 +113,12 @@ void csch_sheet_uninit(csch_sheet_t *sheet)
 {
 	int n;
 
+	if (sheet->non_graphical && (sheet->non_graphical_impl != NULL) && (sheet->non_graphical_impl->free_sheet != NULL)) {
+		sheet->non_graphical_impl->free_sheet(sheet);
+		sheet->non_graphical_data = NULL;
+		sheet->non_graphical_impl = NULL;
+	}
+
 	htpi_uninit(&sheet->util_wirenet.recalc_wn);
 
 	csch_lib_free_sheet_local_libs(sheet);
@@ -121,8 +130,10 @@ void csch_sheet_uninit(csch_sheet_t *sheet)
 	csch_cgrp_uninit(&sheet->indirect);
 
 	TODO("free all objects in the hash");
-	for(n = 0; n < CSCH_DSPLY_max; n++)
+	for(n = 0; n < CSCH_DSPLY_max; n++) {
 		csch_rtree_uninit(&sheet->dsply[n]);
+		csch_rtree_uninit(&sheet->dsply_fill[n]);
+	}
 
 	genht_uninit_deep(htsp, &sheet->comm_str, {
 		free(htent->key);
@@ -151,7 +162,7 @@ void csch_sheet_free(csch_sheet_t *sheet)
 void csch_sheet_bbox_update(csch_sheet_t *sheet)
 {
 	csch_cgrp_bbox_update(sheet, &sheet->direct);
-	sheet->bbox = sheet->direct.hdr.bbox;
+	sheet->bbox = sheet->direct.bbox_flt;
 }
 
 csch_oid_t csch_oid_new(csch_sheet_t *sheet, csch_cgrp_t *grp)
