@@ -190,6 +190,7 @@ struct csch_cgrp_s { /* type=CSCH_CTYPE_GRP || CSCH_CTYPE_GRP_REF */
 	unsigned sym_prefer_loclib:1;     /* this group is a symbol that should be put in the local lib and converted to a group ref if global config permits */
 	vtl0_t aid;        /* link to the abstract objects compiled from this group; zero or one in flat design but can be more in hierarchic */
 	char *file_name;   /* hint: trace file name from which the group was loaded, if available */
+	csch_rtree_box_t bbox_flt; /* bounding box with floaters included (e.g. for sheet size) */
 };
 
 typedef enum csch_sheet_type_e {
@@ -203,7 +204,8 @@ struct csch_sheet_s {
 	rnd_design_t hidlib;
 	long uid;
 
-	csch_rtree_t dsply[CSCH_DSPLY_max];     /* IDs in screen coords, per display layer */
+	csch_rtree_t dsply[CSCH_DSPLY_max];      /* object strokes to draw per display layer */
+	csch_rtree_t dsply_fill[CSCH_DSPLY_max]; /* fills to draw per display layer */
 	csch_cgrp_t direct, indirect; /* a sheet is really made of groups to keep the code simple */
 	/* (sheet attributes are in the direct, the indirect group is for the "local library") */
 
@@ -212,6 +214,11 @@ struct csch_sheet_s {
 	csch_rtree_box_t bbox;
 	unsigned bbox_changed:1; /* set when bbox changed (bumped) by object editing; used and reset by the GUI */
 
+	unsigned non_graphical:1; /* sheet specified by data, not drawing */
+
+	void *non_graphical_data; /* filled in and used by the plugin dealing with the non-graphical format when ->non_graphical==1 */
+	csch_non_graphical_impl_t *non_graphical_impl;
+
 	/* list of all objects ever allocated for the sheet */
 	gdl_list_t active, deleted;
 
@@ -275,7 +282,7 @@ void csch_sheet_uninit(csch_sheet_t *sheet);
 
 csch_sheet_t *csch_sheet_alloc(csch_project_t *parent);
 void csch_sheet_free(csch_sheet_t *);
-csch_inline const csch_rtree_box_t *csch_sheet_bbox(csch_sheet_t *sheet);
+RND_INLINE const csch_rtree_box_t *csch_sheet_bbox(csch_sheet_t *sheet);
 void csch_sheet_bbox_update(csch_sheet_t *sheet);
 
 csch_oid_t csch_oid_new(csch_sheet_t *sheet, csch_cgrp_t *grp);
@@ -295,10 +302,10 @@ void csch_chdr_copy_meta4dup(csch_chdr_t *dst, const csch_chdr_t *src);
 char *csch_chdr_to_oidpath_str(const csch_chdr_t *chdr);
 
 /* An object is selected if it is ->selected or if any of its parents is ->selected */
-csch_inline int csch_chdr_is_selected(csch_chdr_t *obj);
+RND_INLINE int csch_chdr_is_selected(csch_chdr_t *obj);
 
 /* An object is selected if it is ->selected or if any of its parents is ->selected */
-csch_inline int csch_chdr_any_parent_selected(csch_chdr_t *obj);
+RND_INLINE int csch_chdr_any_parent_selected(csch_chdr_t *obj);
 
 /* Return common string for str; if not already allocated and alloc != 0,
    strup and insert str to common strings. If str is NULL or not found/allocated,
@@ -307,14 +314,14 @@ csch_comm_str_t csch_comm_str(csch_sheet_t *sheet, const char *str, int alloc);
 
 
 /*** implementation ***/
-csch_inline const csch_rtree_box_t *csch_sheet_bbox(csch_sheet_t *sheet)
+RND_INLINE const csch_rtree_box_t *csch_sheet_bbox(csch_sheet_t *sheet)
 {
 	if (csch_bbox_is_invalid(&sheet->bbox))
 		csch_sheet_bbox_update(sheet);
 	return &sheet->bbox;
 }
 
-csch_inline int csch_chdr_is_selected(csch_chdr_t *obj)
+RND_INLINE int csch_chdr_is_selected(csch_chdr_t *obj)
 {
 	for(;obj != NULL; obj = &obj->parent->hdr)
 		if (obj->selected)
@@ -323,20 +330,20 @@ csch_inline int csch_chdr_is_selected(csch_chdr_t *obj)
 	return 0;
 }
 
-csch_inline int csch_chdr_any_parent_selected(csch_chdr_t *obj)
+RND_INLINE int csch_chdr_any_parent_selected(csch_chdr_t *obj)
 {
 	return csch_chdr_is_selected(&obj->parent->hdr);
 }
 
 
 /* Returns 1 if obj is a group or group ref, 0 for other objects */
-csch_inline int csch_obj_is_grp(const csch_chdr_t *obj)
+RND_INLINE int csch_obj_is_grp(const csch_chdr_t *obj)
 {
 	return ((obj != NULL) && ((obj->type == CSCH_CTYPE_GRP) || (obj->type == CSCH_CTYPE_GRP_REF)));
 }
 
 /* Returns 1 if obj is deleted (not part of the active objects of the sheet) */
-csch_inline int csch_obj_is_deleted(const csch_chdr_t *obj)
+RND_INLINE int csch_obj_is_deleted(const csch_chdr_t *obj)
 {
 	return (obj->link.parent == &obj->sheet->deleted);
 }
