@@ -52,9 +52,9 @@ static void igy_brk() {}
 		} \
 	} while(0)
 
-csch_inline int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from);
+RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from);
 
-csch_inline int igy_cnc_conn(void *parent, csch_conn_t *c, const char *called_from)
+RND_INLINE int igy_cnc_conn(void *parent, csch_conn_t *c, const char *called_from)
 {
 	int res = 0, had_two_grps = 0;
 	csch_sheet_t *sheet = c->hdr.sheet;
@@ -91,7 +91,7 @@ csch_inline int igy_cnc_conn(void *parent, csch_conn_t *c, const char *called_fr
 	return res;
 }
 
-csch_inline int igy_cnc_obj(csch_cgrp_t *parent, csch_chdr_t *obj, const char *called_from)
+RND_INLINE int igy_cnc_obj(csch_cgrp_t *parent, csch_chdr_t *obj, const char *called_from)
 {
 	int res = 0;
 
@@ -127,7 +127,7 @@ csch_inline int igy_cnc_obj(csch_cgrp_t *parent, csch_chdr_t *obj, const char *c
 /* Recursive intersection search: set ->mark on any object that is in the
    same group and on the CSCH_DSPLY_WIRE layer that are reachable through
    intersections from obj */
-csch_inline void igy_wirenet_find_segs_from(csch_chdr_t *obj)
+RND_INLINE void igy_wirenet_find_segs_from(csch_chdr_t *obj)
 {
 	csch_chdr_t *pair;
 	csch_rtree_it_t it;
@@ -153,7 +153,7 @@ csch_inline void igy_wirenet_find_segs_from(csch_chdr_t *obj)
 	}
 }
 
-csch_inline int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_from)
+RND_INLINE int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_from)
 {
 	int res = 0;
 	long wnlen = htip_length(&wn->id2obj);
@@ -206,7 +206,7 @@ csch_inline int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_fr
 	return res;
 }
 
-csch_inline int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from)
+RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from)
 {
 	int res = 0;
 	htip_entry_t *e;
@@ -239,7 +239,7 @@ csch_inline int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_f
 	return res;
 }
 
-csch_inline int igy_cnc_direct(csch_cgrp_t *grp, const char *called_from)
+RND_INLINE int igy_cnc_direct(csch_cgrp_t *grp, const char *called_from)
 {
 	int res = 0;
 
@@ -252,10 +252,13 @@ csch_inline int igy_cnc_direct(csch_cgrp_t *grp, const char *called_from)
 	return res;
 }
 
-csch_inline int igy_sheet(csch_project_t *proj, csch_sheet_t *sheet, const char *called_from)
+RND_INLINE int igy_sheet(csch_project_t *proj, csch_sheet_t *sheet, const char *called_from)
 {
 	int res = 0;
 
+	if (sheet->non_graphical)
+		return 0; /* don't check them for now */
+
 	if (proj != NULL)
 		ASSERT(proj == (csch_project_t *)sheet->hidlib.project, "broken sheet parent");
 
