@@ -77,7 +77,7 @@ const csch_ops_t *csch_op_get(csch_ctype_t type)
 	return ops[type];
 }
 
-csch_inline csch_chdr_t *csch_cnc_remove_(csch_sheet_t *sheet, csch_chdr_t *obj, csch_cnc_common_remove_t how)
+RND_INLINE csch_chdr_t *csch_cnc_remove_(csch_sheet_t *sheet, csch_chdr_t *obj, csch_cnc_common_remove_t how)
 {
 	const csch_ops_t *ops = csch_op_get(obj->type);
 	csch_undo_remove_t *u, utmp;
@@ -270,6 +270,10 @@ void csch_move(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t dx, csch_coor
 			}
 			uundo_unfreeze_serial(&sheet->undo);
 			uundo_inc_serial(&sheet->undo);
+
+
+			if (undoable)
+				csch_sheet_set_changed(sheet, 1);
 		}
 	}
 }
