@@ -29,7 +29,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <genvector/vtp0.h>
 #include "cnc_grp.h"
 #include "cnc_obj.h"
 #include "cnc_any_obj.h"
@@ -41,24 +40,24 @@
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/compat_lrealpath.h>
 
-static vtp0_t ios;
+vtp0_t csch_ios;
 
 void csch_plug_io_register(const csch_plug_io_t *io)
 {
-	vtp0_append(&ios, (void *)io);
+	vtp0_append(&csch_ios, (void *)io);
 }
 
 void csch_plug_io_unregister(const csch_plug_io_t *io)
 {
 	long n;
-	for(n = 0; n < ios.used; n++)
-		if (ios.array[n] == io)
-			ios.array[n] = NULL;
+	for(n = 0; n < csch_ios.used; n++)
+		if (csch_ios.array[n] == io)
+			csch_ios.array[n] = NULL;
 }
 
 void csch_plug_io_uninit(void)
 {
-	vtp0_uninit(&ios);
+	vtp0_uninit(&csch_ios);
 }
 
 typedef struct {
@@ -95,8 +94,8 @@ static void csch_plug_io_list(vtpr_t *res, const char *fn, const char *fmt, csch
 	int n, p;
 	prio_t *pr;
 
-	for(n = 0; n < vtp0_len(&ios); n++) {
-		csch_plug_io_t *io = ios.array[n];
+	for(n = 0; n < vtp0_len(&csch_ios); n++) {
+		csch_plug_io_t *io = csch_ios.array[n];
 		if (io == NULL) continue;
 		switch(dir) {
 			case LIST_LOAD:
@@ -140,17 +139,21 @@ static int load_postproc_sheet(csch_sheet_t *sheet)
 }
 
 /* if proj is not NULL and sheet is NULL, allocate a new sheet */
-csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, const char *load_fn, const char *real_fn, const char *fmt, int is_buffer)
+csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, const char *load_fn, const char *real_fn, const char *fmt, int is_buffer, FILE *optf)
 {
 	int n;
 	vtpr_t prios;
 	FILE *f;
 
-	f = rnd_fopen(NULL, real_fn, "r");
-	if (f == NULL) {
-		TODO("error reporting");
-		return NULL;
+	if (optf == NULL) {
+		f = rnd_fopen(NULL, real_fn, "r");
+		if (f == NULL) {
+			TODO("error reporting");
+			return NULL;
+		}
 	}
+	else
+		f = optf;
 
 	vtpr_init(&prios);
 	csch_plug_io_list(&prios, real_fn, fmt, (is_buffer ? CSCH_IOTYP_BUFFER : CSCH_IOTYP_SHEET), LIST_LOAD);
@@ -184,9 +187,16 @@ csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, cons
 		if (is_buffer) {
 			load_res = pr->io->load_buffer(f, real_fn, fmt, sheet);
 		}
+		else if (pr->io->load_sheet == NULL)
+			load_res = -1;
 		else {
 			rnd_event(&sheet->hidlib, RND_EVENT_LOAD_PRE, "s", real_fn);
 			load_res = pr->io->load_sheet(f, real_fn, fmt, sheet);
+			if (load_res != 0) {
+				sheet->non_graphical = 0;
+				sheet->non_graphical_impl = NULL;
+				sheet->non_graphical_data = NULL;
+			}
 			rnd_event(&sheet->hidlib, RND_EVENT_LOAD_POST, "si", real_fn, load_res);
 		}
 		csch_cobj_redraw_unfreeze(sheet);
@@ -210,7 +220,9 @@ csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, cons
 			csch_sheet_uninit(sheet);
 	}
 	vtpr_uninit(&prios);
-	fclose(f);
+
+	if (optf == NULL)
+		fclose(f);
 
 	return sheet;
 }
@@ -220,8 +232,8 @@ int csch_test_parse_file(rnd_design_t *hl, FILE *f, const char *real_fn, csch_pl
 	long n;
 	int res = 0;
 
-	for(n = 0; n < vtp0_len(&ios); n++) {
-		csch_plug_io_t *io = ios.array[n];
+	for(n = 0; n < vtp0_len(&csch_ios); n++) {
+		csch_plug_io_t *io = csch_ios.array[n];
 
 		rewind(f);
 		if ((io->test_parse != NULL) && (io->test_parse(f, real_fn, NULL, type) == 0)) {
@@ -248,7 +260,92 @@ int csch_test_parse_fn(rnd_design_t *hl, const char *fn, csch_plug_io_type_t typ
 	return res;
 }
 
-csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *load_fn, const char *fmt, int *already_in_proj)
+void *csch_test_parse_bundled(rnd_design_t *hl, const char *real_fn, csch_plug_io_type_t type, FILE **f_out, void **io_out)
+{
+	long n;
+	int res = 0;
+	FILE *f = NULL;
+	void *cookie = NULL;
+
+	*io_out = NULL;
+
+	for(n = 0; n < vtp0_len(&csch_ios); n++) {
+		csch_plug_io_t *io = csch_ios.array[n];
+
+		if (io->test_parse_bundled == NULL)
+			continue;
+
+		if (f == NULL) {
+			f = rnd_fopen(hl, real_fn, "r");
+			if (f == NULL)
+				return NULL;
+		}
+		else
+			rewind(f);
+
+		cookie = io->test_parse_bundled(f, real_fn, NULL, type);
+		if (cookie != NULL) {
+			*io_out = io;
+			break;
+		}
+	}
+
+	*f_out = f;
+	return cookie;
+}
+
+static int load_postproc_project(csch_project_t *proj)
+{
+	return 0;
+}
+
+csch_sheet_t *csch_load_bundled_sheets(void *cookie, void *io_, FILE *f, const char *fn, void (*post_load_cb)(csch_sheet_t *))
+{
+	csch_plug_io_t *io = io_;
+	csch_project_t *prj;
+	csch_sheet_t *res = NULL;
+
+	prj = csch_project_alloc();
+	prj->hdr.loadname = rnd_strdup(fn);
+	load_postproc_project(prj);
+
+	for(;;) {
+		int r;
+		csch_sheet_t *sheet = csch_sheet_alloc(prj);
+		rnd_conf_state_t *ncs;
+
+		rnd_conf_multi_pre_new_design(&ncs);
+		rnd_conf_reset(RND_CFR_DESIGN, fn);
+		rnd_conf_merge_all(NULL); /* get the conf tree filled in - some io plugins depend on config for the load/parse */
+
+		csch_cobj_redraw_freeze(sheet);
+		r = io->load_sheet_bundled(cookie, f, fn, sheet);
+		csch_cobj_redraw_unfreeze(sheet);
+
+		if (r >= 0) {
+			rnd_project_append_design(&prj->hdr, &sheet->hidlib);
+			if (res == NULL)
+				res = sheet; /* return first sheet loaded */
+		}
+
+		rnd_conf_multi_post_new_design(&ncs, &sheet->hidlib);
+		rnd_conf_state_new_design(&sheet->hidlib);
+		rnd_conf_merge_all(NULL); /* to get the project file applied */
+
+		post_load_cb(sheet);
+		rnd_conf_state_save(sheet->hidlib.saved_rnd_conf);
+
+		if (r != 0) /* stop iteration on error or eof */
+			break;
+	}
+
+	io->end_bundled(cookie, fn);
+
+	return res;
+}
+
+
+csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *load_fn, const char *fmt, int *already_in_proj, FILE *optf)
 {
 	int n;
 	csch_sheet_t *sheet = NULL;
@@ -279,7 +376,7 @@ csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *load_fn, const c
 		}
 	}
 
-	sheet = csch_load_sheet_io(proj, sheet, load_fn, real_fn, fmt, 0);
+	sheet = csch_load_sheet_io(proj, sheet, load_fn, real_fn, fmt, 0, optf);
 	if ((sheet != NULL) && (sheet->hidlib.project != NULL) && (already_in_proj != NULL))
 		*already_in_proj = 1;
 
@@ -312,7 +409,7 @@ void csch_revert_sheet(csch_sheet_t *sheet, csch_sheet_t *(*sheet_new)(csch_shee
 	csch_sheet_uninit(sheet);
 	csch_sheet_init(sheet, proj);
 
-	sheet = csch_load_sheet_io(NULL, orig_sheet, orig_load_fn, orig_real_fn, orig_fmt, 0);
+	sheet = csch_load_sheet_io(NULL, orig_sheet, orig_load_fn, orig_real_fn, orig_fmt, 0, NULL);
 	if (sheet == NULL) {
 		sheet = sheet_new(orig_sheet);
 		newed = 1;
@@ -334,10 +431,6 @@ void csch_revert_sheet(csch_sheet_t *sheet, csch_sheet_t *(*sheet_new)(csch_shee
 }
 
 
-static int load_postproc_project(csch_project_t *proj)
-{
-	return 0;
-}
 
 csch_project_t *csch_load_project(const char *load_fn, const char *fmt, int with_sheets)
 {
@@ -597,6 +690,9 @@ csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *f
 	for(n = 0; n < vtpr_len(&prios); n++) {
 		prio_t *pr = &prios.array[n];
 
+		if (pr->io->load_grp == NULL)
+			continue;
+
 		rewind(f);
 		if ((pr->io->test_parse != NULL) && (pr->io->test_parse(f, real_fn, fmt, CSCH_IOTYP_GROUP) != 0))
 			continue;
@@ -627,7 +723,7 @@ int csch_load_buffer(csch_sheet_t *buffer, const char *load_fn, const char *fmt)
 		return -1;
 	}
 
-	rsheet = csch_load_sheet_io(NULL, buffer, load_fn, real_fn, fmt, 1);
+	rsheet = csch_load_sheet_io(NULL, buffer, load_fn, real_fn, fmt, 1, NULL);
 	free(real_fn);
 	return (rsheet == NULL) ? -1 : 0;
 }
