@@ -2,7 +2,9 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2018 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2018,2023 Tibor 'Igor2' Palinkas
+ *
+ *  (Supported by NLnet NGI0 Entrust in 2023)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -31,6 +33,7 @@
 #include <stdio.h>
 #include <libcschem/concrete.h>
 #include <libcschem/abstract.h>
+#include <genvector/vtp0.h>
 
 typedef enum csch_plug_io_type_s { /* bitfield so multiple detections (e.g. sheet-or-project) can be handled */
 	CSCH_IOTYP_PROJECT = 1,
@@ -62,6 +65,23 @@ typedef struct csch_plug_io_s {
 	int (*export_sheet)(const char *fn, const char *fmt, csch_sheet_t *dst);
 	int (*export_project_abst)(const char *fn, const char *fmt, csch_abstract_t *abs);
 
+	/* Bundled files contain multiple sheets or symbols. For sheets, they
+	   act as a project file. test_parse_bundled() is called before
+	   test_parse; if it returns non-NULL, the file is considered
+	   bundled and the _bundled() loader is called with the cookie
+	   set to the intially returned value, in an iteration. If the
+	   bundled() loader returns a positive value, the iteration stops.
+	   Negative return means error (iteration stops). Return zero when the next
+	   item was loaded succesfully. end_bundled() is called after the iteration.
+	
+	   WARNING: config is not available in test_parse_bundled(), only in
+	   load_sheet_bundled().
+	*/
+	void *(*test_parse_bundled)(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type);
+	int (*load_sheet_bundled)(void *cookie, FILE *f, const char *fn, csch_sheet_t *dst);
+	/* TODO: load_grp_bundled() */
+	void (*end_bundled)(void *cookie, const char *fn);
+
 	const char *ext_export_sheet; /* default extension for exporting sheets */
 	const char *ext_save_sheet;   /* default extension for saving sheets */
 	const char *ext_save_buffer;  /* default extension for saving buffers */
@@ -72,7 +92,10 @@ typedef struct csch_plug_io_s {
 void csch_plug_io_register(const csch_plug_io_t *io);
 void csch_plug_io_unregister(const csch_plug_io_t *io);
 
-csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *fn, const char *fmt, int *already_in_proj);
+/* Load a sheet. If optf is NULL, use fopen()/fclose() using fn. optf
+   is not closed but seeked/rewound. */
+csch_sheet_t *csch_load_sheet(csch_project_t *proj, const char *fn, const char *fmt, int *already_in_proj, FILE *optf);
+
 csch_project_t *csch_load_project(const char *fn, const char *fmt, int with_sheets);
 csch_cgrp_t *csch_load_grp(csch_sheet_t *dst, const char *load_fn, const char *fmt);
 
@@ -98,10 +121,19 @@ int csch_test_parse_fn(rnd_design_t *hl, const char *fn, csch_plug_io_type_t typ
 /* Same as csch_test_parse_fn() but takes FILE *f already open from the caller */
 int csch_test_parse_file(rnd_design_t *hl, FILE *f, const char *real_fn, csch_plug_io_type_t type);
 
-/* low level sheet loader */
-csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, const char *load_fn, const char *real_fn, const char *fmt, int is_buffer);
+/* low level sheet loader. If optf is NULL, use fopen()/fclose() using real_fn.
+    optf is not closed but seeked/rewound. */
+csch_sheet_t *csch_load_sheet_io(csch_project_t *proj, csch_sheet_t *sheet, const char *load_fn, const char *real_fn, const char *fmt, int is_buffer, FILE *optf);
+
+
+void *csch_test_parse_bundled(rnd_design_t *hl, const char *real_fn, csch_plug_io_type_t type, FILE **f_out, void **io_out);
+csch_sheet_t *csch_load_bundled_sheets(void *cookie, void *io, FILE *f, const char *prj_fn, void (*post_load_cb)(csch_sheet_t *));
 
 
 void csch_plug_io_uninit(void);
 
+/* List of all IO plugins */
+extern vtp0_t csch_ios;
+
+
 #endif
