@@ -59,7 +59,7 @@ csch_lib_t *csch_lib_alloc_append(const csch_lib_backend_t *be, csch_lib_t *pare
 	return sl;
 }
 
-csch_inline void csch_lib_uninit(csch_lib_t *sl)
+RND_INLINE void csch_lib_uninit(csch_lib_t *sl)
 {
 	long n;
 
@@ -103,7 +103,7 @@ void csch_lib_remove(csch_lib_t *l)
 
 
 
-csch_inline char *slib_find_realpath(rnd_design_t *hl, csch_lib_master_t *master, char *path, const csch_lib_backend_t **be_out)
+RND_INLINE char *slib_find_realpath(rnd_design_t *hl, csch_lib_master_t *master, char *path, const csch_lib_backend_t **be_out)
 {
 	long n;
 
@@ -131,7 +131,7 @@ int slib_sort_cmp(const void *l1_, const void *l2_)
 }
 
 /* recursively sort a lib dir */
-csch_inline void csch_lib_sort(rnd_design_t *hl, csch_lib_t *l)
+RND_INLINE void csch_lib_sort(rnd_design_t *hl, csch_lib_t *l)
 {
 	long n;
 
@@ -143,7 +143,7 @@ csch_inline void csch_lib_sort(rnd_design_t *hl, csch_lib_t *l)
 	}
 }
 
-csch_inline csch_lib_t *csch_lib_map(rnd_design_t *hl, csch_lib_master_t *master, const csch_lib_backend_t *be, char *path, char *real_path)
+RND_INLINE csch_lib_t *csch_lib_map(rnd_design_t *hl, csch_lib_master_t *master, const csch_lib_backend_t *be, char *path, char *real_path)
 {
 	csch_lib_t *res;
 
@@ -266,8 +266,10 @@ void csch_lib_free_sheet_libs(csch_sheet_t *sheet)
 	/* do not uninit vector entries because they are shared among sheets */
 	for(n = 0; n < sheet->libs.used; n++) {
 		csch_lib_root_t *libroot = sheet->libs.array[n];
-		vtp0_uninit(&libroot->roots);
-		free(libroot);
+		if (libroot != NULL) {
+			vtp0_uninit(&libroot->roots);
+			free(libroot);
+		}
 	}
 	vtp0_uninit(&sheet->libs);
 }
@@ -282,7 +284,7 @@ int csch_lib_add_local(csch_sheet_t *sheet, csch_lib_master_t *master)
 	if (sheet->local_libs.used <= master->uid)
 		vtp0_enlarge(&sheet->local_libs, master->uid);
 
-	/* need to have a local libroot for mater (library type) uid */
+	/* need to have a local libroot for master (library type) uid */
 	if (sheet->local_libs.array[master->uid] == NULL)
 		sheet->local_libs.array[master->uid] = calloc(sizeof(csch_lib_root_t), 1);
 	libroot = sheet->local_libs.array[master->uid];
