@@ -199,10 +199,10 @@ int csch_proj_update_filename(csch_project_t *prj)
 	return rnd_project_update_filename(&prj->hdr);
 }
 
-int csch_project_load_sheet(csch_project_t *prj, const char *fn, const char *fmt, csch_sheet_t **sheet_out, rnd_bool quiet)
+int csch_project_load_sheet(csch_project_t *prj, const char *fn, const char *fmt, csch_sheet_t **sheet_out, rnd_bool quiet, FILE *optf)
 {
 	int ain;
-	csch_sheet_t *sheet = csch_load_sheet(prj, fn, fmt, &ain);
+	csch_sheet_t *sheet = csch_load_sheet(prj, fn, fmt, &ain, optf);
 
 	if (sheet_out != NULL)
 		*sheet_out = sheet;
@@ -229,17 +229,19 @@ int csch_project_remove_sheet(csch_project_t *prj, csch_sheet_t *sheet)
 }
 
 
-csch_project_t *csch_load_project_by_sheet_name(const char *sheet_fn, int with_sheets)
+csch_project_t *csch_load_project_by_sheet_name(const char *sheet_fn, int with_sheets, rnd_bool quiet)
 {
 	const char *try;
 	const char *project_fn = rnd_conf_get_project_conf_name(NULL, sheet_fn, &try);
 	csch_project_t *prj = csch_load_project(project_fn, "lht", with_sheets);
 
 	if (prj == NULL) {
-		if (project_fn == NULL)
-			rnd_message(RND_MSG_INFO, "Failed to load project file for %s; assuming implicit project\n", sheet_fn);
-		else
-			rnd_message(RND_MSG_WARNING, "Failed to load project file %s; creating a dummy project in memory and assuming implicit project\n", project_fn);
+		if (!quiet) {
+			if (project_fn == NULL)
+				rnd_message(RND_MSG_INFO, "Failed to load project file for %s; assuming implicit project\n", sheet_fn);
+			else
+				rnd_message(RND_MSG_WARNING, "Failed to load project file %s; creating a dummy project in memory and assuming implicit project\n", project_fn);
+		}
 		prj = csch_project_alloc();
 	}
 	else
