@@ -72,7 +72,7 @@ void csch_project_clean_views(csch_project_t *prj);
 csch_view_t *csch_view_create(csch_project_t *prj, const char *name);
 
 /* Returns current view or NULL */
-csch_inline csch_view_t *csch_view_get_current(csch_project_t *prj);
+RND_INLINE csch_view_t *csch_view_get_current(csch_project_t *prj);
 
 /* Retuirns view by name using linear search (there'd be only a few views) */
 csch_view_t *csch_view_get(csch_project_t *prj, const char *name);
@@ -118,12 +118,12 @@ void csch_view_renum(csch_view_t *view);
 
 /*** loaders ***/
 /* does not emit sheet post load event */
-int csch_project_load_sheet(csch_project_t *prj, const char *fn, const char *fmt, csch_sheet_t **sheet_out, rnd_bool quiet);
-csch_project_t *csch_load_project_by_sheet_name(const char *sheet_load_fn, int with_sheets);
+int csch_project_load_sheet(csch_project_t *prj, const char *fn, const char *fmt, csch_sheet_t **sheet_out, rnd_bool quiet, FILE *optf);
+csch_project_t *csch_load_project_by_sheet_name(const char *sheet_load_fn, int with_sheets, rnd_bool quiet);
 
 
 /*** implementation ***/
-csch_inline csch_view_t *csch_view_get_current(csch_project_t *prj)
+RND_INLINE csch_view_t *csch_view_get_current(csch_project_t *prj)
 {
 	if ((prj->curr < 0) || (prj->curr >= prj->views.used))
 		return NULL;
