@@ -1,4 +1,4 @@
-#ifndef LIBCSCHEM_UTIL_ANST_H
+#ifndef LIBCSCHEM_UTIL_ABST_H
 #define LIBCSCHEM_UTIL_ABST_H
 
 #include <libcschem/concrete.h>
