@@ -104,29 +104,38 @@ csch_line_t *find_wire(csch_sheet_t *sheet, csch_coord_t x, csch_coord_t y, csch
 	return ctx.res;
 }
 
-csch_cgrp_t *csch_wirenet_new(csch_sheet_t *sheet)
+csch_cgrp_t *csch_wirenet_new_from(csch_sheet_t *sheet, const csch_cgrp_t *attr_src)
 {
 	csch_source_arg_t *src;
 	csch_cgrp_t *grp = (csch_cgrp_t *)csch_op_create(sheet, &sheet->direct, CSCH_CTYPE_GRP);
 
-	src = csch_attrib_src_c(NULL, 0, 0, "manual_draw_wirenet");
-
 	if (grp == NULL) {
 		rnd_message(RND_MSG_ERROR, "Internal error: failed to create direct group for wirenet\n");
 		return NULL;
 	}
 
-	csch_attrib_set(&grp->attr, 0, "role", "wire-net", src, NULL);
+	if (attr_src == NULL) {
+		src = csch_attrib_src_c(NULL, 0, 0, "manual_draw_wirenet");
+		csch_attrib_set(&grp->attr, 0, "role", "wire-net", src, NULL);
+	}
+	else
+		csch_attrib_copy_all(&grp->attr, &attr_src->attr);
+
 	csch_cgrp_attrib_update(sheet, grp, 0, "role", "wire-net");
 
 	if (sheet->util_wirenet.recalc_inhibit)
 		htpi_set(&sheet->util_wirenet.recalc_wn, grp, 1);
 
-
 	return grp;
 }
 
-csch_inline void remove_grp_if_empty(csch_sheet_t *sheet, csch_cgrp_t *grp)
+csch_cgrp_t *csch_wirenet_new(csch_sheet_t *sheet)
+{
+	return csch_wirenet_new_from(sheet, NULL);
+}
+
+
+RND_INLINE void remove_grp_if_empty(csch_sheet_t *sheet, csch_cgrp_t *grp)
 {
 	if ((grp == NULL) || (grp->id2obj.used != 0) || (csch_obj_is_deleted(&grp->hdr)))
 		return;
@@ -144,7 +153,7 @@ typedef struct {
 } wire_merge_t;
 
 /* Return unique direction; 180 degree shift doesn't make a difference */
-csch_inline long line_dir(csch_line_t *line)
+RND_INLINE long line_dir(csch_line_t *line)
 {
 	double l, dx = line->inst.c.p2.x - line->inst.c.p1.x, dy = line->inst.c.p2.y - line->inst.c.p1.y;
 	int sig, sdx, sdy;
@@ -184,7 +193,7 @@ static csch_rtree_dir_t wire_merge_cb(void *ctx_, void *obj_, const csch_rtree_b
 
 /* merges any lines that connect with "line" from within the same wirenet and
    has the same direction; line is never removed */
-csch_inline void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line)
+RND_INLINE void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *line)
 {
 	wire_merge_t ctx = {0};
 	g2d_vect_t min, max;
@@ -248,7 +257,7 @@ csch_inline void csch_wirenet_recalc_merge(csch_sheet_t *sheet, csch_line_t *lin
 		x2 = max.x; y2 = max.y;
 
 		csch_cgrp_vinverse_xform(ctx.wirenet, &x1, &y1, &x2, &y2, NULL);
-		csch_line_modify(sheet, line, &x1, &y1, &x2, &y2, 1, 0);
+		csch_line_modify(sheet, line, &x1, &y1, &x2, &y2, 1, 0, 0);
 
 		/* remove rest of the lines */
 		for(n = 0; n < ctx.lines.used; n++) {
@@ -330,7 +339,7 @@ typedef enum { /* bitfield */
    If return is 1, parent_out is loaded with wirenet group the new line should
    be part of.
 */
-int csch_wirenet_newline_merge_parent(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2, csch_cgrp_t **parent_out, merge_warn_t warn)
+int csch_wirenet_newline_merge_parent(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2, csch_cgrp_t **parent_out, merge_warn_t warn, csch_chdr_t *ignore)
 {
 	csch_line_t *w1, *w2;
 	csch_cgrp_t *parent = NULL;
@@ -339,13 +348,13 @@ int csch_wirenet_newline_merge_parent(csch_sheet_t *sheet, csch_coord_t x1, csch
 	long n;
 
 	/* pick up wires at the end of the new line */
-	w1 = find_wire(sheet, x1, y1, NULL);
-	w2 = find_wire(sheet, x2, y2, NULL);
+	w1 = find_wire(sheet, x1, y1, ignore);
+	w2 = find_wire(sheet, x2, y2, ignore);
 	if (w1 != NULL) grp_append(&adj_grp, w1->hdr.parent);
 	if (w2 != NULL) grp_append(&adj_grp, w2->hdr.parent);
 	find_wire_ends_on_line(sheet, &adj_grp, x1, y1, x2, y2, NULL);
 
-	rnd_trace("wirenet merging: found %d adjacent groups\n", adj_grp.used);
+/*	rnd_trace("wirenet merging: found %d adjacent groups\n", adj_grp.used);*/
 
 	if (adj_grp.used > 1) {
 		csch_cgrp_t *g0;
@@ -379,7 +388,7 @@ int csch_wirenet_newline_merge_parent(csch_sheet_t *sheet, csch_coord_t x1, csch
 			}
 		}
 
-		rnd_trace(" merge\n");
+/*		rnd_trace(" merge wirenets\n");*/
 		parent = g0;
 		parent->role = 0; /* disable side effects during the merge */
 		for(n = 0; n < adj_grp.used; n++) {
@@ -394,12 +403,12 @@ int csch_wirenet_newline_merge_parent(csch_sheet_t *sheet, csch_coord_t x1, csch
 		res = 1;
 	}
 	else if (adj_grp.used == 1) {
-		rnd_trace(" append\n");
+/*		rnd_trace(" append to one existing wirenet\n"); */
 		parent = adj_grp.array[0]; /* append to the existing group */
 		res = 1;
 	}
 	else {
-		rnd_trace(" new\n");
+/*		rnd_trace(" new wirenet\n"); */
 		res = 0;
 	}
 
@@ -555,7 +564,7 @@ csch_chdr_t *csch_wirenet_draw(csch_sheet_t *sheet, csch_comm_str_t stroke_name,
 		return NULL;
 	}
 
-	merge_res = csch_wirenet_newline_merge_parent(sheet, x1, y1, x2, y2, &parent, 0);
+	merge_res = csch_wirenet_newline_merge_parent(sheet, x1, y1, x2, y2, &parent, 0, NULL);
 	if (merge_res < 0) {
 		uundo_unfreeze_serial(&sheet->undo);
 		uundo_inc_serial(&sheet->undo);
@@ -565,6 +574,9 @@ csch_chdr_t *csch_wirenet_draw(csch_sheet_t *sheet, csch_comm_str_t stroke_name,
 	if (parent == NULL)
 		parent = csch_wirenet_new(sheet);
 
+	if (parent == NULL)
+		return NULL;
+
 	/* transform the coords of the new line to undo the parent group's
 	   transformations */
 		csch_cgrp_vinverse_xform(parent, &x1, &y1, NULL);
@@ -607,7 +619,7 @@ typedef struct {
 	unsigned has_segmap:1;
 } crmap_t;
 
-csch_inline void map_seg_obj(crmap_t *map, csch_chdr_t *obj)
+RND_INLINE void map_seg_obj(crmap_t *map, csch_chdr_t *obj)
 {
 	csch_line_t *l = (csch_line_t *)obj;
 
@@ -624,7 +636,7 @@ csch_inline void map_seg_obj(crmap_t *map, csch_chdr_t *obj)
 	map->seg_next++;
 }
 
-csch_inline void map_seg_cr(crmap_t *map, csch_line_t *lo, csch_line_t *lp, int segmap_lp_junction, int lp_is_junc)
+RND_INLINE void map_seg_cr(crmap_t *map, csch_line_t *lo, csch_line_t *lp, int segmap_lp_junction, int lp_is_junc)
 {
 	int id_lo, id_lp;
 
@@ -655,7 +667,7 @@ csch_inline void map_seg_cr(crmap_t *map, csch_line_t *lo, csch_line_t *lp, int
 }
 
 
-static void map_wirenet_crossings(crmap_t *map, csch_sheet_t *sheet, csch_cgrp_t *wirenet, int enable_segmap, int segmap_junctions)
+static void map_wirenet_crossings(crmap_t *map, csch_sheet_t *sheet, csch_cgrp_t *wirenet, int enable_segmap, int segmap_junctions, int map_misc)
 {
 	htip_entry_t *e;
 	htPo_key_t jk;
@@ -720,6 +732,9 @@ static void map_wirenet_crossings(crmap_t *map, csch_sheet_t *sheet, csch_cgrp_t
 				}
 			}
 		}
+		else if (map_misc)
+			htpi_set(&map->obj2seg, obj, -1);
+
 		if (enable_segmap) {
 			if (segmap_junctions || !junc) {
 				/* start a new segment for lo if it didn't cross anything */
@@ -737,6 +752,69 @@ static void map_uninit(crmap_t *map)
 		htpi_uninit(&map->obj2seg);
 }
 
+/* There may be non-line objects, typically floaters, placed around
+   the net, not participating in the connectivity; they are in
+   seg -1 after the mapping. Put each in the seg they are closest to */
+static void map_misc_to_closest(crmap_t *map)
+{
+	htpi_entry_t *e, *e2;
+	for(e = htpi_first(&map->obj2seg); e != NULL; e = htpi_next(&map->obj2seg, e)) {
+		int oseg = e->value;
+		csch_chdr_t *obj = e->key;
+		double best_score = -1, d2;
+		g2d_vect_t org;
+
+		if (oseg >= 0)
+			continue;
+
+		switch(obj->type) {
+			case CSCH_CTYPE_TEXT:
+				org.x = ((csch_text_t *)obj)->inst1.x;
+				org.y = ((csch_text_t *)obj)->inst1.y;
+				break;
+			default:
+				org.x = (obj->bbox.x1 + obj->bbox.x2)/2;
+				org.y = (obj->bbox.y1 + obj->bbox.y2)/2;
+		}
+
+		for(e2 = htpi_first(&map->obj2seg); e2 != NULL; e2 = htpi_next(&map->obj2seg, e2)) {
+			int seg = e2->value;
+			csch_line_t *cand = e2->key;
+
+			if (seg < 0) continue;
+			if (cand->hdr.type != CSCH_CTYPE_LINE) continue;
+
+			d2 = g2d_dist2_cline_pt(&cand->inst.c, org);
+
+			if ((best_score < 0) || (d2 < best_score)) {
+				best_score = d2;
+				e->value = seg;
+			}
+		}
+	}
+}
+
+/* Returns 1 if the map actually using multiple segments */
+static int map_is_multiseg(crmap_t *map)
+{
+	htpi_entry_t *e;
+	int first_seg = -1;
+
+	for(e = htpi_first(&map->obj2seg); e != NULL; e = htpi_next(&map->obj2seg, e)) {
+		int seg = e->value;
+		if (seg < 0)
+			continue;
+		if (first_seg >= 0) {
+			if (seg != first_seg)
+				return 1;
+		}
+		else
+			first_seg = seg;
+	}
+
+	return 0;
+}
+
 void csch_wirenet_recalc_junctions(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
 {
 	crmap_t map;
@@ -752,7 +830,7 @@ void csch_wirenet_recalc_junctions(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
 
 	wirenet->wirenet_recalc_lock = 1;
 
-	map_wirenet_crossings(&map, sheet, wirenet, 1, 1);
+	map_wirenet_crossings(&map, sheet, wirenet, 1, 1, 1);
 
 	if (csch_wirenet_dbg_junct) rnd_trace("^^^ junctions wirenet=#%ld:\n", wirenet->hdr.oid);
 	for(je = htPo_first(&map.jl); je != NULL; je = htPo_next(&map.jl, je)) {
@@ -791,37 +869,43 @@ void csch_wirenet_recalc_junctions(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
 	}
 
 	if (csch_wirenet_dbg_junct) rnd_trace("SegS: %d\n", map.seg_next);
-	/* if we have more than one segments, that means the wirenet broke up;
-	   create new wirenets for each segment and move objects into them */
-	if (!wirenet->wirenet_split_lock && (map.seg_next > 2)) {
-		htpi_entry_t *e;
-		csch_cgrp_t **new_seg = calloc(sizeof(csch_cgrp_t), map.seg_next);
 
-		/* seg 0 is not used by the mapper; seg 1 is the segment we keep as original; from 2 up are the new segments (allocated on request) */
-		for(e = htpi_first(&map.obj2seg); e != NULL; e = htpi_next(&map.obj2seg, e)) {
-			int seg = e->value;
-			csch_chdr_t *obj = e->key;
-			if ((seg > 1) && (!csch_obj_is_deleted(obj))) {
-				if (csch_wirenet_dbg_junct) rnd_trace(" obj move %p -> %d\n", obj, seg);
-				if (new_seg[seg] == NULL) {
-					new_seg[seg] = csch_wirenet_new(sheet);
-					new_seg[seg]->hdr.selected = wirenet->hdr.selected;
+	if (map_is_multiseg(&map)) {
+		/* pick up floaters */
+		map_misc_to_closest(&map);
+
+		/* if we have more than one segments, that means the wirenet broke up;
+		   create new wirenets for each segment and move objects into them */
+		if (!wirenet->wirenet_split_lock && (map.seg_next > 2)) {
+			htpi_entry_t *e;
+			csch_cgrp_t **new_seg = calloc(sizeof(csch_cgrp_t), map.seg_next);
+
+			/* seg 0 is not used by the mapper; seg 1 is the segment we keep as original; from 2 up are the new segments (allocated on request) */
+			for(e = htpi_first(&map.obj2seg); e != NULL; e = htpi_next(&map.obj2seg, e)) {
+				int seg = e->value;
+				csch_chdr_t *obj = e->key;
+				if ((seg > 1) && (!csch_obj_is_deleted(obj))) {
+					if (csch_wirenet_dbg_junct) rnd_trace(" obj move #%ld/%p -> %d\n", obj->oid, obj, seg);
+					if (new_seg[seg] == NULL) {
+						new_seg[seg] = csch_wirenet_new_from(sheet, wirenet);
+						new_seg[seg]->hdr.selected = wirenet->hdr.selected;
+					}
+					csch_op_move_into(sheet, new_seg[seg], obj, 0, 0);
 				}
-				csch_op_move_into(sheet, new_seg[seg], obj, 0, 0);
 			}
+			free(new_seg);
 		}
-		free(new_seg);
+
+		remove_grp_if_empty(sheet, wirenet);
 	}
 
 	map_uninit(&map);
 
-	remove_grp_if_empty(sheet, wirenet);
-
 	wirenet->wirenet_recalc_lock = 0;
 }
 
 /* Recalculate junctions of a wirenet and remove the wirenet if it became empty */
-csch_inline void wirenet_remove_or_recalc(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
+RND_INLINE void wirenet_remove_or_recalc(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
 {
 	csch_wirenet_recalc_junctions(sheet, wirenet);
 
@@ -840,21 +924,20 @@ static void csch_wirenet_newseg2wirenets(csch_sheet_t *sheet, crmap_t *map, csch
 	csch_cgrp_t **wn, *wn_;
 
 	my_seg = htpi_get(&map->obj2seg, line);
-	rnd_trace("my_seg=%d\n", my_seg);
+/*	rnd_trace("my_seg=%d\n", my_seg);*/
 	for(e = htpi_first(&map->obj2seg); e != NULL; e = htpi_next(&map->obj2seg, e)) {
 		csch_chdr_t *obj = e->key;
 		int seg = e->value;
 
-		rnd_trace(" seg: %d\n", seg);
+/*		rnd_trace(" seg: %d\n", seg);*/
 		if (!csch_obj_is_junction(&line->hdr)) { /* real wire lines should not get removed */
 			assert(!csch_obj_is_deleted(&line->hdr));
 		}
 		if (seg != my_seg) {
 			wn = (csch_cgrp_t **)vtp0_get(new_wirenets, seg, 0);
 			if ((wn == NULL) || (*wn == NULL)) {
-				wn_ = csch_wirenet_new(sheet);
+				wn_ = csch_wirenet_new_from(sheet, line->hdr.parent);
 				wn_->hdr.selected = line->hdr.parent->hdr.selected;
-				TODO("copy netname from line_wn");
 				vtp0_set(new_wirenets, seg, wn_);
 				wn = &wn_;
 			}
@@ -865,7 +948,7 @@ static void csch_wirenet_newseg2wirenets(csch_sheet_t *sheet, crmap_t *map, csch
 			if (obj->parent != 0)
 				obj->parent->wirenet_split_lock = 0;
 			(*wn)->wirenet_split_lock = 0;
-			rnd_trace("  moved %d to wn %d\n", obj->oid, (*wn)->hdr.oid);
+/*			rnd_trace("  moved %d to wn %d\n", obj->oid, (*wn)->hdr.oid);*/
 		}
 		if (!csch_obj_is_junction(&line->hdr)) { /* real wire lines should not get removed */
 			assert(!csch_obj_is_deleted(&line->hdr));
@@ -881,7 +964,10 @@ void csch_wirenet_recalc(csch_sheet_t *sheet, csch_cgrp_t *line_wn)
 	vtp0_t new_wirenets = {0};
 	long n;
 
-	map_wirenet_crossings(&map, sheet, line_wn, 1, 0);
+	map_wirenet_crossings(&map, sheet, line_wn, 1, 0, 1);
+
+	/* pick up floaters */
+	map_misc_to_closest(&map);
 
 	/* collect new wirenets; pick one line randomly for the segment that is
 	   kept in the old/existing wirenet */
@@ -924,7 +1010,10 @@ void csch_wirenet_recalc_line_chg(csch_sheet_t *sheet, csch_line_t *line)
 		return;
 	}
 
-	map_wirenet_crossings(&map, sheet, line_wn, 1, 0);
+	map_wirenet_crossings(&map, sheet, line_wn, 1, 0, 1);
+
+	/* pick up floaters */
+	map_misc_to_closest(&map);
 
 	csch_wirenet_newseg2wirenets(sheet, &map, line, &new_wirenets);
 
@@ -933,7 +1022,7 @@ void csch_wirenet_recalc_line_chg(csch_sheet_t *sheet, csch_line_t *line)
 		csch_cgrp_t *parent;
 		int merge_res;
 
-		merge_res = csch_wirenet_newline_merge_parent(sheet, line->inst.c.p1.x, line->inst.c.p1.y, line->inst.c.p2.x, line->inst.c.p2.y, &parent, MERGE_WARN_NON_FATAL);
+		merge_res = csch_wirenet_newline_merge_parent(sheet, line->inst.c.p1.x, line->inst.c.p1.y, line->inst.c.p2.x, line->inst.c.p2.y, &parent, MERGE_WARN_NON_FATAL, &line->hdr);
 		if (merge_res > 0)
 			csch_wirenet_recalc_junctions(sheet, parent);
 	}
