@@ -39,7 +39,7 @@
 
 static const char sch_construct_cookie[] = "construct plugin";
 
-csch_inline int can_convert(csch_sheet_t *sheet, csch_chdr_t *obj, unsigned int *warn, int by_selection)
+RND_INLINE int can_convert(csch_sheet_t *sheet, csch_chdr_t *obj, unsigned int *warn, int by_selection)
 {
 	if (obj->parent != &sheet->direct) {
 
