@@ -27,7 +27,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <stdarg.h>
 #include <ctype.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
@@ -36,6 +35,8 @@
 #include <libcschem/config.h>
 #include <libcschem/plug_io.h>
 
+#include <plugins/lib_netlist_exp/lib_netlist_exp.h>
+
 static csch_plug_io_t etdx_net;
 
 static int tdx_export_prio(const char *fn, const char *fmt, csch_plug_io_type_t type)
@@ -68,56 +69,6 @@ static void tdx_fprint_escape(FILE *f, const char *val)
 	}
 }
 
-static const char *get_refdes(const csch_acomp_t *comp)
-{
-	const char *refdes;
-	refdes = csch_attrib_get_str(&comp->hdr.attr, "display/name");
-	if (refdes == NULL) refdes = csch_attrib_get_str(&comp->hdr.attr, "display/refdes");
-	if (refdes == NULL) refdes = csch_attrib_get_str(&comp->hdr.attr, "name");
-	if (refdes == NULL) refdes = csch_attrib_get_str(&comp->hdr.attr, "refdes");
-/*	if (refdes == NULL) refdes = comp->name; No name means do not export */
-	return refdes;
-}
-
-static const char *get_pinnum(const csch_aport_t *port)
-{
-	const char *pinnum;
-	pinnum = csch_attrib_get_str(&port->hdr.attr, "display/name");
-	if (pinnum == NULL) pinnum = csch_attrib_get_str(&port->hdr.attr, "display/pinnum");
-	if (pinnum == NULL) pinnum = csch_attrib_get_str(&port->hdr.attr, "name");
-	if (pinnum == NULL) pinnum = csch_attrib_get_str(&port->hdr.attr, "pinnum");
-	if (pinnum == NULL) pinnum = port->name;
-	return pinnum;
-}
-
-static const char *get_netname(const csch_anet_t *net)
-{
-	const char *netname;
-	netname = csch_attrib_get_str(&net->hdr.attr, "display/name");
-	if (netname == NULL) netname = csch_attrib_get_str(&net->hdr.attr, "name");
-	if (netname == NULL) netname = net->name;
-	return netname;
-}
-
-
-const char *get_alt_attr(const csch_attribs_t *attribs, ...)
-{
-	const char *val = NULL;
-	va_list ap;
-
-	va_start(ap, attribs);
-	for(;;) {
-		const char *key = va_arg(ap, const char *);
-		if (key == NULL)
-			break;
-		val = csch_attrib_get_str(attribs, key);
-		if (val != NULL)
-			break;
-	}
-	va_end(ap);
-	return val;
-}
-
 static void export_attr(FILE *f, const char *cmd, const char *key, const char *val, const char *val2)
 {
 	if ((key == NULL) || (val == NULL))
@@ -138,18 +89,18 @@ static void tdx_export_comps(FILE *f, csch_abstract_t *abs)
 	htsp_entry_t *e, *p;
 	for(e = htsp_first(&abs->comps); e != NULL; e = htsp_next(&abs->comps, e)) {
 		csch_acomp_t *comp = e->value;
-		const char *refdes = get_refdes(comp);
+		const char *refdes = sch_nle_get_refdes(comp);
 
 		if (refdes == NULL)
 			continue;
 
-		export_attr(f, "footprint", refdes, get_alt_attr(&comp->hdr.attr, "display/footprint", "footprint", NULL), NULL);
-		export_attr(f, "value", refdes, get_alt_attr(&comp->hdr.attr, "display/value", "value", NULL), NULL);
-		export_attr(f, "device", refdes, get_alt_attr(&comp->hdr.attr, "display/device", "device", NULL), NULL);
+		export_attr(f, "footprint", refdes, sch_nle_get_alt_attr(&comp->hdr.attr, "display/footprint", "footprint", NULL), NULL);
+		export_attr(f, "value", refdes, sch_nle_get_alt_attr(&comp->hdr.attr, "display/value", "value", NULL), NULL);
+		export_attr(f, "device", refdes, sch_nle_get_alt_attr(&comp->hdr.attr, "display/device", "device", NULL), NULL);
 		for(p = htsp_first(&comp->ports); p != NULL; p = htsp_next(&comp->ports, p)) {
 			const csch_aport_t *port = p->value;
-			const char *pinnum = get_pinnum(port);
-			const char *pinname = get_alt_attr(&port->hdr.attr, "display/pinname", "name", NULL);
+			const char *pinnum = sch_nle_get_pinnum(port);
+			const char *pinname = sch_nle_get_alt_attr(&port->hdr.attr, "display/pinname", "name", NULL);
 
 			if (strpbrk(pinnum, " \t") != NULL) { /* space separated list of pinnums */
 				char *s, *next, *tmp = rnd_strdup(pinnum);
@@ -180,7 +131,7 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 
 	for(e = htsp_first(&abs->nets); e != NULL; e = htsp_next(&abs->nets, e)) {
 		csch_anet_t *net = e->value;
-		const char *netname = get_netname(net);
+		const char *netname = sch_nle_get_netname(net);
 
 		for(n = 0; n < net->conns.used; n++) {
 			csch_aport_t *port = net->conns.array[n];
@@ -191,14 +142,14 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 				continue;
 			}
 
-			pinnum = get_pinnum(port);
+			pinnum = sch_nle_get_pinnum(port);
 			if (pinnum == NULL) {
 				rnd_message(RND_MSG_ERROR, "tdx: can't determine port's pin number\n");
 				continue;
 			}
 
 			if (port->parent != NULL)
-				refdes = get_refdes(port->parent);
+				refdes = sch_nle_get_refdes(port->parent);
 			if (refdes == NULL) {
 				/* This is not an error: no refdes means: do not export (e.g. gnd) */
 /*				rnd_message(RND_MSG_ERROR, "tdx: can't determine port's parent component refdes\n");*/
