@@ -35,7 +35,8 @@
 #include <sch-rnd/buffer.h>
 #include <sch-rnd/select.h>
 
-csch_inline int cmd_auto_obj_or_buff(int cmd)
+RND_INLINE
+ int cmd_auto_obj_or_buff(int cmd)
 {
 	rnd_toolid_t buff;
 
