@@ -46,6 +46,7 @@
 
 #include <libcschem/search.h>
 #include <libcschem/event.h>
+#include <libcschem/plug_io.h>
 #include <sch-rnd/draw.h>
 #include <sch-rnd/search.h>
 #include <sch-rnd/funchash_core.h>
@@ -230,14 +231,65 @@ TODO("loadfrom action");
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Load, function = argv[1].val.str);
 
 	if (rnd_strcasecmp(function, "Sheet") == 0) {
+		int n, di, rem;
 		static const char *pat_lht[] = {"*.rs", "*.lht", NULL};
 		static const char *pat_tdx[] = {"*.tdx", NULL};
-		static const rnd_hid_fsd_filter_t flt[] = {
+		char name_tmp[32][32];
+		char ext_tmp[32][32];
+		char *pat_tmp[32][2];
+		rnd_hid_fsd_filter_t flt[32];
+		static const rnd_hid_fsd_filter_t flt1[] = {
 			{"lihata", "lihata", pat_lht},
 			{"tEDAx", "tEDAx", pat_tdx},
+		};
+		static const rnd_hid_fsd_filter_t  flt2[] = {
 			{"all",    NULL, flt_any},
 			{NULL, NULL, NULL}
 		};
+
+		di = sizeof(flt1)/sizeof(flt1[0]);
+		rem = sizeof(flt)/sizeof(flt[0]) - di - sizeof(flt2)/sizeof(flt2[0]);
+		memcpy(flt, flt1, sizeof(flt1));
+
+		for(n = 0; (n < csch_ios.used) && (rem > 0); n++) {
+			char *sep, *ext;
+			int namelen;
+			csch_plug_io_t *io = csch_ios.array[n];
+
+			if (io->load_sheet == NULL) continue;
+
+			/* generate name */
+			sep = strchr(io->name, ' ');
+			if (sep != NULL) {
+				namelen = sep - io->name;
+				if (namelen > 31)
+					namelen = 31;
+			}
+			else
+				namelen = 31;
+			strncpy(name_tmp[di], io->name, namelen);
+			(name_tmp[di])[namelen] = '\0';
+
+			if (strcmp(name_tmp[di], "lihata") == 0) continue;
+			if (strcmp(name_tmp[di], "tEDAx") == 0) continue;
+
+			/* generate pattern */
+			ext = ext_tmp[di];
+			ext[0] = '*'; ext[1] = '.';
+			strncpy(ext+2, io->ext_save_sheet, 29);
+			ext[31] = '\0';
+			(pat_tmp[di])[0] = ext;
+			(pat_tmp[di])[1] = NULL;
+
+			flt[di].name = name_tmp[di];
+			flt[di].mime = name_tmp[di];
+			flt[di].pat = (const char **)pat_tmp[di];
+
+			rem--;
+			di++;
+		}
+		memcpy(flt+di, flt2, sizeof(flt2));
+
 		name = rnd_hid_fileselect(rnd_gui, "Load sheet", "Import a sheet from file", last_layer, ".rs", flt, "sheet", RND_HID_FSD_READ, NULL);
 	}
 	else if (rnd_strcasecmp(function, "Project") == 0) {
