@@ -48,10 +48,13 @@
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/safe_fs_dir.h>
 #include <librnd/core/compat_fs.h>
+#include <librnd/core/math_helper.h>
+#include <librnd/core/rotate.h>
 #include <librnd/core/safe_fs.h>
 #include <sch-rnd/buffer.h>
 
 #include <plugins/lib_alien/read_helper.h>
+#include <plugins/lib_alien/read_postproc.h>
 
 #include "io_geda_conf.h"
 extern conf_io_geda_t io_geda_conf;
@@ -924,8 +927,23 @@ static void flush_last_comp(read_ctx_t *ctx)
 			}
 
 			if (ds->grp != NULL) {
-				csch_chdr_t *newo = csch_cobj_dup(ctx->sheet, &ctx->sheet->direct, &ds->grp->hdr, 0, 0);
-				last_comp_move_fields(ctx, (csch_cgrp_t *)newo, ctx->last_comp);
+				csch_cgrp_t *newo = (csch_cgrp_t *)csch_cobj_dup(ctx->sheet, &ctx->sheet->direct, &ds->grp->hdr, 0, 0);
+				rnd_coord_t ox, oy;
+
+				last_comp_move_fields(ctx, newo, ctx->last_comp);
+
+				ox = ds->grp->hdr.bbox.x1;
+				oy = ds->grp->hdr.bbox.y1;
+				if ((ox != 0) || (oy != 0)) {
+					if (newo->spec_rot != 0) {
+						double rad = -newo->spec_rot / RND_RAD_TO_DEG;
+						rnd_rotate(&ox, &oy, 0, 0, cos(rad), sin(rad));
+					}
+					if (newo->mirx)
+						ox = -ox;
+					newo->x -= ox;
+					newo->y -= oy;
+				}
 			}
 			else
 				error(ctx, ("Failed to load library symbol called '%s'\n", ctx->last_comp_name));
@@ -967,7 +985,7 @@ static int read_comp(read_ctx_t *ctx, csch_cgrp_t *parent)
 	ctx->last_comp->y = y;
 	ctx->last_comp->hdr.lock = !selectable;
 	ctx->last_comp_name = rnd_strdup(name);
-	ctx->last_comp_rot = angle;
+	ctx->last_comp_rot = -angle;
 	ctx->last_comp_mir = mirror;
 	ctx->last = &ctx->last_comp->hdr;
 
