@@ -1038,7 +1038,7 @@ static int parse_conf(read_ctx_t *ctx, lht_node_t *sub)
 	if ((sub == NULL) || (ctx->cfg_dest == RND_CFR_invalid))
 		return 0;
 	if (rnd_conf_insert_tree_as(ctx->cfg_dest, sub) != 0) {
-		rnd_message(RND_MSG_ERROR, "Failed to insert the config subtree '%s' found in %s\n", sub->name, ctx->sheet->hidlib.filename);
+		rnd_message(RND_MSG_ERROR, "Failed to insert the config subtree '%s' found in %s\n", sub->name, ctx->sheet->hidlib.fullpath);
 		return -1;
 	}
 	else
@@ -1133,10 +1133,10 @@ int io_lihata_load_project(FILE *f, const char *fn, const char *fmt, csch_projec
 		char *end;
 		ctx.ver = strtol(ctx.doc->root->name+18, &end, 10);
 		if (*end == '\0') {
-			free(dst->loadname);
-			dst->loadname = rnd_strdup(fn);
+			free(dst->hdr.loadname);
+			dst->hdr.loadname = rnd_strdup(fn);
 			csch_proj_update_filename(dst);
-			dst->doc = ctx.doc;
+			dst->hdr.root = ctx.doc;
 			ctx.doc = NULL;
 			res = 0;
 		}
