@@ -66,8 +66,11 @@ int pplg_init_io_tinycad(void)
 
 	tinycad.name = "tinycad schematics sheet v2 or symbol v1";
 	tinycad.load_prio = io_tinycad_load_prio;
-	tinycad.load_sheet = io_tinycad_load_sheet;
-	tinycad.test_parse = io_tinycad_test_parse;
+
+	tinycad.test_parse_bundled = io_tinycad_test_parse_bundled;
+	tinycad.load_sheet_bundled = io_tinycad_load_sheet_bundled;
+	tinycad.end_bundled = io_tinycad_end_bundled;
+
 
 	tinycad.ext_save_sheet = "dsn";
 	csch_plug_io_register(&tinycad);
