@@ -44,8 +44,10 @@
 #include <libcschem/cnc_poly.h>
 #include <libcschem/cnc_pen.h>
 #include <libcschem/operation.h>
+#include <libcschem/util_loclib.h>
 #include <libcschem/vtoid.h>
 #include <plugins/lib_alien/read_helper.h>
+#include <plugins/lib_alien/read_postproc.h>
 
 #include "io_tinycad_conf.h"
 
@@ -65,8 +67,9 @@ extern conf_io_tinycad_t io_tinycad_conf;
 typedef struct read_ctx_s {
 	const char *fn;
 	xmlDoc *doc;
-	xmlNode *root;
+	xmlNode *root, *next_sheet_nd;
 	csch_alien_read_ctx_t alien;
+	csch_cgrp_t *loclib_sym; /* 'symbol' master group in sheet->indirect */
 	csch_cgrp_t *symdef; /* symdef we are reading at the moment */
 	double symdef_dx, symdef_dy;
 	double symdef_dx_power, symdef_dy_power;
@@ -75,6 +78,7 @@ typedef struct read_ctx_s {
 	htpp_t sym2xml;  /* key: (csch_cgrp_t *); value: (xmlNode *) */
 	unsigned silent:1;
 	unsigned symdef_dxy_power_valid:1; /* whether symdef_d[xy]_power got loaded */
+	long sheetno;
 } read_ctx_t;
 
 #define PROP(node, propname) \
@@ -90,6 +94,8 @@ static int node_name_eq(xmlNode *nd, const char *expected)
 #define PINATTR_POWER    "io_tinycad_power"
 #define SYMATTR_DX_POWER "io_tinycad_dx_power"
 #define SYMATTR_DY_POWER "io_tinycad_dy_power"
+#define SYMATTR_SYM_DXBB "io_tinycad_dx_bbox"
+#define SYMATTR_SYM_DYBB "io_tinycad_dy_bbox"
 
 static int parse_coords(read_ctx_t *ctx, xmlNode *nd, const char *str, double *x, double *y)
 {
@@ -202,6 +208,10 @@ static int dir2dxy(read_ctx_t *ctx, xmlNode *root, int dir, double *dx, double *
 	return 0;
 }
 
+/* Calculate sym placement; dx and dy are multiplier (0 or +-1) for moving
+   by (non-floater) bbox w and h; swbb is set to 1 if bbox w and h need to
+   be swapped (if used before rot+mir applied, which is not the case, so
+   it is safe to ignore swbb). */
 static void rot2sym(read_ctx_t *ctx, xmlNode *nd, int rotin, double *rot_out, int *mirx, int *miry, int *dx, int *dy, int *swbb)
 {
 	switch(rotin) {
@@ -209,6 +219,7 @@ static void rot2sym(read_ctx_t *ctx, xmlNode *nd, int rotin, double *rot_out, in
 		case 1: *mirx = 0; *miry = 1; *rot_out = 0;   *dx = 0;  *dy = 1; *swbb=0; return;
 		case 2: *mirx = 0; *miry = 1; *rot_out = 90;  *dx = 0;  *dy = 0; *swbb=0; return;
 		case 3: *mirx = 0; *miry = 0; *rot_out = -90; *dx = -1; *dy = 0; *swbb=1; return;
+
 		case 4: *mirx = 1; *miry = 0; *rot_out = 0;   *dx = -1; *dy = 0; *swbb=0; return;
 		case 5: *mirx = 1; *miry = 1; *rot_out = 0;   *dx = -1; *dy = 1; *swbb=0; return;
 		case 6: *mirx = 1; *miry = 1; *rot_out = -90; *dx = 0;  *dy = 1; *swbb=1; return;
@@ -277,7 +288,7 @@ static int parse_pen_style2sheet_decor(read_ctx_t *ctx, xmlNode *root, char penn
 
 static int parse_name(read_ctx_t *ctx, void *dst, xmlNode *root)
 {
-	/* Nothing to do with this: this is the tab name in tinycad, TYC#6 */
+	ctx->alien.sheet->hidlib.loadname = rnd_strdup(parse_text(ctx, root, 0));
 	return 0;
 }
 
@@ -418,26 +429,24 @@ static int parse_symdef_pin(read_ctx_t *ctx, void *dst, xmlNode *root)
 	const char *spos = PROP(root, "pos"), *sdir = PROP(root, "direction");
 	const char *slen = PROP(root, "length"), *snum = PROP(root, "number");
 	const char *sshow = PROP(root, "show"), *swhich = PROP(root, "which");
-	const char *part = PROP(root, "part");
-	long dir, llen, num, which, show;
-	double ox, oy, Dx = 0, Dy = 0, dx = 0, dy = 0, shorten = 0, len;
+	const char *part = PROP(root, "part"), *selec = PROP(root, "elec");
+	long dir, llen, num, which, show, elec;
+	double ox, oy, Dx = 0, Dy = 0, dx = 0, tdx = 0, dy = 0, shorten = 0, len;
 	csch_cgrp_t *pin;
 	csch_source_arg_t *src;
 	const char *pinlab = NULL;
-	int fonth = 3000, in_slot0 = 1;
+	int fonth = 3000;
 
 	if (parse_coords(ctx, root, spos, &ox, &oy) != 0)   return -1;
 	if (parse_long(ctx, root, sdir, &dir, 1) != 0)      return -1;
 	if (parse_long(ctx, root, slen, &llen, 1) != 0)     return -1;
 	if (parse_long(ctx, root, snum, &num, 1) != 0)      return -1;
 	if (parse_long(ctx, root, swhich, &which, 1) != 0)  return -1;
+	if (parse_long(ctx, root, selec, &elec, 1) != 0)    return -1;
 	if (parse_long(ctx, root, sshow, &show, 1) != 0)    return -1;
 	pinlab = parse_text(ctx, root, 0);
 
-	if ((part != NULL) && (part[0] != '0'))
-		in_slot0 = 0;
-
-	if (which != 5)
+	if (which != 6)
 		len = (double)llen/5.0;
 	else
 		len = 0;
@@ -465,11 +474,14 @@ static int parse_symdef_pin(read_ctx_t *ctx, void *dst, xmlNode *root)
 		csch_alien_mkline(&ctx->alien, pin, ox+Dx + dy*+1, +oy+Dy + dx*+1,    ox+Dx + dy*-1, +oy+Dy + dx*-1, "term-decor");
 		csch_alien_mkline(&ctx->alien, pin, ox+Dx + dy*+1, +oy+Dy + dx*+1,    ox+Dx + dx*+2, +oy+Dy + dy*+2, "term-decor");
 		csch_alien_mkline(&ctx->alien, pin, ox+Dx + dy*-1, +oy+Dy + dx*-1,    ox+Dx + dx*+2, +oy+Dy + dy*+2, "term-decor");
+		tdx = 2;
 	}
-	if (which == 6) { /* X mark on the outer end */
+	if ((which == 6) || (elec == 6)) { /* X mark on the outer end */
 		csch_alien_mkline(&ctx->alien, pin, ox + dy*+1 + dx, +oy + dx*+1 + dy,    ox + dy*-1 - dx, +oy + dx*-1 - dy, "term-decor");
 		csch_alien_mkline(&ctx->alien, pin, ox + dy*+1 - dx, +oy + dx*+1 + dy,    ox + dy*-1 + dx, +oy + dx*-1 - dy, "term-decor");
 	}
+	if (which == 6)
+		tdx = dx * (double)llen/5.0 + 2;
 
 
 	/* validate and remember slotting info */
@@ -490,7 +502,7 @@ static int parse_symdef_pin(read_ctx_t *ctx, void *dst, xmlNode *root)
 	/* show is a bitfield */
 	if (show & 0x01) { /* show pin name (inside the box) */
 		if (pinlab != NULL) {
-			csch_text_t *text = (csch_text_t *)csch_alien_mktext(&ctx->alien, pin, ox+Dx, oy+Dy, "sym-decor");
+			csch_text_t *text = (csch_text_t *)csch_alien_mktext(&ctx->alien, pin, ox+Dx+tdx, oy+Dy, "sym-decor");
 			text->text = rnd_strdup(pinlab);
 			switch(dir) {
 				case 0: text->spec1.x += fonth/2; text->spec1.y += fonth/6; text->spec_rot = 90; break; /* sticking out downward */
@@ -677,9 +689,8 @@ static int parse_ellipse(read_ctx_t *ctx, void *dst, xmlNode *root, const char *
 {
 	const char *sa = PROP(root, "a"), *sb = PROP(root, "b");
 	const char *sfill = PROP(root, "fill");
-	double ax, ay, bx, by, cx, cy, a, d, lx, ly, x, y, rx, ry;
+	double ax, ay, bx, by, cx, cy, rx, ry;
 	csch_cgrp_t *grp = dst;
-	csch_chdr_t *poly;
 	long fill;
 
 	if (parse_long(ctx, root, sfill, &fill, 1) != 0)   return -1;
@@ -695,21 +706,39 @@ static int parse_ellipse(read_ctx_t *ctx, void *dst, xmlNode *root, const char *
 	ry = fabs(ay - by) / 2;
 	cx = (ax+bx)/2;
 	cy = (ay+by)/2;
-	d = 1.0/((rx+ry)/2.0);
-	if (d > 0.2)
-		d = 0.2;
 
-	poly = csch_alien_mkpoly(&ctx->alien, ctx->symdef == NULL ? grp : ctx->symdef, penname, (fill ? penname : NULL));
+	csch_alien_mkearc(&ctx->alien, ctx->symdef == NULL ? grp : ctx->symdef,
+		cx, cy, rx, ry, 0, 8, penname, (fill ? penname : NULL));
 
-	for(a = 0; a < 2*M_PI; a += d) {
-		x = cx + cos(a) * rx;
-		y = cy + sin(a) * ry;
-		if (a > 0)
-			csch_alien_append_poly_line(&ctx->alien, poly, lx, ly, x, y);
-		lx = x;
-		ly = y;
+	return 0;
+}
+
+static int parse_sheet_noconnect(read_ctx_t *ctx, void *dst, xmlNode *root)
+{
+	csch_sheet_t *sheet = dst;
+	const char *pos = PROP(root, "pos");
+	double x, y;
+	csch_cgrp_t *sym;
+	csch_alien_read_ctx_t a0 = {0};
+
+	a0.sheet = ctx->alien.sheet;
+	a0.fmt_prefix = ctx->alien.fmt_prefix;
+	a0.coord_factor = ctx->alien.coord_factor;
+
+	if (parse_coords(ctx, root, pos, &x, &y) != 0)    return -1;
+
+	sym = csch_cgrp_alloc(dst, &sheet->direct, csch_oid_new(dst, &sheet->direct));
+	if (sym == NULL) {
+		error(root, ("Failed to allocate symbol for noconnect\n"));
+		return -1;
 	}
 
+	sym->x = csch_alien_coord_x(&ctx->alien, x);
+	sym->y = csch_alien_coord_y(&ctx->alien, y);
+
+	csch_alien_mkline(&a0, sym, -1, -1, +1, +1, "sheet-decor");
+	csch_alien_mkline(&a0, sym, +1, -1, -1, +1, "sheet-decor");
+
 	return 0;
 }
 
@@ -778,10 +807,21 @@ static int parse_symdef(read_ctx_t *ctx, void *dst, xmlNode *root)
 		return -1;
 	}
 
+	/* make sure symbol loclib is available - need to create all symdefs there */
+	if (ctx->loclib_sym == NULL) {
+		int alloced;
+		src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
+		ctx->loclib_sym = csch_loclib_get_root_by_name(sheet, "symbol", src, 1, &alloced);
+		if (ctx->loclib_sym == NULL) {
+			error(root, ("Failed to allocate symbol local lib (root)\n"));
+			return -1;
+		}
+	}
+
 	ctx->symdef_dxy_power_valid = 0;
-	ctx->symdef = csch_cgrp_alloc(dst, &sheet->indirect, oid);
+	ctx->symdef = csch_cgrp_alloc(dst, ctx->loclib_sym, oid);
 	if (ctx->symdef == NULL) {
-		error(root, ("Failed to allocate symdef in local lib\n"));
+		error(root, ("Failed to allocate symdef in local lib (symdef)\n"));
 		return -1;
 	}
 
@@ -882,8 +922,6 @@ static int parse_sym_field(read_ctx_t *ctx, void *dst, xmlNode *root)
 		ox = csch_alien_coord(&ctx->alien, ox - ctx->symdef_attr_dx);
 		oy = csch_alien_coord(&ctx->alien, oy - ctx->symdef_attr_dy);
 
-		TODO("sym_power[23].dsn ^^^");
-
 		csch_vtoid_append(&xf->path.vt, text->hdr.oid);
 
 		switch(ctx->parent_rot) {
@@ -911,7 +949,7 @@ static int parse_sym(read_ctx_t *ctx, void *dst, xmlNode *root)
 	const char *sscx = PROP(root, "scale_x"), *sscy = PROP(root, "scale_y");
 	const char *srot = PROP(root, "rotate");
 	const char *sshow_power = PROP(root, "show_power");
-	csch_cgrp_t *symdef, *sym;
+	csch_cgrp_t *symdef = NULL, *sym;
 	csch_coord_t bbw, bbh;
 	double ox, oy, scx, scy;
 	long id, rot;
@@ -941,7 +979,8 @@ static int parse_sym(read_ctx_t *ctx, void *dst, xmlNode *root)
 		return -1;
 	}
 
-	symdef = htip_get(&sheet->indirect.id2obj, id);
+	if (ctx->loclib_sym != NULL)
+		symdef = htip_get(&ctx->loclib_sym->id2obj, id);
 	if (symdef == NULL) {
 		error(root, ("Can not find symbol def id %ld\n", id));
 		return -1;
@@ -979,24 +1018,9 @@ static int parse_sym(read_ctx_t *ctx, void *dst, xmlNode *root)
 			if (my) py = -py;
 			ctx->symdef_attr_dx = px;
 			ctx->symdef_attr_dy = py;
-			rnd_trace("NKD#1 px %f %f | ox %f %f bb=%d %d (%d)\n", px, py, ox, oy, bbw, bbh, swbb);
+/*			rnd_trace("NKD#1 px %f %f | ox %f %f bb=%d %d (%d) bbflt=%d %d\n", px, py, ox, oy, bbw, bbh, swbb, bbw, bbh, symdef->bbox_flt.x2 - symdef->bbox_flt.x1, symdef->bbox_flt.y2 - symdef->bbox_flt.y1);*/
 			ox += px;
 			oy += py;
-			if (mx) {
-				/* compensate for the error of mirror being done with non-naked bbox */
-				ox += (double)bbw / 1000.0; /* add non-naked bbox */
-				ox -= 20; /* sub naked bbox; so at the end we added back only the error */
-				TODO("NKD#1: calculate naked bbox in the lib");
-			}
-			if (my) {
-				TODO("NKD#2: probably the same need to be done for y mirror");
-			}
-			rnd_trace("NKD#2 px %f %f | ox %f %f | mx %d %d rot=%f spx=%s %s\n", px, py, ox, oy, mx, my, sym->spec_rot, spx, spy);
-			TODO("NKD#3: this mechanism of correcting for mirror shall not depend on show_power=1, see sym_power3.dsn");
-			TODO("NKD#3: this mechanism should be moved to lib_alien maybe");
-
-			TODO("sym_power[23].dsn ^^^");
-
 		}
 	}
 
@@ -1004,10 +1028,29 @@ static int parse_sym(read_ctx_t *ctx, void *dst, xmlNode *root)
 	sym->miry = my;
 	sym->data.ref.grp = symdef;
 
-	rnd_trace("symdef bbox: %d*%ld %d*%ld\n", dx, bbw, dy, bbh);
+/*	rnd_trace("symdef bbox NKD#2: %d*%ld %d*%ld\n", dx, bbw, dy, bbh);*/
+	sym->x = csch_alien_coord_x(&ctx->alien, ox) /*+ dx * bbw*/;
+	sym->y = csch_alien_coord_y(&ctx->alien, oy) /*+ dy * bbh*/;
 
-	sym->x = csch_alien_coord_x(&ctx->alien, ox) + dx * bbw;
-	sym->y = csch_alien_coord_y(&ctx->alien, oy) + dy * bbh;
+	/* save dx and dy here and postpone the actual translation, because
+	   the final bounding box depends on what pins are shown which is
+	   figured only in postprocessing; do sym->x += dx*bbw and sym-yx += dy*bbw there */
+	{
+		csch_source_arg_t *src;
+		char tmp[32];
+
+		if (dx != 0) {
+			sprintf(tmp, "%d", dx);
+			src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
+			csch_attrib_set(&sym->attr, CSCH_ATP_USER_DEFAULT, SYMATTR_SYM_DXBB, tmp, src, NULL);
+		}
+
+		if (dy != 0) {
+			sprintf(tmp, "%d", dy);
+			src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
+			csch_attrib_set(&sym->attr, CSCH_ATP_USER_DEFAULT, SYMATTR_SYM_DYBB, tmp, src, NULL);
+		}
+	}
 
 	/* do not ref-embed here, let postprocessor do that */
 
@@ -1058,7 +1101,6 @@ static void create_net_label(read_ctx_t *ctx, csch_line_t *wire, xmlNode *root,
 	csch_text_t *text;
 	csch_source_arg_t *src;
 	csch_cgrp_t *parent;
-	csch_line_t *line;
 	const char *templ;
 	long tw, th, thy;
 	double w, h, step;
@@ -1279,6 +1321,7 @@ static csch_cgrp_t *power_sym(read_ctx_t *ctx, void *dst, xmlNode *root, const c
 	}
 	src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
 	csch_attrib_set(&sym->attr, CSCH_ATP_USER_DEFAULT, "role", "symbol", src, NULL);
+	csch_attr_side_effects(sym, "role");
 	src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
 	csch_attrib_set(&sym->attr, CSCH_ATP_USER_DEFAULT, "rail", netname, src, NULL);
 	src = csch_attrib_src_c(ctx->fn, root->line, 0, NULL);
@@ -1308,6 +1351,9 @@ static int parse_power(read_ctx_t *ctx, void *dst, xmlNode *root)
 	if (parse_long(ctx, root, swhich, &which, 1) != 0)  return -1;
 	if (parse_long(ctx, root, sdir, &dir, 1) != 0)      return -1;
 
+	if (netname == NULL)
+		netname = "unknown";
+
 	sym = power_sym(ctx, dst, root, netname);
 	if (sym == NULL)
 		return -1;
@@ -1504,6 +1550,35 @@ static int sym_pin_vis(read_ctx_t *ctx, csch_cgrp_t *sym)
 	return 0;
 }
 
+static void postproc_sym_placement(read_ctx_t *ctx, csch_cgrp_t *sym)
+{
+	int dx = 0, dy = 0;
+	csch_coord_t bbw, bbh;
+	const char *tmp;
+	csch_rtree_box_t bb;
+
+	tmp = csch_attrib_get_str(&sym->attr, SYMATTR_SYM_DXBB);
+	if (tmp != NULL) dx = strtol(tmp, NULL, 10); /* always valid (code generated) */
+	tmp = csch_attrib_get_str(&sym->attr, SYMATTR_SYM_DYBB);
+	if (tmp != NULL) dy = strtol(tmp, NULL, 10); /* always valid (code generated) */
+
+	if ((dx == 0) && (dy == 0))
+		return;
+
+	/* get all objects rendered for and centerline bbox calculated */
+	csch_cgrp_ref_render(ctx->alien.sheet, sym);
+	csch_alien_centerline_bbox(&ctx->alien, &sym->hdr, &bb);
+	bbw = bb.x2 - bb.x1;
+	bbh = bb.y2 - bb.y1;
+/*	if (swbb) rnd_swap(csch_coord_t, bbw, bbh);*/
+
+/*	rnd_trace("NKD#5: d=%d;%d bb=%d;%d sw=%d\n", dx, dy, (int)bbw, (int)bbh, swbb);*/
+
+
+	sym->x += dx * bbw;
+	sym->y += dy * bbh;
+}
+
 static int postproc_slot(read_ctx_t *ctx, csch_cgrp_t *grp)
 {
 	htip_entry_t *e;
@@ -1522,6 +1597,10 @@ static int postproc_slot(read_ctx_t *ctx, csch_cgrp_t *grp)
 				return -1;
 		}
 	}
+
+	if (grp->hdr.type == CSCH_CTYPE_GRP_REF)
+		postproc_sym_placement(ctx, grp);
+
 	return 0;
 }
 
@@ -1545,6 +1624,7 @@ static int parse_sheet(read_ctx_t *ctx, void *dst, xmlNode *root)
 		{"POLYGON", parse_sheet_polygon},
 		{"RECTANGLE", parse_sheet_rectangle},
 		{"ELLIPSE", parse_sheet_ellipse},
+		{"NOCONNECT", parse_sheet_noconnect},
 		{NULL, NULL}
 	};
 	static const parser_t parsers2[] = {
@@ -1557,66 +1637,36 @@ static int parse_sheet(read_ctx_t *ctx, void *dst, xmlNode *root)
 	if (res == 0)
 		postproc_slot(ctx, &ctx->alien.sheet->direct);
 
+	/* clear cache so the next sheet doesn't inherit current sheet's */
+	ctx->loclib_sym = NULL;
+
 	return res;
 }
 
 /*** file level parsing and entry points ***/
-int io_tinycad_load_sheet(FILE *f, const char *fn, const char *fmt, csch_sheet_t *dst)
+static int io_tinycad_load_sheet(read_ctx_t *ctx, xmlNode *sheet_node, const char *fn, csch_sheet_t *dst)
 {
-	int res = -1;
-	read_ctx_t ctx = {0};
-	xmlNode *n;
-
-	ctx.alien.sheet = dst;
-	ctx.alien.fmt_prefix = "io_tinycad";
-	ctx.alien.coord_factor = io_tinycad_conf.plugins.io_tinycad.coord_mult;
-	ctx.alien.flip_y = 1;
-	ctx.fn = fn;
-	ctx.doc = xmlReadFile(fn, NULL, 0);
-
-	if (ctx.doc == NULL) {
-		rnd_message(RND_MSG_ERROR, "xml parsing error on file %s\n", fn);
-		return -1;
-	}
-
-	ctx.root = xmlDocGetRootElement(ctx.doc);
-	if (xmlStrcmp(ctx.root->name, (xmlChar *)"TinyCADSheets") != 0) {
-		rnd_message(RND_MSG_ERROR, "xml error: root is not <TinyCADSheets>\n");
-		xmlFreeDoc(ctx.doc);
-		return -1;
-	}
-
-	htpp_init(&ctx.sym2xml, ptrhash, ptrkeyeq);
-	csch_alien_sheet_setup(&ctx.alien, 1);
-
-	for(n = ctx.root->children; n != NULL; n = n->next) {
-		if (xmlStrcmp(n->name, (const unsigned char *)"TinyCAD") == 0) {
-			res = parse_sheet(&ctx, dst, n);
-			TODO("We are really reading a project");
-			break;
-		}
-	}
+	int res;
 
+	res = parse_sheet(ctx, dst, sheet_node);
 	if (res == 0) {
 		csch_cgrp_render_all(dst, &dst->direct);
-		res = csch_alien_postproc_sheet(&ctx.alien);
+		res = csch_alien_postproc_sheet(&ctx->alien);
 
 		csch_cgrp_update(dst, &dst->direct, 1);
+		csch_alien_update_conns(&ctx->alien);
 
 		if (io_tinycad_conf.plugins.io_tinycad.emulate_text_ang_180)
-			csch_alien_postproc_text_autorot(&ctx.alien, &dst->direct, 1, 1);
+			csch_alien_postproc_text_autorot(&ctx->alien, &dst->direct, 1, 1);
 
 		if ((res == 0) && io_tinycad_conf.plugins.io_tinycad.auto_normalize)
-			csch_alien_postproc_normalize(&ctx.alien);
+			csch_alien_postproc_normalize(&ctx->alien);
 	}
 
-
-	htpp_uninit(&ctx.sym2xml);
-	xmlFreeDoc(ctx.doc);
 	return res;
 }
 
-int io_tinycad_test_parse(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type)
+static int io_tinycad_test_parse(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type)
 {
 	char line[512], *s;
 	int n;
@@ -1637,3 +1687,79 @@ int io_tinycad_test_parse(FILE *f, const char *fn, const char *fmt, csch_plug_io
 	}
 	return -1;
 }
+
+/* Start from next_sheet_nd; if it's a sheet, return; else keep stepping on
+   ->next until it's a sheet or NULL */
+static void io_tinycad_seek_next(read_ctx_t *ctx)
+{
+	for(;ctx->next_sheet_nd != NULL; ctx->next_sheet_nd = ctx->next_sheet_nd->next) {
+		if (xmlStrcmp(ctx->next_sheet_nd->name, (const unsigned char *)"TinyCAD") == 0)
+			return;
+	}
+}
+
+void *io_tinycad_test_parse_bundled(FILE *f, const char *fn, const char *fmt, csch_plug_io_type_t type)
+{
+	if (io_tinycad_test_parse(f, fn, fmt, type) == 0) {
+		read_ctx_t *ctx = calloc(sizeof(read_ctx_t), 1);
+
+		ctx->alien.fmt_prefix = "io_tinycad";
+		ctx->alien.flip_y = 1;
+		ctx->fn = fn;
+		ctx->doc = xmlReadFile(fn, NULL, 0);
+
+		if (ctx->doc == NULL) {
+			rnd_message(RND_MSG_ERROR, "io_tinycad: xml parsing error on file %s\n", fn);
+			free(ctx);
+			return NULL;
+		}
+
+		ctx->root = xmlDocGetRootElement(ctx->doc);
+		if (xmlStrcmp(ctx->root->name, (xmlChar *)"TinyCADSheets") != 0) {
+			rnd_message(RND_MSG_ERROR, "io_tinycad: xml error: root is not <TinyCADSheets>\n");
+			xmlFreeDoc(ctx->doc);
+			free(ctx);
+			return NULL;
+		}
+
+		ctx->next_sheet_nd = ctx->root->children;
+		io_tinycad_seek_next(ctx);
+		if (ctx->next_sheet_nd == NULL) {
+			rnd_message(RND_MSG_ERROR, "io_tinycad: xml error: no sheets under <TinyCADSheets>\n");
+			xmlFreeDoc(ctx->doc);
+			free(ctx);
+			return NULL;
+		}
+
+		htpp_init(&ctx->sym2xml, ptrhash, ptrkeyeq);
+		return ctx;
+	}
+	return NULL;
+}
+
+int io_tinycad_load_sheet_bundled(void *cookie, FILE *f, const char *fn, csch_sheet_t *dst)
+{
+	read_ctx_t *ctx = cookie;
+
+	ctx->alien.sheet = dst;
+	ctx->alien.coord_factor = io_tinycad_conf.plugins.io_tinycad.coord_mult;
+	csch_alien_sheet_setup(&ctx->alien, 1);
+	if (io_tinycad_load_sheet(ctx, ctx->next_sheet_nd, fn, dst) != 0)
+		return -1;
+	ctx->alien.sheet->hidlib.fullpath = rnd_strdup_printf("%s_%ld.rs", fn, ++ctx->sheetno);
+	ctx->alien.sheet = NULL;
+
+	/* return 1 on no more sheet */
+	ctx->next_sheet_nd = ctx->next_sheet_nd->next;
+	io_tinycad_seek_next(ctx);
+	return (ctx->next_sheet_nd == NULL) ? 1 : 0;
+}
+
+void io_tinycad_end_bundled(void *cookie, const char *fn)
+{
+	read_ctx_t *ctx = cookie;
+
+	htpp_uninit(&ctx->sym2xml);
+	xmlFreeDoc(ctx->doc);
+	free(ctx);
+}
