@@ -35,6 +35,7 @@
 #include <libcschem/cnc_text.h>
 #include <libcschem/cnc_poly.h>
 #include <libcschem/cnc_any_obj.h>
+#include <libcschem/cnc_conn.h>
 #include <libcschem/operation.h>
 #include <libcschem/project.h>
 
@@ -116,7 +117,7 @@ csch_chdr_t *csch_alien_mkline(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent,
 	return &line->hdr;
 }
 
-csch_inline void poly_line(csch_cpoly_t *poly, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2)
+RND_INLINE void poly_line(csch_cpoly_t *poly, csch_coord_t x1, csch_coord_t y1, csch_coord_t x2, csch_coord_t y2)
 {
 	csch_coutline_t *dst = csch_vtcoutline_alloc_append(&poly->outline, 1);
 	csch_line_t *line = &dst->line;
@@ -269,15 +270,65 @@ csch_chdr_t *csch_alien_mkarc(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, d
 	return &arc->hdr;
 }
 
+
+csch_chdr_t *csch_alien_mkearc(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, double cx, double cy, double rx, double ry, double sa, double da, const char *stroke, const char *fill)
+{
+	csch_chdr_t *poly = csch_alien_mkpoly(ctx, parent, stroke, fill);
+	double a, ea = sa+da, d, tmp, lx, ly, x, y;
+	int first = 1;
+
+	d = 1.0/((rx+ry)/2.0);
+	if (d > 0.2)
+		d = 0.2;
+
+	if ((da > 2*M_PI) || (da < -2*M_PI)) {
+		ea = 2*M_PI;
+		sa = 0;
+	}
+
+	/* swap if necessary, so iteration is always positive */
+	if (da < 0) {
+		tmp = sa;
+		sa = ea;
+		ea = tmp;
+		da = -da;
+	}
+
+	/* degenerate case: need at least two points so we don't end up with an empty poly */
+	if (d > da/2.0)
+		d = da/2.0;
+
+	for(a = sa; a < ea; a += d) {
+		x = cx + cos(a) * rx;
+		y = cy + sin(a) * ry;
+		if (!first)
+			csch_alien_append_poly_line(ctx, poly, lx, ly, x, y);
+		lx = x;
+		ly = y;
+		first = 0;
+	}
+
+	/* close */
+	if (!first) {
+		x = cx + cos(ea) * rx;
+		y = cy + sin(ea) * ry;
+		if ((x != lx) || (y != ly))
+			csch_alien_append_poly_line(ctx, poly, lx, ly, x, y);
+	}
+
+	return poly;
+}
+
+
 void csch_alien_append_poly_arc(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly_, double cx, double cy, double r, double sa, double da)
 {
 	csch_cpoly_t *poly = (csch_cpoly_t *)poly_;
 	csch_coutline_t *dst = csch_vtcoutline_alloc_append(&poly->outline, 1);
 	dst->hdr = poly->hdr;
 	dst->hdr.type = CSCH_CTYPE_ARC;
-	dst->arc.spec.c.x = rnd_round(cx);
-	dst->arc.spec.c.y = rnd_round(cy);
-	dst->arc.spec.r = rnd_round(r);
+	dst->arc.spec.c.x = rnd_round(CRDX(cx));
+	dst->arc.spec.c.y = rnd_round(CRDY(cy));
+	dst->arc.spec.r = rnd_round(CRD(r));
 	dst->arc.spec.start = sa / RND_RAD_TO_DEG;
 	dst->arc.spec.delta = da / RND_RAD_TO_DEG;
 }
@@ -372,177 +423,70 @@ csch_cgrp_t *csch_alien_attr_grp(csch_alien_read_ctx_t *ctx, csch_chdr_t **obj)
 	return csch_alien_convert_to_grp(ctx, obj);
 }
 
-/* Execute the generic, per format, user provideed postprocessor action, e.g.
-   io_geda_postporc_sheet_load, if it is defined. Returns 0 on success. */
-static int alien_postproc_sheet_act(csch_alien_read_ctx_t *ctx)
-{
-	fgw_func_t *af;
-	char *aname = rnd_concat(ctx->fmt_prefix, "_postproc_sheet_load", NULL);
-	int res = 0;
-
-	rnd_find_action(aname, &af);
-	if (af != NULL)
-		res = rnd_action(&ctx->sheet->hidlib, aname);
-
-	free(aname);
-	return res;
-}
-
-typedef struct {
-	int res;
-	const char *act;
-	csch_sheet_t *sheet;
-} alien_postproc_sheet_conf_t;
-
-static void alien_postproc_sheet_conf_cb(void *user_ctx, pcb_qry_val_t *res, csch_chdr_t *current)
-{
-	alien_postproc_sheet_conf_t *ppctx = user_ctx;
-	int bv;
-
-	if (res->type == PCBQ_VT_COORD)
-		bv = res->data.crd != 0;
-	else if (res->type == PCBQ_VT_LONG)
-		bv = res->data.lng != 0;
-	else if (res->type == PCBQ_VT_LST)
-		bv = res->data.lst.used > 0;
-	else if (res->type == PCBQ_VT_OBJ)
-		bv = res->data.obj != NULL;
-	else
-		return;
-
-	if (!bv)
-		return;
-
-	ppctx->sheet->currobj = current;
-	current->selected = 1;
-	ppctx->res |= rnd_parse_command(&ppctx->sheet->hidlib, ppctx->act, 0) < 0;
-	current->selected = 0;
-	ppctx->sheet->currobj = NULL;
-}
-
-static int alien_postproc_sheet_conf_exec(csch_alien_read_ctx_t *ctx, const char *pat, const char *act)
-{
-	pcb_qry_exec_t qctx = {0};
-	int qres;
-	alien_postproc_sheet_conf_t ppctx;
-
-	ppctx.res = 0;
-	ppctx.act = act;
-	ppctx.sheet = ctx->sheet;
-
-	pcb_qry_init(&qctx, ctx->sheet, NULL, -1);
-	pcb_qry_list_all_sheet_indirect(&qctx.all, ctx->sheet, CSCH_CMASK_ANY);
-	qres = pcb_qry_run_script(&qctx, ctx->sheet, pat, "sheet", alien_postproc_sheet_conf_cb, &ppctx);
-	pcb_qry_uninit(&qctx);
-
-	return (qres < 0) | ppctx.res;
-}
-
-static int alien_postproc_sheet_conf(csch_alien_read_ctx_t *ctx)
-{
-	char *path;
-	rnd_conf_native_t *nat;
-	rnd_conflist_t *list;
-	rnd_conf_listitem_t *i;
-	const char *pat, *act;
-	int idx;
-
-
-	path = rnd_concat("plugins/", ctx->fmt_prefix, "/postproc_sheet_load", NULL);
-	nat = rnd_conf_get_field(path);
-	if (nat == NULL) {
-		free(path);
-		return 0;
-	}
-
-	if (nat->type != RND_CFN_LIST) {
-		rnd_message(RND_MSG_ERROR, "Invalid config node type %s: should be a list\n", path);
-		free(path);
-		return -1;
-	}
-
-	list = nat->val.list;
-	for(i = rnd_conf_list_first_str(list, &pat, &idx); i != NULL; i = rnd_conf_list_next_str(i, &pat, &idx)) {
-		if (i == NULL) {
-			rnd_message(RND_MSG_ERROR, "Invalid config node %s: missing action (odd number of list items)\n", path);
-			free(path);
-			return -1;
-		}
-		i = rnd_conf_list_next_str(i, &act, &idx);
-		if (alien_postproc_sheet_conf_exec(ctx, pat, act) != 0) {
-			rnd_message(RND_MSG_ERROR, "Failed to execute %s\n", path);
-			free(path);
-			return -1;
-		}
-	}
-
-	free(path);
-	return 0;
-}
-
-int csch_alien_postproc_sheet(csch_alien_read_ctx_t *ctx)
-{
-
-	if (ctx->fmt_prefix == NULL) {
-		rnd_message(RND_MSG_ERROR, "csch_alien_postproc_sheet(): fmt_prefix not available\n");
-		return -1;
-	}
-
-	if (alien_postproc_sheet_conf(ctx) != 0)
-		return -1;
-
-	return alien_postproc_sheet_act(ctx);
-}
-
-void csch_alien_postproc_normalize(csch_alien_read_ctx_t *ctx)
-{
-	htip_entry_t *e;
-	csch_coord_t dx = ctx->sheet->bbox.x1, dy = ctx->sheet->bbox.y1;
-
-	dx = dx / 4000 * 4000;
-	dy = dy / 4000 * 4000;
-
-	for(e = htip_first(&ctx->sheet->direct.id2obj); e != NULL; e = htip_next(&ctx->sheet->direct.id2obj, e)) {
-		csch_chdr_t *o = e->value;
-		csch_move(ctx->sheet, o, -dx, -dy, 0);
-	}
-}
-
-static int is_text_rot_180(csch_text_t *t)
-{
-	int res = (fabs((fabs(t->inst_raw_rot) - 180.0)) < 0.01); /* +- 180 */
-	/*rnd_trace("T180: '%s' '%s' rot=%f %f mir=%d %d -> %d %f\n", t->text, t->rtext, t->inst_rot, t->inst_raw_rot, t->inst_mirx, t->inst_miry, res, fabs((fabs(t->inst_rot) - 180.0)));*/
-	return res;
-}
-
-static int is_text_rot_270(csch_text_t *t)
-{
-	if ((fabs(t->inst_raw_rot - 270.0)) < 0.01) return 1; /* 270 */
-	if ((fabs(t->inst_raw_rot + 90.0)) < 0.01) return 1; /* -90 */
-	return 0;
-}
-
-static void csch_alien_postproc_text_autorot_(csch_alien_read_ctx_t *ctx, csch_cgrp_t *grp, int inref, int fix180, int fix270)
+static void alien_collect_conns(csch_alien_read_ctx_t *ctx, vtp0_t *dst, csch_cgrp_t *grp)
 {
 	htip_entry_t *e;
 
 	for(e = htip_first(&grp->id2obj); e != NULL; e = htip_next(&grp->id2obj, e)) {
-		csch_chdr_t *o = e->value;
-		if (o->type == CSCH_CTYPE_TEXT) {
-			csch_text_t *t = (csch_text_t *)o;
-			if (fix180 && is_text_rot_180(t))
-				csch_rotate90(ctx->sheet, o, (o->bbox.x1+o->bbox.x2)/2, (o->bbox.y1+o->bbox.y2)/2, 2, 0);
-			if (fix270 && is_text_rot_270(t))
-				csch_rotate90(ctx->sheet, o, (o->bbox.x1+o->bbox.x2)/2, (o->bbox.y1+o->bbox.y2)/2, 2, 0);
+		csch_cgrp_t *g = e->value;
+		if (csch_obj_is_grp(&g->hdr)) {
+			if (g->role == CSCH_ROLE_TERMINAL)
+				vtp0_append(dst, g);
+			else
+				alien_collect_conns(ctx, dst, g);
 		}
-		else if (o->type == CSCH_CTYPE_GRP)
-			csch_alien_postproc_text_autorot_(ctx, (csch_cgrp_t *)o, inref, fix180, fix270);
-		else if (o->type == CSCH_CTYPE_GRP_REF)
-			csch_alien_postproc_text_autorot_(ctx, (csch_cgrp_t *)o, 1, fix180, fix270);
 	}
 }
 
-void csch_alien_postproc_text_autorot(csch_alien_read_ctx_t *ctx, csch_cgrp_t *grp, int fix180, int fix270)
+void csch_alien_update_conns(csch_alien_read_ctx_t *ctx)
 {
-	csch_alien_postproc_text_autorot_(ctx, grp, 0, fix180, fix270);
+	vtp0_t grps = {0};
+	long n;
+
+	/* collect all terminal groups recursively */
+	alien_collect_conns(ctx, &grps, &ctx->sheet->direct);
+
+	for(n = 0; n < grps.used; n++)
+		csch_conn_auto_recalc(ctx->sheet, grps.array[n]);
+
+	vtp0_uninit(&grps);
 }
+
+static int centerline_bbox(csch_alien_read_ctx_t *ctx, csch_chdr_t *src, csch_rtree_box_t *dst)
+{
+	switch(src->type) {
+		case CSCH_CTYPE_LINE: csch_line_center_bbox(ctx->sheet, (csch_line_t *)src, dst); return 1;
+		case CSCH_CTYPE_ARC:  csch_arc_center_bbox(ctx->sheet, (csch_arc_t *)src, dst); return 1;
+		case CSCH_CTYPE_POLY: csch_cpoly_center_bbox(ctx->sheet, (csch_cpoly_t *)src, dst); return 1;
+		case CSCH_CTYPE_GRP:
+		case CSCH_CTYPE_GRP_REF:
+			{
+				htip_entry_t *e;
+				csch_rtree_box_t tmp;
+				csch_cgrp_t *grp = (csch_cgrp_t *)src;
+
+				for(e = htip_first(&grp->id2obj); e != NULL; e = htip_next(&grp->id2obj, e)) {
+					csch_bbox_reset(&tmp);
+					if (centerline_bbox(ctx, e->value, &tmp)) {
+						csch_bbox_bump(dst, x, tmp.x1);
+						csch_bbox_bump(dst, y, tmp.y1);
+						csch_bbox_bump(dst, x, tmp.x2);
+						csch_bbox_bump(dst, y, tmp.y2);
+					}
+				}
+			}
+			return 1;
+		default:
+			break;
+	}
+	return 0;
+}
+
+void csch_alien_centerline_bbox(csch_alien_read_ctx_t *ctx, csch_chdr_t *src, csch_rtree_box_t *dst)
+{
+	csch_bbox_reset(dst);
+	centerline_bbox(ctx, src, dst);
+}
+
+
+#include "read_postproc.c"
