@@ -60,6 +60,11 @@ csch_chdr_t *csch_alien_mkarc(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, d
 csch_chdr_t *csch_alien_mkrect(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, double x1, double y1, double x2, double y2, const char *stroke_penname, const char *fill_penname);
 csch_chdr_t *csch_alien_mktext(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, double x, double y, const char *penname);
 
+/* Elliptical arc is emulated using a polygon and line approximation;
+   sa and da are in radians for start and delta angle. */
+csch_chdr_t *csch_alien_mkearc(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, double cx, double cy, double rx, double ry, double sa, double da, const char *stroke, const char *fill);
+
+
 csch_chdr_t *csch_alien_mkpoly(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, const char *stroke_name, const char *fill_name);
 void csch_alien_append_poly_line(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly, double x1, double y1, double x2, double y2);
 void csch_alien_append_poly_arc(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly_, double cx, double cy, double r, double sa, double da);
@@ -77,12 +82,10 @@ csch_coord_t csch_alien_coord_y(csch_alien_read_ctx_t *ctx, double crd);
 csch_coord_t csch_alien_coord(csch_alien_read_ctx_t *ctx, double crd);
 
 
-/* Standard alien file format postprocessing. Returns 0 on success */
-int csch_alien_postproc_sheet(csch_alien_read_ctx_t *ctx);
+/* Update connection on every single terminal group on the sheet */
+void csch_alien_update_conns(csch_alien_read_ctx_t *ctx);
 
-/* Rebase origin: move sheet's bbox x1;y1 to 0;0 */
-void csch_alien_postproc_normalize(csch_alien_read_ctx_t *ctx);
+/* Calculate the centerline bbox of lines, arcs, polygons and groups; ignores
+   anything else. Centerline ignores pen thickness. */
+void csch_alien_centerline_bbox(csch_alien_read_ctx_t *ctx, csch_chdr_t *src, csch_rtree_box_t *dst);
 
-/* recursively emulate tune text rotation; 0 and 90 degree text is always
-   kept; 180 or 270 degree text is adjusted depending on the arguments */
-void csch_alien_postproc_text_autorot(csch_alien_read_ctx_t *ctx, csch_cgrp_t *grp, int fix180, int fix270);
