@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - property editor plugin
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022,2023 Tibor 'Igor2' Palinkas
  *  (Adapted from propsel code in pcb-rnd by the same author)
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -36,8 +36,8 @@
 #include <genlist/gendlist.h>
 #include <genvector/gds_char.h>
 
-#include <librnd/core/hid_dad.h>
-#include <librnd/core/hid_dad_tree.h>
+#include <librnd/hid/hid_dad.h>
+#include <librnd/hid/hid_dad_tree.h>
 #include <librnd/core/globalconst.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/conf.h>
@@ -45,6 +45,8 @@
 #include <librnd/core/event.h>
 
 #include <libcschem/event.h>
+#include <sch-rnd/dad.h>
+#include <sch-rnd/draw.h>
 
 #include "props.h"
 #include "propsel.h"
@@ -177,16 +179,17 @@ static void prop_sch2dlg(propdlg_t *ctx)
 
 		hv.str = scope.array;
 		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wscope, &hv);
+		gds_uninit(&scope);
 	}
 }
 
-static void (*help_expose)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+static void (*help_expose)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e) = NULL;
 
-static void prop_nil_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void prop_nil_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 }
 
-static void prop_prv_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
+static void prop_prv_expose_cb(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e)
 {
 	if (help_expose != NULL)
 		help_expose(attrib, prv, gc, e);
@@ -217,17 +220,17 @@ static void prop_valedit_update(propdlg_t *ctx, csch_props_t *p, csch_propval_t
 
 	memset(&hv, 0, sizeof(hv));
 	switch(p->type) {
-		case CSCH_PROPT_STRING: hv.str = rnd_strdup(pv->string == NULL ? "" : pv->string); break;
-		case CSCH_PROPT_COORD:  hv.lng = pv->coord; break;
+		case CSCH_PROPT_STRING: hv.str = pv->string == NULL ? "" : pv->string; break;
+		case CSCH_PROPT_COORD:  hv.crd = C2P(pv->coord); break;
 		case CSCH_PROPT_ANGLE:  hv.dbl = pv->angle; break;
 		case CSCH_PROPT_DOUBLE: hv.dbl = pv->d; break;
 		case CSCH_PROPT_BOOL:
 		case CSCH_PROPT_INT:    hv.lng = pv->i; break;
-		case CSCH_PROPT_COMMS:  hv.str = rnd_strdup(pv->comms.str == NULL ? "" : pv->comms.str); break;
-		case CSCH_PROPT_ENUM:   hv.str = rnd_strdup(p->enum_names[pv->i]); break;
+		case CSCH_PROPT_COMMS:  hv.str = pv->comms.str == NULL ? "" : pv->comms.str; break;
+		case CSCH_PROPT_ENUM:   hv.str = p->enum_names[pv->i]; break;
 		case CSCH_PROPT_ATTRARR:
 			return; /* can't update directly */
-		case CSCH_PROPT_UUID:  minuid_bin2str(utmp, pv->u); hv.str = rnd_strdup(utmp); break;
+		case CSCH_PROPT_UUID:  minuid_bin2str(utmp, pv->u); hv.str = utmp; break;
 
 		case CSCH_PROPT_invalid:
 		case CSCH_PROPT_max: return;
@@ -290,11 +293,11 @@ static void prop_vals_update(propdlg_t *ctx, csch_props_t *p)
 
 static void prop_select_node_cb(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_t *row)
 {
-	rnd_hidlib_t *hidlib = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hidlib = rnd_gui->get_dad_design(hid_ctx);
 	rnd_hid_tree_t *tree = attrib->wdata;
 	propdlg_t *ctx = tree->user_ctx;
 	csch_props_t *p = NULL;
-	void (*last_help)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e) = NULL;
+	void (*last_help)(rnd_hid_attribute_t *attrib, rnd_hid_preview_t *prv, rnd_hid_gc_t gc, rnd_hid_expose_ctx_t *e) = NULL;
 	const char *helptxt = NULL;
 	int enable_quick_attr = 0;
 
@@ -387,7 +390,7 @@ static void prop_data_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 			force_update = 1;
 			break;
 		case CSCH_PROPT_COORD:
-			sctx.c = ctx->dlg[ctx->wedit[p->type]].val.lng;
+			sctx.c = P2C(ctx->dlg[ctx->wedit[p->type]].val.crd);
 			sctx.c_absolute = ctx->dlg[ctx->wabs[p->type]].val.lng;
 			sctx.c_valid = 1;
 			break;
@@ -477,7 +480,7 @@ static void prop_change_comms_cb(void *hid_ctx, void *caller_data, rnd_hid_attri
 
 			if (pen_name != NULL) {
 				rnd_hid_attr_val_t hv;
-				hv.str = rnd_strdup(pen_name);
+				hv.str = pen_name;
 				rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, attr - ctx->dlg, &hv);
 				prop_data_cb(hid_ctx, caller_data, attr, 1);
 			}
@@ -547,7 +550,7 @@ static void prop_change_attrarr_cb(void *hid_ctx, void *caller_data, rnd_hid_att
 	rnd_hid_row_t *r = rnd_dad_tree_get_selected(&ctx->dlg[ctx->wtree]);
 /*	csch_sheet_t *sheet = ctx->pe.sheet;*/
 	csch_oidpath_t *idp;
-	rnd_hidlib_t *hl = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
 
 
 	idp = prop_scope_single_obj(&ctx->pe);
@@ -566,7 +569,7 @@ static void prop_attrdlg_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 {
 	propdlg_t *ctx = caller_data;
 	csch_oidpath_t *idp;
-	rnd_hidlib_t *hl = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hl = rnd_gui->get_dad_design(hid_ctx);
 
 	idp = prop_scope_single_obj(&ctx->pe);
 	if (idp != NULL) {
@@ -582,7 +585,7 @@ static void prop_attrdlg_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 
 static void prop_quickattr_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	rnd_hidlib_t *hidlib = rnd_gui->get_dad_hidlib(hid_ctx);
+	rnd_design_t *hidlib = rnd_gui->get_dad_design(hid_ctx);
 	propdlg_t *ctx = caller_data;
 	csch_oidpath_t *idp;
 
@@ -606,6 +609,11 @@ static void prop_quickattr_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 		rnd_message(RND_MSG_ERROR, "Attribute-editing array is supported only for single-object propedit\nThis propedit has a scope of multiple objects.\n");
 }
 
+static void prop_attr_enter_pressed_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	rnd_dad_retovr_t **retovr = caller_data;
+	rnd_hid_dad_close(hid_ctx, *retovr, 0);
+}
 
 static void prop_add_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
@@ -624,10 +632,11 @@ static void prop_add_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *a
 			RND_DAD_LABEL(dlg, "Attribute value:");
 			RND_DAD_STRING(dlg);
 				wval = RND_DAD_CURRENT(dlg);
+				RND_DAD_ENTER_CB(dlg, prop_attr_enter_pressed_cb);
 		RND_DAD_END(dlg);
 		RND_DAD_BUTTON_CLOSES(dlg, clbtn);
 	RND_DAD_END(dlg);
-	RND_DAD_AUTORUN("propedit_add", dlg, "Propedit: add new attribute", NULL, failed);
+	RND_DAD_AUTORUN("propedit_add", dlg, "Propedit: add new attribute", &dlg_ret_override, failed);
 
 	key = dlg[wkey].val.str;
 	if (key == NULL) key = "";
@@ -701,7 +710,6 @@ static void build_propval(propdlg_t *ctx)
 {
 	static const char *type_tabs[] = {"none", "string", "coord", "angle", "double", "int", NULL};
 	static const char *abshelp = "When unticked each apply is a relative change added to\nthe current value of each object";
-	long cmax = (1ul<<31)-1l;
 
 	RND_DAD_BEGIN_TABBED(ctx->dlg, type_tabs);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_HIDE_TABLAB);
@@ -727,9 +735,8 @@ static void build_propval(propdlg_t *ctx)
 		RND_DAD_END(ctx->dlg);
 		RND_DAD_BEGIN_VBOX(ctx->dlg);
 			RND_DAD_LABEL(ctx->dlg, "Data type: coord");
-			RND_DAD_INTEGER(ctx->dlg);
+			RND_DAD_CSCH_COORD(ctx->dlg);
 				ctx->wedit[2] = RND_DAD_CURRENT(ctx->dlg);
-				RND_DAD_MINMAX(ctx->dlg, -cmax, cmax);
 				RND_DAD_ENTER_CB(ctx->dlg, prop_data_auto_cb);
 			RND_DAD_BEGIN_HBOX(ctx->dlg);
 				RND_DAD_LABEL(ctx->dlg, "abs");
@@ -874,7 +881,7 @@ static void csch_dlg_propdlg(propdlg_t *ctx)
 
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-		RND_DAD_BEGIN_HPANE(ctx->dlg);
+		RND_DAD_BEGIN_HPANE(ctx->dlg, "left-right");
 
 			/* left: property tree and filter */
 			RND_DAD_BEGIN_VBOX(ctx->dlg);
@@ -897,7 +904,7 @@ static void csch_dlg_propdlg(propdlg_t *ctx)
 						RND_DAD_HELP(ctx->dlg, "Remove the selected attribute\n(from the a/ subtree)");
 					RND_DAD_BUTTON(ctx->dlg, "rfr");
 						RND_DAD_CHANGE_CB(ctx->dlg, prop_refresh_cb);
-						RND_DAD_HELP(ctx->dlg, "Refresh: rebuild the tree\nupdating all values from the board");
+						RND_DAD_HELP(ctx->dlg, "Refresh: rebuild the tree\nupdating all values from the sheet");
 				RND_DAD_END(ctx->dlg);
 			RND_DAD_END(ctx->dlg);
 
@@ -961,7 +968,7 @@ const char csch_acts_propedit[] = "propedit(object[:id]|sheet|selection)\n";
 const char csch_acth_propedit[] = "";
 fgw_error_t csch_act_propedit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	rnd_hidlib_t *hl = RND_ACT_HIDLIB;
+	rnd_design_t *hl = RND_ACT_DESIGN;
 	csch_sheet_t *sheet = (csch_sheet_t *)hl;
 	propdlg_t *ctx = calloc(sizeof(propdlg_t), 1);
 	int a, r;
@@ -985,7 +992,7 @@ fgw_error_t csch_act_propedit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx)
+static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx, void *user_data)
 {
 	propdlg_t *ctx;
 	gdl_iterator_t it;
@@ -995,7 +1002,7 @@ static void propdlg_unit_change(rnd_conf_native_t *cfg, int arr_idx)
 	}
 }
 
-static void propedit_sheet_edit(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void propedit_sheet_edit(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	propdlg_t *pd;
 
@@ -1004,7 +1011,7 @@ static void propedit_sheet_edit(rnd_hidlib_t *hidlib, void *user_data, int argc,
 			prop_refresh(pd);
 }
 
-static void propedit_sheet_preunload(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+static void propedit_sheet_preunload(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
 	propdlg_t *n, *next;
@@ -1032,6 +1039,7 @@ void csch_propdlg_init(void)
 	}
 
 	rnd_event_bind(CSCH_EVENT_SHEET_EDITED, propedit_sheet_edit, NULL, csch_propedit_cookie);
+	rnd_event_bind(CSCH_EVENT_SELECTION_CHANGED, propedit_sheet_edit, NULL, csch_propedit_cookie);
 	rnd_event_bind(CSCH_EVENT_SHEET_PREUNLOAD, propedit_sheet_preunload, NULL, csch_propedit_cookie);
 }
 
