@@ -156,7 +156,7 @@ static fgw_error_t csch_act_propset(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		RND_ACT_CONVARG(3, FGW_STR, propset, name = argv[3].val.str);
 		RND_ACT_CONVARG(4, FGW_STR, propset, val = argv[4].val.str);
 	}
-	if (strcmp(first, "@") == 0) {
+	else if (strcmp(first, "@") == 0) {
 		if (sheet->currobj == NULL) {
 			rnd_message(RND_MSG_ERROR, "propset: @ without sheet->currobj set\n");
 			return FGW_ERR_ARG_CONV;
