@@ -458,22 +458,22 @@ static void set_line(csch_propset_ctx_t *st, csch_line_t *line)
 	}
 
 	if (st->c_valid && (strcmp(pn, "x1") == 0)) {
-		csch_line_modify(st->sheet, line, &st->c, NULL, NULL, NULL, 1, !st->c_absolute);
+		csch_line_modify(st->sheet, line, &st->c, NULL, NULL, NULL, 1, !st->c_absolute, 1);
 		DONE;
 	}
 
 	if (st->c_valid && (strcmp(pn, "y1") == 0)) {
-		csch_line_modify(st->sheet, line, NULL, &st->c, NULL, NULL, 1, !st->c_absolute);
+		csch_line_modify(st->sheet, line, NULL, &st->c, NULL, NULL, 1, !st->c_absolute, 1);
 		DONE;
 	}
 
 	if (st->c_valid && (strcmp(pn, "x2") == 0)) {
-		csch_line_modify(st->sheet, line, NULL, NULL, &st->c, NULL, 1, !st->c_absolute);
+		csch_line_modify(st->sheet, line, NULL, NULL, &st->c, NULL, 1, !st->c_absolute, 1);
 		DONE;
 	}
 
 	if (st->c_valid && (strcmp(pn, "y2") == 0)) {
-		csch_line_modify(st->sheet, line, NULL, NULL, NULL, &st->c, 1, !st->c_absolute);
+		csch_line_modify(st->sheet, line, NULL, NULL, NULL, &st->c, 1, !st->c_absolute, 1);
 		DONE;
 	}
 
