@@ -4,5 +4,5 @@ extern const char csch_acth_SearchDialog[];
 fgw_error_t csch_act_SearchDialog(fgw_arg_t *res, int argc, fgw_arg_t *argv);
 
 void sch_rnd_search_close_all(void);
-void sch_rnd_query_ev_preunload(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[]);
+void sch_rnd_query_ev_preunload(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[]);
 
