@@ -232,14 +232,14 @@ do { \
 } while(0)
 
 
-csch_inline double obj_thickness(csch_chdr_t *o)
+RND_INLINE double obj_thickness(csch_chdr_t *o)
 {
 	if (o->stroke == NULL)
 		return 1;
 	return o->stroke->size;
 }
 
-csch_inline int field_obj_attr(pcb_qry_exec_t *ec, csch_cgrp_t *o, const char *key, pcb_qry_val_t *res)
+RND_INLINE int field_obj_attr(pcb_qry_exec_t *ec, csch_cgrp_t *o, const char *key, pcb_qry_val_t *res)
 {
 	csch_attrib_t *a = csch_attrib_get(&o->attr, key);
 	long n;
@@ -263,7 +263,7 @@ csch_inline int field_obj_attr(pcb_qry_exec_t *ec, csch_cgrp_t *o, const char *k
 	return 0;
 }
 
-csch_inline int field_obj_conn(pcb_qry_exec_t *ec, vtp0_t *conn_fld, pcb_qry_val_t *res)
+RND_INLINE int field_obj_conn(pcb_qry_exec_t *ec, vtp0_t *conn_fld, pcb_qry_val_t *res)
 {
 	long n;
 
@@ -282,7 +282,7 @@ csch_inline int field_obj_conn(pcb_qry_exec_t *ec, vtp0_t *conn_fld, pcb_qry_val
 	return 0;
 }
 
-csch_inline int field_obj_pen(csch_chdr_t *o, csch_comm_str_t penname, csch_cpen_t *pen, pcb_qry_node_t *fld, pcb_qry_val_t *res)
+RND_INLINE int field_obj_pen(csch_chdr_t *o, csch_comm_str_t penname, csch_cpen_t *pen, pcb_qry_node_t *fld, pcb_qry_val_t *res)
 {
 	query_fields_keys_t fh1;
 
