@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - GUI
- *  Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2020,2022,2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
  *
@@ -351,7 +351,7 @@ static void attr_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row_
 	attr2dlg(ctx);
 }
 
-csch_inline csch_attrib_t *tree_get_current_attr(attrdlg_ctx_t *ctx)
+RND_INLINE csch_attrib_t *tree_get_current_attr(attrdlg_ctx_t *ctx)
 {
 	rnd_hid_attribute_t *attr = &ctx->dlg[ctx->wattrs];
 	rnd_hid_row_t *r = rnd_dad_tree_get_selected(attr);
@@ -395,19 +395,17 @@ static void attr_val_set_meta_and_str(attrdlg_ctx_t *ctx, csch_attrib_t *a, int
 	if (prio != a->prio)
 		chg = 1;
 
-	if (set_str) {
-		if (strcmp(val, a->val) != 0)
-			chg = 1;
-	}
-	else
-		val = a->val; /* do not change value */
+	if ((set_str) && (strcmp(val, a->val) != 0))
+		chg = 1;
 
 	if (!chg)
 		return;
 
-
 	ctx->refresh_lock++;
-	csch_attr_modify_str(ctx->sheet, ctx->obj, prio, key, val, attrdlg_src(), 1);
+	if (set_str)
+		csch_attr_modify_str(ctx->sheet, ctx->obj, prio, key, val, attrdlg_src(), 1);
+	else
+		csch_attr_modify_prio(ctx->sheet, ctx->obj, a, prio, attrdlg_src(), 1);
 	ctx->refresh_lock--;
 	sheet2dlg(ctx);
 }
@@ -441,6 +439,59 @@ static void attr_strval_set_cb(void *hid_ctx, void *caller_data, rnd_hid_attribu
 		attr_val_set_meta_and_str(ctx, a, 1);
 }
 
+/*** Multiline string edit dialog ***/
+typedef struct {
+	RND_DAD_DECL_NOINIT(dlg)
+	int wtxt;
+	char *new_val;
+} mledit_t;
+
+static void mledit_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
+{
+	mledit_t *ctx = caller_data;
+	rnd_hid_attribute_t *atxt = &ctx->dlg[ctx->wtxt];
+	rnd_hid_text_t *txt = atxt->wdata;
+
+	/* remember the string accepted */
+	ctx->new_val = txt->hid_get_text(atxt, ctx->dlg_hid_ctx);
+}
+
+static void attr_strval_mledit_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	mledit_t ctx = {0};
+	attrdlg_ctx_t *pctx = caller_data;
+	const char *val = pctx->dlg[pctx->wval_str].val.str;
+
+	rnd_hid_attr_val_t hv;
+	rnd_hid_dad_buttons_t clbtn[] = {{"Cancel", 0}, {"OK", 1}, {NULL, 0}};
+
+
+	RND_DAD_BEGIN_VBOX(ctx.dlg);
+		RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
+		RND_DAD_TEXT(ctx.dlg, NULL);
+			RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
+			ctx.wtxt = RND_DAD_CURRENT(ctx.dlg);
+		RND_DAD_BUTTON_CLOSES(ctx.dlg, clbtn);
+	RND_DAD_END(ctx.dlg);
+
+	RND_DAD_DEFSIZE(ctx.dlg, 400, 200);
+	RND_DAD_NEW("AttributeMultiline", ctx.dlg, "Atribute dialog: multiline text edit", &ctx, 1, mledit_close_cb);
+
+	hv.str = (val == NULL ? "" : val);
+	rnd_gui->attr_dlg_set_value(ctx.dlg_hid_ctx, ctx.wtxt, &hv);
+
+	if (RND_DAD_RUN(ctx.dlg) == 1) {
+		hv.str = ctx.new_val;
+		rnd_gui->attr_dlg_set_value(pctx->dlg_hid_ctx, pctx->wval_str, &hv);
+		attr_strval_set_cb(hid_ctx, caller_data, attr); /* get the str value set */
+	}
+
+	free(ctx.new_val);
+	RND_DAD_FREE(ctx.dlg);
+}
+
+
+/*** array ***/
 static csch_attrib_t *tree_get_current_attr_arr(attrdlg_ctx_t *ctx, long *idx, const char **key)
 {
 	rnd_hid_attribute_t *aattr = &ctx->dlg[ctx->wattrs];
@@ -821,6 +872,8 @@ static const char *attr_dlg(csch_sheet_t *sheet, csch_cgrp_t *obj, const char *t
 									RND_DAD_CHANGE_CB(ctx->dlg, attr_conv_to_arr_cb);
 									ctx->wconv_arr = RND_DAD_CURRENT(ctx->dlg);
 								spring(ctx);
+								RND_DAD_BUTTON(ctx->dlg, "Edit multiline");
+									RND_DAD_CHANGE_CB(ctx->dlg, attr_strval_mledit_cb);
 								RND_DAD_BUTTON(ctx->dlg, "Set");
 									RND_DAD_CHANGE_CB(ctx->dlg, attr_strval_set_cb);
 							RND_DAD_END(ctx->dlg);
@@ -924,7 +977,7 @@ static const char *attr_dlg(csch_sheet_t *sheet, csch_cgrp_t *obj, const char *t
 
 extern csch_chdr_t *csch_obj_clicked;
 
-csch_inline csch_chdr_t *resolve_obj_(csch_sheet_t *sheet, const char *actname, const char *cmd, int *has_coords)
+RND_INLINE csch_chdr_t *resolve_obj_(csch_sheet_t *sheet, const char *actname, const char *cmd, int *has_coords)
 {
 	*has_coords = 0;
 
