@@ -670,8 +670,10 @@ static void library_refresh_cb(void *hid_ctx, void *caller_data, rnd_hid_attribu
 		library_sheet2dlg(ctx);
 
 		r = rnd_dad_tree_get_selected(attr);
-		library_update_preview(ctx, r->user_data, NULL);
-		library_filter_reapply(hid_ctx, ctx);
+		if (r != NULL) {
+			library_update_preview(ctx, r->user_data, NULL);
+			library_filter_reapply(hid_ctx, ctx);
+		}
 	}
 	else
 		rnd_message(RND_MSG_ERROR, "Failed to refresh '%s'\n", rootname);
@@ -966,7 +968,7 @@ static char *sch_rnd_library_dlg(csch_sheet_t *sheet, const char *lib_type_name,
 						RND_DAD_CHANGE_CB(ctx->dlg, library_edit_cb);
 						ctx->wedit = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_PICBUTTON(ctx->dlg, xpm_refresh);
-						RND_DAD_HELP(ctx->dlg, "reload and refresh the current\nmain tree of the library");
+						RND_DAD_HELP(ctx->dlg, "reload and refresh the currently selected\nmain tree of the library\nYou need to select an entry in the tree first and only that subtree will be rehashed.\nIf you have new roots configured/created not shown in the tree view above,\nre-scan the library (e.g. file/maintenance menu).");
 						RND_DAD_CHANGE_CB(ctx->dlg, library_refresh_cb);
 				RND_DAD_END(ctx->dlg);
 				RND_DAD_BEGIN_HBOX(ctx->dlg);
