@@ -160,7 +160,7 @@ static void set_text_timed(void *ctx_)
 	ctx->timed.str.used = 0;
 }
 
-csch_inline void dyntext_build_timed_subst(dyntext_dlg_ctx_t *ctx, const char *str1, const char *str2)
+RND_INLINE void dyntext_build_timed_subst(dyntext_dlg_ctx_t *ctx, const char *str1, const char *str2)
 {
 	ctx->timed.str.used = 0;
 	gds_append_len(&ctx->timed.str, ctx->text->text, ctx->start);
