@@ -135,7 +135,7 @@ static const char *get_name(csch_chdr_t *obj)
 	return csch_attrib_get_str(&grp->attr, "name");
 }
 
-csch_inline int strcmp_safe(const char *s1, const char *s2)
+RND_INLINE int strcmp_safe(const char *s1, const char *s2)
 {
 	if ((s1 == NULL) && (s2 == NULL)) return 0;
 	if ((s1 == NULL) || (s2 == NULL)) return 1;
