@@ -30,6 +30,8 @@
 
 #include <libcschem/config.h>
 
+#include <ctype.h>
+
 #include <genvector/gds_char.h>
 #include <librnd/core/actions.h>
 #include <librnd/hid/hid_dad.h>
@@ -44,12 +46,25 @@ static gds_t key2act_tmp = {0};
 
 static const char *key2act(const char *key)
 {
+	int n;
+
 	if (key2act_tmp.used == 0)
 		gds_append_str(&key2act_tmp, "quick_attr_");
 	else
 		key2act_tmp.used = 11;
 
 	gds_append_str(&key2act_tmp, key);
+
+	/* replace non-alnum and non-underscore with __ */
+	for(n = 0; n < key2act_tmp.used; n++) {
+		int c = key2act_tmp.array[n];
+		if (isalnum(c) || (c == '_'))
+			continue;
+		key2act_tmp.array[n] = '_';
+		gds_insert_len(&key2act_tmp, n, "_", 1);
+		n++;
+	}
+
 	return key2act_tmp.array;
 }
 
