@@ -44,7 +44,7 @@ static char *devmap_lib_lookup(ldch_ctx_t *ctx, const char *load_name, ldch_low_
 		le = csch_lib_search_master(devmaster, load_name2, CSCH_SLIB_STATIC);
 		free(load_name2);
 	}
-	rnd_trace("devmap lookup: %s -> %p\n", load_name, le);
+/*	rnd_trace("devmap lookup: %s -> %p\n", load_name, le);*/
 
 	return le == NULL ? NULL : rnd_strdup(le->realpath);
 }
@@ -110,10 +110,10 @@ static csch_attribs_t *devmap_get_extlib(devmap_ctx_t *ctx, const char *devmap_n
 	res = &devmap->comp_attribs;
 
 	if (save_in_local) {
-		rnd_trace("devmap: inserting %s in local libs:\n", devmap_name);
+/*		rnd_trace("devmap: inserting %s in local libs:\n", devmap_name);*/
 		for(n = 0; n < ctx->ssyms.used; n++) {
 			csch_cgrp_t *sym = ctx->ssyms.array[n];
-			rnd_trace("         %s\n", sym->hdr.sheet->hidlib.fullpath);
+/*			rnd_trace("         %s\n", sym->hdr.sheet->hidlib.fullpath);*/
 			rnd_message(RND_MSG_INFO, "devmap: inserting %s in local lib of %s\n", devmap_name, sym->hdr.sheet->hidlib.fullpath);
 			devmap_set_in_loclib(sym->hdr.sheet, devmap_name, res);
 		}
@@ -155,7 +155,7 @@ static csch_attribs_t *devmap_get_from_any_lib(devmap_ctx_t *ctx, csch_acomp_t *
 			continue;
 
 		cdmn = csch_attrib_get_str(&sym->attr, "devmap");
-rnd_trace("devmap: comp: %s devmap: %s sym's: '%s'\n", comp->name, devmap_name, cdmn);
+/*rnd_trace("devmap: comp: %s devmap: %s sym's: '%s'\n", comp->name, devmap_name, cdmn);*/
 		if ((cdmn == NULL) || (strcmp(cdmn, devmap_name) != 0))
 			continue;
 
@@ -186,11 +186,11 @@ rnd_trace("devmap: comp: %s devmap: %s sym's: '%s'\n", comp->name, devmap_name,
 	}
 
 	if (res != NULL) {
-		rnd_trace("devmap: served %s from local lib of sheet %s\n", devmap_name, res_sym->hdr.sheet->hidlib.fullpath);
+/*		rnd_trace("devmap: served %s from local lib of sheet %s\n", devmap_name, res_sym->hdr.sheet->hidlib.fullpath);*/
 		return res;
 	}
 
-	rnd_trace("devmap: %s is not in our local libs\n", devmap_name);
+/*	rnd_trace("devmap: %s is not in our local libs\n", devmap_name);*/
 	res = devmap_get_extlib(ctx, devmap_name, ucallctx, 1);
 	if (res == NULL) {
 		rnd_message(RND_MSG_ERROR, "Devmap %s not found in the library for component %s\n", devmap_name, comp->name);
