@@ -132,7 +132,7 @@ static csch_attribs_t *devmap_get_from_loclib(csch_sheet_t *sheet, const char *d
 	map = root_dir->backend_data.ptr[0];
 
 	gd = htsp_get(map, devmap_name);
-rnd_trace("*** get: map=%p '%s' -> %p\n", map, devmap_name, gd);
+/*rnd_trace("*** get: map=%p '%s' -> %p\n", map, devmap_name, gd);*/
 	if (gd == NULL)
 		return NULL;
 
@@ -177,7 +177,7 @@ void devmap_set_in_loclib(csch_sheet_t *sheet, const char *devmap_name, csch_att
 	devmap_local_ins(map, root_dir, gd);
 	rnd_event(&sheet->hidlib, CSCH_EVENT_LIBRARY_CHANGED, NULL);
 
-rnd_trace("*** set: map=%p '%s' -> %p\n", map, gd->loclib_name, gd);
+/*rnd_trace("*** set: map=%p '%s' -> %p\n", map, gd->loclib_name, gd);*/
 
 
 }
