@@ -160,7 +160,7 @@ fgw_error_t csch_act_quick_attr_devmap(fgw_arg_t *res, int argc, fgw_arg_t *argv
 
 			src = csch_attrib_src_p("std_devmap", "manually picked from the devmap lib");
 			csch_attr_modify_str(sheet, grp, -CSCH_ATP_USER_DEFAULT, "devmap", sep+1, src, 1);
-			rnd_trace("new devmap val: '%s'\n", sep+1);
+/*			rnd_trace("new devmap val: '%s'\n", sep+1);*/
 		}
 	}
 	fgw_arg_free(&rnd_fgw, &ares);
