@@ -294,7 +294,7 @@ static int forge_exec(csch_ahdr_t *aobj, const char *inst, int prio)
 {
 	while(isspace(*inst)) inst++;
 
-	rnd_trace(" %s\n", inst);
+/*	rnd_trace(" %s\n", inst);*/
 
 	switch(*inst) {
 		case 'a':
@@ -344,7 +344,7 @@ fgw_error_t std_forge_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (forge == NULL)
 		return 0;
 
-	rnd_trace("--- FORGE in comp %s\n", comp->name);
+/*	rnd_trace("--- FORGE in comp %s\n", comp->name);*/
 	prio = cctx->view_eng->eprio + CSCH_PRI_PLUGIN_NORMAL;
 	r = 0;
 	for(n = 0; (r == 0) && (n < forge->arr.used); n++)
