@@ -83,7 +83,7 @@ static void tool_arrow_adjust_attached_objects(rnd_design_t *hl)
 
 	if (arrow_is_drag_n_drop()) {
 		const char *tool_name = rnd_gui->control_is_pressed(rnd_gui) ? "copy" : "move";
-		rnd_trace("Drag&drop object; passing on to %s\n", tool_name);
+/*		rnd_trace("Drag&drop object; passing on to %s\n", tool_name);*/
 		arrow.click = 0;
 		rnd_tool_select_by_name(hl, tool_name);
 		tool_movecopy_press_at(hl, arrow.press_chx, arrow.press_chy, arrow.click_obj, 1);
