@@ -59,6 +59,11 @@ static void tool_circle_release(rnd_design_t *hl)
 		const char *stroke_name;
 		csch_arc_t *arc = (csch_arc_t *)csch_op_create(sheet, &sheet->direct, CSCH_CTYPE_ARC);
 
+		if (arc == NULL) {
+			rnd_message(RND_MSG_ERROR, "Failed to create arc object\n");
+			return;
+		}
+
 		arc->spec.c.x = csch_tool_circle.x;
 		arc->spec.c.y = csch_tool_circle.y;
 		arc->spec.r = csch_tool_circle.r;
