@@ -44,19 +44,16 @@ static tool_movecopy_t mvcp;
 
 static void tool_move_init(void)
 {
-	rnd_trace("move init\n");
 	mvcp.copy = 0;
 }
 
 static void tool_copy_init(void)
 {
-	rnd_trace("copy init\n");
 	mvcp.copy = 1;
 }
 
 static void tool_movecopy_uninit(void)
 {
-	rnd_trace("move uninit\n");
 }
 
 /* for the passon from the arrow tool */
@@ -118,9 +115,9 @@ static void move_endpoint(csch_sheet_t *sheet, csch_coord_t dx, csch_coord_t dy)
 				csch_line_t *l = (csch_line_t *)mvcp.click_obj;
 				uundo_freeze_serial(&sheet->undo);
 				if (mvcp.endpoint == 1)
-					csch_line_modify(sheet, l, &dx, &dy, NULL, NULL, 1, 1);
+					csch_line_modify(sheet, l, &dx, &dy, NULL, NULL, 1, 1, 1);
 				else if (mvcp.endpoint == 2)
-					csch_line_modify(sheet, l, NULL, NULL, &dx, &dy, 1, 1);
+					csch_line_modify(sheet, l, NULL, NULL, &dx, &dy, 1, 1, 1);
 				uundo_unfreeze_serial(&sheet->undo);
 				uundo_inc_serial(&sheet->undo);
 			}
@@ -139,7 +136,6 @@ static void tool_movecopy_release(rnd_design_t *hl)
 		csch_coord_t x = P2C(sch_rnd_crosshair_x), y = P2C(sch_rnd_crosshair_y);
 		csch_coord_t dx = x - mvcp.press_x, dy = y - mvcp.press_y;
 
-		rnd_trace("move release: %d %d\n", dx, dy);
 		if (!mvcp.copy) {
 			if (!mvcp.endpoint) {
 				csch_cobj_redraw_freeze(sheet);
