@@ -69,6 +69,11 @@ static void tool_rect_release(rnd_design_t *hl)
 		csch_cpoly_t *poly = (csch_cpoly_t *)csch_op_create(sheet, &sheet->direct, CSCH_CTYPE_POLY);
 		rnd_coord_t x1, y1, x2, y2;
 
+		if (poly == NULL) {
+			rnd_message(RND_MSG_ERROR, "Failed to create line object\n");
+			return;
+		}
+
 		csch_tool_rect.stroke = SCH_RND_DIRECT_PEN(sheet, tool_rect_stroke, &stroke_name);
 		csch_tool_rect.fill = SCH_RND_DIRECT_PEN(sheet, tool_rect_fill, &fill_name);
 
