@@ -53,6 +53,11 @@ void sch_tool_text_notify_mode(rnd_design_t *hl)
 		const char *stroke_name;
 		csch_text_t *text = (csch_text_t *)csch_op_create(sheet, &sheet->direct, CSCH_CTYPE_TEXT);
 
+		if (text == NULL) {
+			rnd_message(RND_MSG_ERROR, "Failed to create line object\n");
+			return;
+		}
+
 		text->spec1.x = P2C(sch_rnd_crosshair_x);
 		text->spec1.y = P2C(sch_rnd_crosshair_y);
 		text->text = new_str;
