@@ -57,7 +57,7 @@
 csch_sheet_t *sch_rnd_buffer[SCH_RND_BUFFER_MAX];
 csch_project_t sch_rnd_buffer_prj;
 
-csch_inline void get_obj_parent_sel(csch_sheet_t *sheet, csch_chdr_t *obj, int *skip, int *orphan)
+RND_INLINE void get_obj_parent_sel(csch_sheet_t *sheet, csch_chdr_t *obj, int *skip, int *orphan)
 {
 	csch_cgrp_t *grp;
 
