@@ -83,6 +83,8 @@ typedef struct {
 			RND_CFT_COLOR hilight_stroke;
 			RND_CFT_COLOR symbol_meta_embed;         /* symbol meta bounding box and info text draw color for group objects */
 			RND_CFT_COLOR symbol_meta_loclib;        /* symbol meta bounding box and info text draw color for group refs to local lib */
+			RND_CFT_COLOR non_graphical_background;  /* color of non-graphical sheet background */
+			RND_CFT_COLOR non_graphical_text;        /* color of non-graphical sheet text */
 		} color;
 	} appearance;
 	const struct compile {
