@@ -2,7 +2,9 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - sch-rnd (executable)
- *  Copyright (C) 2019,2020,2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2020,2022,2023 Tibor 'Igor2' Palinkas
+ *
+ *  (Supported by NLnet NGI0 Entrust in 2023)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +42,7 @@
 #include <libcschem/cnc_text.h>
 #include <libcschem/cnc_arc.h>
 #include <libcschem/cnc_pen.h>
+#include <libcschem/non_graphical.h>
 #include <libcschem/util_wirenet.h>
 #include <libcschem/event.h>
 
@@ -55,7 +58,7 @@ static const char draw_cookie[] = "sch-rnd/draw.c";
 typedef struct {
 	csch_sheet_t *sheet;
 	rnd_hid_gc_t gc;
-	vtp0_t text_update;
+	vtp0_t objlist;
 	rnd_xform_t *xform;
 } draw_ctx_t;
 
@@ -99,7 +102,7 @@ static void pcb_draw_dashed_line(rnd_hid_gc_t GC, rnd_coord_t x1, rnd_coord_t y1
 		x2, y2);
 }
 
-csch_inline rnd_cap_style_t pen_cap(csch_cpen_t *pen)
+RND_INLINE rnd_cap_style_t pen_cap(csch_cpen_t *pen)
 {
 	switch(pen->shape) {
 		case CSCH_PSHP_ROUND: return rnd_cap_round;
@@ -116,7 +119,7 @@ static void lighten_color(const rnd_color_t *orig, rnd_color_t *dst, double fact
 }
 
 
-csch_inline const rnd_color_t *sch_rnd_stroke_color(draw_ctx_t *ctx, const csch_chdr_t *obj, const csch_cpen_t *stroke, int selected)
+RND_INLINE const rnd_color_t *sch_rnd_stroke_color(draw_ctx_t *ctx, const csch_chdr_t *obj, const csch_cpen_t *stroke, int selected)
 {
 	const rnd_color_t *res;
 	int no_render_select = (ctx->xform != NULL) && (ctx->xform->no_render_select);
@@ -137,7 +140,7 @@ csch_inline const rnd_color_t *sch_rnd_stroke_color(draw_ctx_t *ctx, const csch_
 	return res;
 }
 
-csch_inline const rnd_color_t *sch_rnd_fill_color(draw_ctx_t *ctx, const csch_chdr_t *obj, const csch_cpen_t *fill, int selected)
+RND_INLINE const rnd_color_t *sch_rnd_fill_color(draw_ctx_t *ctx, const csch_chdr_t *obj, const csch_cpen_t *fill, int selected)
 {
 	const rnd_color_t *res;
 	if (obj->hilight)
@@ -151,7 +154,9 @@ csch_inline const rnd_color_t *sch_rnd_fill_color(draw_ctx_t *ctx, const csch_ch
 	return res;
 }
 
-csch_inline void draw_layer_line(draw_ctx_t *ctx, csch_line_t *l, csch_cpen_t *pen, int selected)
+#include "draw_poly.c"
+
+RND_INLINE void draw_layer_line(draw_ctx_t *ctx, csch_line_t *l, csch_cpen_t *pen, int selected)
 {
 	rnd_render->set_color(ctx->gc, sch_rnd_stroke_color(ctx, &l->hdr, pen, selected));
 	rnd_hid_set_line_cap(ctx->gc, pen_cap(pen));
@@ -159,7 +164,7 @@ csch_inline void draw_layer_line(draw_ctx_t *ctx, csch_line_t *l, csch_cpen_t *p
 	rnd_render->draw_line(ctx->gc, C2P(l->inst.c.p1.x), C2P(l->inst.c.p1.y), C2P(l->inst.c.p2.x), C2P(l->inst.c.p2.y));
 }
 
-csch_inline void draw_layer_conn(draw_ctx_t *ctx, csch_conn_t *c)
+RND_INLINE void draw_layer_conn(draw_ctx_t *ctx, csch_conn_t *c)
 {
 	long n, *crd;
 
@@ -182,7 +187,7 @@ csch_inline void draw_layer_conn(draw_ctx_t *ctx, csch_conn_t *c)
 	}
 }
 
-csch_inline void draw_vectors(draw_ctx_t *ctx, g2d_vect_t base, g2d_vect_t origin, g2d_xform_t mx)
+RND_INLINE void draw_vectors(draw_ctx_t *ctx, g2d_vect_t base, g2d_vect_t origin, g2d_xform_t mx)
 {
 		g2d_vect_t u[6];
 		int n;
@@ -206,7 +211,7 @@ csch_inline void draw_vectors(draw_ctx_t *ctx, g2d_vect_t base, g2d_vect_t origi
 		rnd_render->draw_line(ctx->gc, C2P(u[3].x), C2P(u[3].y), C2P(u[5].x), C2P(u[5].y));
 }
 
-csch_inline void print_mx(const char *name, g2d_xform_t mx)
+RND_INLINE void print_mx(const char *name, g2d_xform_t mx)
 {
 	int n;
 	rnd_trace("MX %s\n", name);
@@ -218,7 +223,7 @@ csch_inline void print_mx(const char *name, g2d_xform_t mx)
 	rnd_trace("\n");
 }
 
-csch_inline void draw_layer_text(draw_ctx_t *ctx, csch_text_t *t, csch_cpen_t *pen, int selected)
+RND_INLINE void draw_layer_text(draw_ctx_t *ctx, csch_text_t *t, csch_cpen_t *pen, int selected)
 {
 	int use_local = (ctx->xform != NULL) && ctx->xform->use_local_vis;
 	int vis_meta = use_local ? ctx->xform->local_vis[CSCH_DSPLY_TEXT_META] : csch_layer_vis[CSCH_DSPLY_TEXT_META];
@@ -281,115 +286,9 @@ csch_inline void draw_layer_text(draw_ctx_t *ctx, csch_text_t *t, csch_cpen_t *p
 			rnd_render->draw_line(ctx->gc, C2P(t->inst1.x), C2P(t->inst1.y), C2P((csch_coord_t)(t->inst1.x + vx*3000)), C2P((csch_coord_t)(t->inst1.y + vy*3000)));
 		}
 	}
-
 }
 
-vtc0_t draw_poly_x, draw_poly_y;
-
-static void draw_poly_reset(void)
-{
-	draw_poly_x.used = draw_poly_y.used = 0;
-}
-
-static void draw_poly_append(rnd_coord_t x, rnd_coord_t y)
-{
-	/* do not add duplicate points */
-	if (draw_poly_x.used > 0) {
-		if ((draw_poly_x.array[draw_poly_x.used-1] == x) && (draw_poly_y.array[draw_poly_x.used-1] == y))
-			return;
-	}
-
-	vtc0_append(&draw_poly_x, x);
-	vtc0_append(&draw_poly_y, y);
-}
-
-static void draw_poly_uninit(void)
-{
-	vtc0_uninit(&draw_poly_x);
-	vtc0_uninit(&draw_poly_y);
-}
-
-csch_inline void draw_poly_arc(csch_arc_t *arc)
-{
-	double sa = arc->inst.c.start, da = arc->inst.c.delta;
-	long int n, steps;
-	double a, step;
-
-	if (rnd_render != NULL) {
-		double cpp = rnd_render->coord_per_pix;
-
-		if (cpp <= 0)
-			cpp = RND_MIL_TO_COORD(1000.0)/600.0; /* assume 600 DPI, for the exporters */
-
-		steps = (double)C2P(arc->inst.c.r) * (double)da / cpp / 10.0;
-		if (steps < 0)
-			steps= - steps;
-		if (steps < 3)
-			steps = 3;
-		else if (steps > 1000)
-			steps = 1000;
-	}
-	else
-		steps = 3;
-
-
-	step = da/steps;
-	for(a = sa, n = 0; n < steps; a += step, n++) {
-		csch_coord_t x, y;
-		x = rnd_round(arc->inst.c.c.x + arc->inst.c.r * cos(a));
-		y = rnd_round(arc->inst.c.c.y + arc->inst.c.r * sin(a));
-		draw_poly_append(C2P(x), C2P(y));
-	}
-}
-
-csch_inline void draw_layer_poly(draw_ctx_t *ctx, csch_cpoly_t *p, csch_cpen_t *stroke, int selected)
-{
-	long n;
-	csch_coutline_t *o;
-
-
-	if (p->has_fill) {
-		rnd_render->set_color(ctx->gc, sch_rnd_fill_color(ctx, &p->hdr, csch_fill_fallback(p->hdr.sheet, p, ctx->xform == NULL ? NULL : ctx->xform->fallback_pen), selected));
-		draw_poly_reset();
-		for(n = 0, o = p->outline.array; n < p->outline.used; n++, o++) {
-			switch(o->hdr.type) {
-				case CSCH_CTYPE_LINE:
-					draw_poly_append(C2P(o->line.inst.c.p1.x), C2P(o->line.inst.c.p1.y));
-					draw_poly_append(C2P(o->line.inst.c.p2.x), C2P(o->line.inst.c.p2.y));
-					break;
-				case CSCH_CTYPE_ARC:
-					draw_poly_arc(&o->arc);
-					break;
-				default:
-					/* invalid object in contour, already warned */
-					break;
-			}
-		}
-		rnd_render->fill_polygon(ctx->gc, draw_poly_x.used, draw_poly_x.array, draw_poly_y.array);
-	}
-
-	if (p->has_stroke) {
-		rnd_render->set_color(ctx->gc, sch_rnd_stroke_color(ctx, &p->hdr, stroke, selected));
-		rnd_hid_set_line_cap(ctx->gc, pen_cap(stroke));
-		rnd_hid_set_line_width(ctx->gc, C2P(stroke->size));
-
-		for(n = 0, o = p->outline.array; n < p->outline.used; n++, o++) {
-			switch(o->hdr.type) {
-				case CSCH_CTYPE_LINE:
-					rnd_render->draw_line(ctx->gc, C2P(o->line.inst.c.p1.x), C2P(o->line.inst.c.p1.y), C2P(o->line.inst.c.p2.x), C2P(o->line.inst.c.p2.y));
-					break;
-				case CSCH_CTYPE_ARC:
-					rnd_render->draw_arc(ctx->gc, C2P(o->arc.inst.c.c.x), C2P(o->arc.inst.c.c.y), C2P(o->arc.inst.c.r), C2P(o->arc.inst.c.r), (180.0 - o->arc.inst.c.start * RND_RAD_TO_DEG), -(o->arc.inst.c.delta * RND_RAD_TO_DEG));
-					break;
-				default:
-					/* invalid, do not draw */
-					break;
-			}
-		}
-	}
-}
-
-csch_inline void draw_layer_arc(draw_ctx_t *ctx, csch_arc_t *a, csch_cpen_t *pen, int selected)
+RND_INLINE void draw_layer_arc(draw_ctx_t *ctx, csch_arc_t *a, csch_cpen_t *pen, int selected)
 {
 	rnd_render->set_color(ctx->gc, sch_rnd_stroke_color(ctx, &a->hdr, pen, selected));
 	rnd_hid_set_line_cap(ctx->gc, pen_cap(pen));
@@ -415,7 +314,7 @@ static csch_rtree_dir_t predraw_layer_obj(void *ctx_, void *obj_, const csch_rtr
 			{
 				csch_text_t *t = (csch_text_t *)obj;
 				if ((rnd_render->draw_pixmap != NULL) && (t->pixmap == NULL))
-					vtp0_append(&ctx->text_update, t);
+					vtp0_append(&ctx->objlist, t);
 			}
 			break;
 		default: break;
@@ -449,11 +348,83 @@ static void draw_grp_meta(draw_ctx_t *ctx, csch_cgrp_t *grp)
 			rnd_render->draw_line(ctx->gc, C2P(grp->hdr.bbox.x1 + 1000), C2P(grp->hdr.bbox.y2 - 1000), C2P(grp->hdr.bbox.x1 + 2000), C2P(grp->hdr.bbox.y2 - 1000));
 			rnd_render->draw_line(ctx->gc, C2P(grp->hdr.bbox.x1 + 1000), C2P(grp->hdr.bbox.y2 - 2000), C2P(grp->hdr.bbox.x1 + 1500), C2P(grp->hdr.bbox.y2 - 2000));
 		}
+	}
 
+	/* mark origin */
+	if (vis_meta_sym && (grp->role == CSCH_ROLE_SYMBOL)) {
+		rnd_render->set_color(ctx->gc, &conf_core.appearance.color.symbol_meta_embed);
+		rnd_hid_set_line_cap(ctx->gc, rnd_cap_round);
+		rnd_hid_set_line_width(ctx->gc, -1);
+		rnd_render->draw_line(ctx->gc, C2P(grp->x - 100), C2P(grp->y - 100), C2P(grp->x + 100), C2P(grp->y + 100));
+		rnd_render->draw_line(ctx->gc, C2P(grp->x + 100), C2P(grp->y - 100), C2P(grp->x - 100), C2P(grp->y + 100));
 	}
 }
 
-static csch_rtree_dir_t draw_layer_obj(void *ctx_, void *obj_, const csch_rtree_box_t *box)
+static csch_rtree_dir_t collect_layer_obj_fill(void *ctx_, void *obj_, const csch_rtree_box_t *box)
+{
+	draw_ctx_t *ctx = (draw_ctx_t *)ctx_;
+	csch_chdr_t *obj = obj_;
+
+	switch(obj->type) {
+		case CSCH_CTYPE_POLY:
+			{
+				csch_cpoly_t *poly = (csch_cpoly_t *)obj;
+				if (poly->has_fill) {
+					if (poly->area < 0)
+						draw_poly_calc_area(ctx, poly);
+					vtp0_append(&ctx->objlist, obj);
+				}
+			}
+			break;
+
+		case CSCH_CTYPE_ARC:
+		case CSCH_CTYPE_LINE:
+		case CSCH_CTYPE_TEXT:
+		case CSCH_CTYPE_CONN:
+		case CSCH_CTYPE_BITMAP:
+		case CSCH_CTYPE_GRP:
+		case CSCH_CTYPE_GRP_REF:
+			/* no fill */
+			break;
+
+		case CSCH_CTYPE_PEN:
+		case CSCH_CTYPE_invalid:
+		case CSCH_CTYPE_max:
+			/* no graphical representation */
+			break;
+	}
+
+	return csch_RTREE_DIR_FOUND_CONT;
+}
+
+
+static void draw_layer_obj_fill(draw_ctx_t *ctx, csch_chdr_t *obj)
+{
+	int sel = csch_chdr_is_selected(obj);
+
+	switch(obj->type) {
+		case CSCH_CTYPE_POLY: draw_layer_poly_fill(ctx, (csch_cpoly_t *)obj, sel); break;
+
+		case CSCH_CTYPE_ARC:
+		case CSCH_CTYPE_LINE:
+		case CSCH_CTYPE_TEXT:
+		case CSCH_CTYPE_CONN:
+		case CSCH_CTYPE_BITMAP:
+		case CSCH_CTYPE_GRP:
+		case CSCH_CTYPE_GRP_REF:
+			/* no fill */
+			break;
+
+		case CSCH_CTYPE_PEN:
+		case CSCH_CTYPE_invalid:
+		case CSCH_CTYPE_max:
+			/* no graphical representation */
+			break;
+	}
+}
+
+
+static csch_rtree_dir_t draw_layer_obj_stroke(void *ctx_, void *obj_, const csch_rtree_box_t *box)
 {
 	draw_ctx_t *ctx = (draw_ctx_t *)ctx_;
 	csch_chdr_t *obj = obj_;
@@ -462,7 +433,7 @@ static csch_rtree_dir_t draw_layer_obj(void *ctx_, void *obj_, const csch_rtree_
 
 	switch(obj->type) {
 		case CSCH_CTYPE_LINE: draw_layer_line(ctx, (csch_line_t *)obj, stroke, sel); break;
-		case CSCH_CTYPE_POLY: draw_layer_poly(ctx, (csch_cpoly_t *)obj, stroke, sel); break;
+		case CSCH_CTYPE_POLY: draw_layer_poly_stroke(ctx, (csch_cpoly_t *)obj, stroke, sel); break;
 		case CSCH_CTYPE_ARC:  draw_layer_arc(ctx, (csch_arc_t *)obj, stroke, sel); break;
 		case CSCH_CTYPE_TEXT: draw_layer_text(ctx, (csch_text_t *)obj, stroke, sel); break;
 		case CSCH_CTYPE_CONN: draw_layer_conn(ctx, (csch_conn_t *)obj); break;
@@ -487,63 +458,150 @@ static csch_rtree_dir_t draw_layer_obj(void *ctx_, void *obj_, const csch_rtree_
 static csch_rtree_dir_t draw_layer_obj_nojunc(void *ctx_, void *obj_, const csch_rtree_box_t *box)
 {
 	if (!csch_obj_is_junction(obj_))
-		return draw_layer_obj(ctx_, obj_, box);
+		return draw_layer_obj_stroke(ctx_, obj_, box);
 	return csch_RTREE_DIR_NOT_FOUND_CONT;
 }
 
 static csch_rtree_dir_t draw_layer_obj_junc(void *ctx_, void *obj_, const csch_rtree_box_t *box)
 {
 	if (csch_obj_is_junction(obj_))
-		draw_layer_obj(ctx_, obj_, box);
+		draw_layer_obj_stroke(ctx_, obj_, box);
 	return csch_RTREE_DIR_NOT_FOUND_CONT;
 }
 
+static int fill_area_cmp(const void *a_, const void *b_)
+{
+	const csch_cpoly_t **a = (const csch_cpoly_t **)a_, **b = (const csch_cpoly_t **)b_;
+	if ((*a)->area < (*b)->area) return 1;
+	return -1;
+}
 
-static void draw_layer(csch_sheet_t *sheet, csch_displayer_t layer, const csch_rtree_box_t *bbox, rnd_hid_gc_t gc, rnd_xform_t *xform)
+RND_INLINE void draw_layer_fill(draw_ctx_t *ctx, csch_displayer_t layer, const csch_rtree_box_t *bbox)
 {
-	draw_ctx_t ctx = {0};
 	long n;
 
 	if ((layer == CSCH_DSPLY_SYMBOL_META) || (layer == CSCH_DSPLY_TEXT_META))
 		return;
 
-	ctx.sheet = sheet;
-	ctx.gc = gc;
-	ctx.xform = xform;
+	ctx->objlist.used = 0;
 
-	csch_rtree_search_obj(&sheet->dsply[layer], bbox, predraw_layer_obj, &ctx);
+	csch_rtree_search_obj(&ctx->sheet->dsply_fill[layer], bbox, collect_layer_obj_fill, ctx);
 
-	for(n = 0; n < ctx.text_update.used; n++) {
-		csch_chdr_t *obj = ctx.text_update.array[n];
-		sch_rnd_font_text_update(sheet, (csch_text_t *)obj, csch_stroke_fallback_(obj, ctx.xform == NULL ? NULL : ctx.xform->fallback_pen));
+	qsort(ctx->objlist.array, ctx->objlist.used, sizeof(void *), fill_area_cmp);
+	for(n = 0; n < ctx->objlist.used; n++)
+		draw_layer_obj_fill(ctx, ctx->objlist.array[n]);
+}
+
+
+RND_INLINE void draw_layer_stroke(draw_ctx_t *ctx, csch_displayer_t layer, const csch_rtree_box_t *bbox)
+{
+	long n;
+
+	if ((layer == CSCH_DSPLY_SYMBOL_META) || (layer == CSCH_DSPLY_TEXT_META))
+		return;
+
+	ctx->objlist.used = 0;
+
+	csch_rtree_search_obj(&ctx->sheet->dsply[layer], bbox, predraw_layer_obj, ctx);
+
+	for(n = 0; n < ctx->objlist.used; n++) {
+		csch_chdr_t *obj = ctx->objlist.array[n];
+		sch_rnd_font_text_update(ctx->sheet, (csch_text_t *)obj, csch_stroke_fallback_(obj, ctx->xform == NULL ? NULL : ctx->xform->fallback_pen));
 	}
-	vtp0_uninit(&ctx.text_update);
 
 	if (layer == CSCH_DSPLY_WIRE) {
 		/* have to draw in two steps so junctions are always above wires */
-		csch_rtree_search_obj(&sheet->dsply[layer], bbox, draw_layer_obj_nojunc, &ctx);
-		csch_rtree_search_obj(&sheet->dsply[layer], bbox, draw_layer_obj_junc, &ctx);
+		csch_rtree_search_obj(&ctx->sheet->dsply[layer], bbox, draw_layer_obj_nojunc, ctx);
+		csch_rtree_search_obj(&ctx->sheet->dsply[layer], bbox, draw_layer_obj_junc, ctx);
 	}
 	else
-		csch_rtree_search_obj(&sheet->dsply[layer], bbox, draw_layer_obj, &ctx);
+		csch_rtree_search_obj(&ctx->sheet->dsply[layer], bbox, draw_layer_obj_stroke, ctx);
 }
 
-void sch_rnd_draw_sheet(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
+RND_INLINE void sch_rnd_draw_sheet_graphical(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
 {
 	int n;
 	csch_rtree_box_t bb;
+	draw_ctx_t ctx = {0};
+
+	ctx.sheet = sheet;
+	ctx.gc = gc;
+	ctx.xform = xform_caller;
 
 	bb.x1 = P2C(region->view.X1); bb.y1 = P2C(region->view.Y1);
 	bb.x2 = P2C(region->view.X2); bb.y2 = P2C(region->view.Y2);
 
 	for(n = 0; n < CSCH_DSPLY_max; n++) {
 		int use_local = (xform_caller != NULL) && xform_caller->use_local_vis;
-		int vis =  use_local ? xform_caller->local_vis[n] : csch_layer_vis[n];
+		int vis = use_local ? xform_caller->local_vis[n] : csch_layer_vis[n];
 		if (vis)
-			draw_layer(sheet, n, &bb, gc, xform_caller);
+			draw_layer_fill(&ctx, n, &bb);
+	}
+
+	for(n = 0; n < CSCH_DSPLY_max; n++) {
+		int use_local = (xform_caller != NULL) && xform_caller->use_local_vis;
+		int vis = use_local ? xform_caller->local_vis[n] : csch_layer_vis[n];
+		if (vis)
+			draw_layer_stroke(&ctx, n, &bb);
+	}
+
+	vtp0_uninit(&ctx.objlist);
+}
+
+RND_INLINE void sch_rnd_draw_sheet_non_graphical(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
+{
+	static csch_text_t t;
+	static csch_cpen_t pen;
+	static int inited = 0;
+	draw_ctx_t ctx = {0};
+	void *cookie = NULL;
+	long cnt = 0;
+	csch_coord_t y, step = 4000;
+	char *line;
+
+	if (!inited) {
+		inited = 1;
+
+		pen.size = 250;
+		pen.color = conf_core.appearance.color.non_graphical_text;
+		pen.font_height = 3000;
+		pen.font_family = "sans";
+		t.inst1.x = 0;
+		t.inst1.y = 0;
+	}
+
+	ctx.sheet = sheet;
+	ctx.gc = gc;
+	ctx.xform = NULL;
+
+	rnd_render->set_color(gc, sch_rnd_stroke_color(&ctx, &t.hdr, &pen, 0));
+
+	if ((sheet->non_graphical_impl == NULL) || (sheet->non_graphical_impl->draw_getline == NULL)) {
+		t.bbox_calced = 0;
+		t.rtext = "non-graphical sheet.";
+		sch_rnd_font_text_render(sheet, gc, &t, &pen);
+		return;
+	}
+
+	y = sheet->bbox.y2 - step;
+	while((line = sheet->non_graphical_impl->draw_getline(sheet, &cnt, &cookie)) != NULL) {
+		t.bbox_calced = 0;
+		t.inst1.y = y;
+		t.rtext = line;
+		sch_rnd_font_text_render(sheet, gc, &t, &pen);
+		y -= step;
 	}
 }
 
+void sch_rnd_draw_sheet(csch_sheet_t *sheet, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
+{
+	if (sheet->non_graphical)
+		sch_rnd_draw_sheet_non_graphical(sheet, gc, region, xform_caller);
+	else
+		sch_rnd_draw_sheet_graphical(sheet, gc, region, xform_caller);
+}
+
+
 void sch_rnd_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller)
 {
 	rnd_hid_gc_t gc;
@@ -593,6 +651,17 @@ void sch_rnd_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e)
 	rnd_render->destroy_gc(gc);
 }
 
+int sch_draw_setup_non_graphical(csch_sheet_t *sheet, long lines)
+{
+	sheet->bbox.x2 = 210*1000;
+	sheet->bbox.y2 = lines * 4000;
+	sheet->bbox_changed = 1;
+	rnd_conf_set(RND_CFR_DESIGN, "appearance/color/background", -1, conf_core.appearance.color.non_graphical_background.str, RND_POL_OVERWRITE);
+	rnd_conf_set(RND_CFR_DESIGN, "editor/draw_grid", -1, "0", RND_POL_OVERWRITE);
+	rnd_event(&sheet->hidlib, CSCH_EVENT_SHEET_EDITED, NULL);
+	return 0;
+}
+
 void sch_rnd_redraw(rnd_design_t *target)
 {
 	rnd_design_t *curr = rnd_multi_get_current();
