@@ -52,19 +52,19 @@ typedef struct {
 	unsigned backref:1;/* floaters draw a line back to their original position */
 } xor_ctx_t;
 
-csch_inline void draw_xor_line(xor_ctx_t *ctx, csch_line_t *l, csch_cpen_t *stroke)
+RND_INLINE void draw_xor_line(xor_ctx_t *ctx, csch_line_t *l, csch_cpen_t *stroke)
 {
 	if (ctx->thin || ctx->wire)
 		rnd_render->draw_line(ctx->gc, C2P(l->inst.c.p1.x + ctx->dx), C2P(l->inst.c.p1.y + ctx->dy), C2P(l->inst.c.p2.x + ctx->dx), C2P(l->inst.c.p2.y + ctx->dy));
 }
 
-csch_inline void draw_xor_arc(xor_ctx_t *ctx, csch_arc_t *a, csch_cpen_t *stroke)
+RND_INLINE void draw_xor_arc(xor_ctx_t *ctx, csch_arc_t *a, csch_cpen_t *stroke)
 {
 	if (ctx->thin || ctx->wire)
 		rnd_render->draw_arc(ctx->gc, C2P(a->inst.c.c.x + ctx->dx), C2P(a->inst.c.c.y + ctx->dy), C2P(a->inst.c.r), C2P(a->inst.c.r), (180.0 - a->inst.c.start * RND_RAD_TO_DEG), -(a->inst.c.delta * RND_RAD_TO_DEG));
 }
 
-csch_inline void draw_xor_text(xor_ctx_t *ctx, csch_text_t *t, csch_cpen_t *stroke)
+RND_INLINE void draw_xor_text(xor_ctx_t *ctx, csch_text_t *t, csch_cpen_t *stroke)
 {
 	if (ctx->thin || ctx->wire) {
 		/* if there's no spec2 calculated for a non-bbox-specified text, need to update it to get real dimensions */
@@ -80,7 +80,7 @@ csch_inline void draw_xor_text(xor_ctx_t *ctx, csch_text_t *t, csch_cpen_t *stro
 	}
 }
 
-csch_inline void draw_xor_poly(xor_ctx_t *ctx, csch_cpoly_t *p, csch_cpen_t *stroke)
+RND_INLINE void draw_xor_poly(xor_ctx_t *ctx, csch_cpoly_t *p, csch_cpen_t *stroke)
 {
 	int save;
 	long n;
@@ -100,7 +100,7 @@ csch_inline void draw_xor_poly(xor_ctx_t *ctx, csch_cpoly_t *p, csch_cpen_t *str
 
 static void sch_rnd_xor_draw_obj_(xor_ctx_t *ctx, csch_chdr_t *obj);
 
-csch_inline void draw_xor_grp(xor_ctx_t *ctx, csch_cgrp_t *grp)
+RND_INLINE void draw_xor_grp(xor_ctx_t *ctx, csch_cgrp_t *grp)
 {
 	htip_entry_t *e;
 	for(e = htip_first(&grp->id2obj); e != NULL; e = htip_next(&grp->id2obj, e))
