@@ -156,7 +156,7 @@ void sch_rnd_backup(csch_sheet_t *sheet)
 	char *filename = NULL;
 	const char *fmt = "lihata";
 
-	if (sheet->hidlib.fullpath[0] == '<')
+	if ((sheet->hidlib.fullpath == NULL) || (sheet->hidlib.fullpath[0] == '<'))
 		return; /* do not make backups of <none> */
 
 	filename = rnd_build_fn(&sheet->hidlib, conf_core.rc.backup_name);
