@@ -48,21 +48,21 @@
 sch_rnd_export_appspec_t sch_rnd_no_appspec = {0};
 
 
-csch_inline void vis_invert(rnd_xform_t *xform)
+RND_INLINE void vis_invert(rnd_xform_t *xform)
 {
 	int n;
 	for(n = 0; n < CSCH_DSPLY_max; n++)
 		xform->local_vis[n] = !xform->local_vis[n];
 }
 
-csch_inline void vis_set_all(rnd_xform_t *xform, int val)
+RND_INLINE void vis_set_all(rnd_xform_t *xform, int val)
 {
 	int n;
 	for(n = 0; n < CSCH_DSPLY_max; n++)
 		xform->local_vis[n] = val;
 }
 
-csch_inline void vis_set_by_name(rnd_xform_t *xform, const char *name, int len, int val)
+RND_INLINE void vis_set_by_name(rnd_xform_t *xform, const char *name, int len, int val)
 {
 	int n, set = 0;
 
