@@ -35,6 +35,8 @@
 #include <libcschem/concrete.h>
 #include <libcschem/plug_library.h>
 #include <libcschem/event.h>
+#include <libcschem/cnc_grp.h>
+#include <libcschem/operation.h>
 #include <libcschem/project.h>
 #include <libcschem/plug_io.h>
 #include <libcschem/util_path.h>
@@ -85,6 +87,81 @@ static fgw_error_t csch_act_SymlibRehash(fgw_arg_t *res, int argc, fgw_arg_t *ar
 	return 0;
 }
 
+static const char csch_acts_DevmaplibRehash[] = "DevmaplibRehash()";
+static const char csch_acth_DevmaplibRehash[] = "Rebuild the in-memory tree of devmaps";
+static fgw_error_t csch_act_DevmaplibRehash(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	csch_sheet_t *sheet = CSCH_ACT_SHEET;
+	csch_lib_master_t *master = csch_lib_get_master("devmap", 1);
+
+	csch_lib_clear_sheet_lib(sheet, master->uid);
+	csch_lib_add_all(sheet, master, &conf_core.rc.library_search_paths);
+	rnd_event(&sheet->hidlib, CSCH_EVENT_LIBRARY_CHANGED, NULL);
+	RND_ACT_IRES(0);
+	return 0;
+}
+
+static const char csch_acts_DevmaplibCleanLocal[] = "DevmaplibCleanLocal()";
+static const char csch_acth_DevmaplibCleanLocal[] = "Remove all local-lib devmaps from the current sheet; they are re-loaded from external libs into the local lib upon the next compilation. Useful to refresh local lib from disk.";
+static fgw_error_t csch_act_DevmaplibCleanLocal(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	csch_sheet_t *sheet = CSCH_ACT_SHEET;
+	long cnt = 0, n, i;
+	csch_lib_root_t *libroot;
+	csch_lib_master_t *master = csch_lib_get_master("devmap", 0);
+
+	libroot = sheet->local_libs.array[master->uid];
+	for(n = 0; n < libroot->roots.used; n++) {
+		csch_lib_t *root = libroot->roots.array[n];
+		if (strcmp(root->name, "<local>") == 0) {
+			for(i = root->children.used-1; i >= 0; i--) {
+				csch_lib_t *le = root->children.array[i];
+				csch_lib_remove(le);
+				cnt++;
+			}
+			break;
+		}
+	}
+
+	rnd_message(RND_MSG_INFO, "Removed %ld devmap(s) from the local lib of the sheet\n", cnt);
+
+	rnd_event(&sheet->hidlib, CSCH_EVENT_LIBRARY_CHANGED, NULL);
+	RND_ACT_IRES(0);
+	return 0;
+}
+
+static const char csch_acts_SymlibReloadAllLocal[] = "SymlibReloadAllLocal()";
+static const char csch_acth_SymlibReloadAllLocal[] = "Replace all local symbols from a newer version of the same symbol from the symbol library";
+static fgw_error_t csch_act_SymlibReloadAllLocal(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	csch_sheet_t *sheet = CSCH_ACT_SHEET;
+	long cnt = 0, n, i;
+	csch_lib_root_t *libroot;
+	csch_lib_master_t *master = csch_lib_get_master("symbol", 0);
+
+	libroot = sheet->local_libs.array[master->uid];
+	for(n = 0; n < libroot->roots.used; n++) {
+		csch_lib_t *root = libroot->roots.array[n];
+		if (strcmp(root->name, "<local>") == 0) {
+			for(i = root->children.used-1; i >= 0; i--) {
+				csch_lib_t *l = root->children.array[i];
+				if ((l != NULL) && (l->backend != NULL) && (l->backend->loc_refresh_from_ext != NULL)) {
+					if (l->backend->loc_refresh_from_ext(sheet, l) == 0)
+						cnt++;
+				}
+			}
+			break;
+		}
+	}
+
+	rnd_message(RND_MSG_INFO, "Reloaded %ld local lib symbol(s) from external libs\n", cnt);
+
+	rnd_event(&sheet->hidlib, CSCH_EVENT_LIBRARY_CHANGED, NULL);
+	RND_ACT_IRES(0);
+	return 0;
+}
+
+
 static const char csch_acts_Revert[] = "Revert([sheet|project])";
 static const char csch_acth_Revert[] = "Revert to on-disk version of file(s). Default target is sheet.";
 fgw_error_t csch_act_Revert(fgw_arg_t *res, int argc, fgw_arg_t *argv)
@@ -542,6 +619,9 @@ fgw_error_t csch_act_SaveAll(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 static rnd_action_t file_action_list[] = {
 	{"Quit", csch_act_Quit, csch_acth_Quit, csch_acts_Quit},
 	{"SymlibRehash", csch_act_SymlibRehash, csch_acth_SymlibRehash, csch_acts_SymlibRehash},
+	{"SymlibReloadAllLocal", csch_act_SymlibReloadAllLocal, csch_acth_SymlibReloadAllLocal, csch_acts_SymlibReloadAllLocal},
+	{"DevmaplibRehash", csch_act_DevmaplibRehash, csch_acth_DevmaplibRehash, csch_acts_DevmaplibRehash},
+	{"DevmaplibCleanLocal", csch_act_DevmaplibCleanLocal, csch_acth_DevmaplibCleanLocal, csch_acts_DevmaplibCleanLocal},
 	{"Revert", csch_act_Revert, csch_acth_Revert, csch_acts_Revert},
 	{"New", csch_act_New, csch_acth_New, csch_acts_New},
 	{"ProjectNew", csch_act_ProjectNew, csch_acth_ProjectNew, csch_acts_ProjectNew},
