@@ -462,6 +462,9 @@ static void rf_text_render(csch_sheet_t *sheet, rnd_hid_gc_t gc, csch_text_t *t,
 
 	deg = t->inst_raw_rot;
 
+	if ((deg > 360.0) || (deg < -360.0))
+		deg = fmod(deg, 360.0);
+
 	/* rnd_trace("deg=%f %d %d '%s' \n", deg, mirx, miry, text_str); */
 
 	x = xo + C2P(mirx ? -t->off_x : +t->off_x) - (mirx ? C2P(t->net_sx) : 0);
