@@ -51,7 +51,7 @@
 #include <libcschem/undo.h>
 
 /* print usage lines */
-static inline void u(const char *fmt, ...)
+RND_INLINE void u(const char *fmt, ...)
 {
 	va_list ap;
 	va_start(ap, fmt);
