@@ -33,6 +33,7 @@
 #include <librnd/core/compat_fs.h>
 #include <librnd/hid/hid.h>
 #include <librnd/core/event.h>
+#include <librnd/core/rnd_conf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/compat_lrealpath.h>
 #include <librnd/core/safe_fs.h>
@@ -43,6 +44,8 @@
 #include <libcschem/util_project.h>
 #include <libcschem/event.h>
 
+#include <libcschem/plug_io.h>
+
 #include "conf_core.h"
 #include "sheet.h"
 #include "project.h"
@@ -69,7 +72,7 @@ static csch_project_t *sch_rnd_multi_load_project_(const char *project_fn)
 	csch_project_t *prj = htsp_get(&rnd_projects, project_fn);
 	if (prj == NULL) {
 		char *pfn = rnd_strdup(project_fn);
-		prj = csch_load_project_by_sheet_name(pfn, 0);
+		prj = csch_load_project_by_sheet_name(pfn, 0, rnd_conf.rc.quiet);
 		htsp_set(&rnd_projects, pfn, prj);
 	}
 	return prj;
@@ -183,6 +186,17 @@ int sch_rnd_is_fn_project_file(const char *fn)
 	return strcmp(end, "project.lht") == 0;
 }
 
+/* sch-rnd, app-specific tasks on any newly loaded sheet */
+static void sch_rnd_multi_load_post(csch_sheet_t *sheet)
+{
+	rnd_tool_select_by_name(&sheet->hidlib, "arrow");
+
+	rnd_event(&sheet->hidlib, CSCH_EVENT_SHEET_POSTLOAD, NULL);
+	rnd_event(&sheet->hidlib, RND_EVENT_LOAD_POST, NULL);
+
+	sch_rnd_prj_postproc(sheet->hidlib.project);
+}
+
 static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const char *project_fn, int *is_project, rnd_conflist_t *root_sheets_out, rnd_conflist_t *aux_sheets_out)
 {
 	csch_sheet_t *sheet;
@@ -191,6 +205,8 @@ static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const
 	char *freeme = NULL;
 	int lres;
 	rnd_conf_state_t *ncs;
+	FILE *f = NULL;
+	void *cookie, *io;
 
 	if ((project_fn == NULL) && ((fmt == NULL) || (*fmt == '\0'))) {
 		if (sch_rnd_is_fn_project_file(fn)) {
@@ -200,6 +216,34 @@ static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const
 		}
 	}
 
+	/* try load as bundled */
+	{
+		prj = htsp_get(&rnd_projects, (char *)fn);
+		if (prj != NULL) { /* already loaded */
+			if (prj->hdr.designs.used > 0)
+				return prj->hdr.designs.array[0];
+			return NULL;
+		}
+
+		cookie = csch_test_parse_bundled(NULL, real_fn, CSCH_IOTYP_SHEET, &f, &io);
+		if (cookie != NULL) {
+			if (f != NULL) {
+				sheet = csch_load_bundled_sheets(cookie, io, f, fn, sch_rnd_multi_load_post);
+				fclose(f);
+				if (root_sheets_out != NULL)
+					memcpy(root_sheets_out, &conf_core.prj.root_sheets, sizeof(rnd_conflist_t));
+
+				if (sheet != NULL) {
+					prj = (csch_project_t *)sheet->hidlib.project;
+					htsp_set(&rnd_projects, (char *)fn, prj);
+				}
+				return sheet;
+			}
+		}
+	}
+
+	/* not bundled; single sheet loader with all the extra rounds for project files */
+
 	if (is_project != NULL)
 		*is_project = 0;
 
@@ -230,7 +274,9 @@ static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const
 		}
 	}
 
-	lres = csch_project_load_sheet(prj, real_fn, fmt, &sheet, 0);
+	lres = csch_project_load_sheet(prj, real_fn, fmt, &sheet, rnd_conf.rc.quiet, f);
+	if (f != NULL)
+		fclose(f);
 	rnd_conf_multi_post_new_design(&ncs, &sheet->hidlib);
 	if (lres != 0) {
 		free(freeme);
@@ -240,20 +286,14 @@ static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const
 	rnd_multi_load_prj_for_dsg(&sheet->hidlib);
 
 	rnd_conf_state_new_design(&sheet->hidlib);
-
 	rnd_conf_merge_all(NULL); /* to get the project file applied */
-	sch_rnd_prj_postproc(prj);
-
-	rnd_tool_select_by_name(&sheet->hidlib, "arrow");
-
-	rnd_event(&sheet->hidlib, CSCH_EVENT_SHEET_POSTLOAD, NULL);
-	rnd_event(&sheet->hidlib, RND_EVENT_LOAD_POST, NULL);
 
 	if (root_sheets_out != NULL)
 		memcpy(root_sheets_out, &conf_core.prj.root_sheets, sizeof(rnd_conflist_t));
 	if (aux_sheets_out != NULL)
 		memcpy(aux_sheets_out, &conf_core.prj.aux_sheets, sizeof(rnd_conflist_t));
 
+	sch_rnd_multi_load_post(sheet);
 	rnd_conf_state_save(sheet->hidlib.saved_rnd_conf);
 
 	free(freeme);
@@ -262,7 +302,7 @@ static csch_sheet_t *sch_rnd_multi_load_(const char *fn, const char *fmt, const
 
 csch_sheet_t *sch_rnd_multi_load(const char *fn, const char *fmt, int *is_project)
 {
-	rnd_conflist_t roots, aux;
+	rnd_conflist_t roots = {0}, aux = {0};
 	csch_sheet_t *sheet;
 	
 	sheet = sch_rnd_multi_load_(fn, fmt, NULL, is_project, &roots, &aux);
@@ -373,3 +413,13 @@ void sch_rnd_multi_uninit(void)
 {
 	rnd_conf_state_plug_unreg_all_cookie(sch_rnd_multi_cookie);
 }
+
+void sch_rnd_sheet_free_all(void)
+{
+	rnd_design_t *curr, *next;
+	for(curr = gdl_first(&rnd_designs); curr != NULL; curr = next) {
+		next = gdl_next(&rnd_designs, curr);
+		gdl_remove(&rnd_designs, curr, link);
+		csch_sheet_free((csch_sheet_t *)curr);
+	}
+}
