@@ -25,5 +25,8 @@ void sch_rnd_multi_unload(csch_sheet_t *s);
 int sch_rnd_is_fn_project_file(const char *fn);
 
 
+/* Free all sheets currently loaded (useful on exit) */
+void sch_rnd_sheet_free_all(void);
+
 void sch_rnd_multi_init(void);
 void sch_rnd_multi_uninit(void);
