@@ -54,7 +54,7 @@ static const char sheet_cookie[] = "sch-rnd/sheet.c";
 
 extern const char *default_sheet_internal;
 
-csch_inline rnd_coord_t sheet_attr_crd(csch_sheet_t *sheet, const char *key, rnd_coord_t defval)
+RND_INLINE rnd_coord_t sheet_attr_crd(csch_sheet_t *sheet, const char *key, rnd_coord_t defval)
 {
 	const char *s = csch_attrib_get_str(&sheet->direct.attr, key);
 	double val;
@@ -96,19 +96,21 @@ void sch_rnd_sheet_warn_size(csch_sheet_t *sheet, csch_coord_t x1, csch_coord_t
 
 void sch_rnd_sheet_postproc(csch_sheet_t *sheet)
 {
-	rnd_coord_t min_x = sheet_attr_crd(sheet, "drawing_min_width", 0);
-	rnd_coord_t min_y = sheet_attr_crd(sheet, "drawing_min_height", 0);
-
 	sheet->hidlib.grid = rnd_conf.editor.grid;
-	csch_sheet_bbox_update(sheet);
 
-	sheet->hidlib.dwg.X1 = C2P(sheet->bbox.x1);
-	sheet->hidlib.dwg.Y1 = C2P(sheet->bbox.y1);
-	sheet->hidlib.dwg.X2 = C2P(RND_MAX(min_x, sheet->bbox.x2));
-	sheet->hidlib.dwg.Y2 = C2P(RND_MAX(min_y, sheet->bbox.y2));
+	if (!sheet->non_graphical) {
+		rnd_coord_t min_x = sheet_attr_crd(sheet, "drawing_min_width", 0);
+		rnd_coord_t min_y = sheet_attr_crd(sheet, "drawing_min_height", 0);
 
-	sch_rnd_sheet_warn_size(sheet, sheet->bbox.x1, sheet->bbox.y1, RND_MAX(min_x, sheet->bbox.x2), RND_MAX(min_y, sheet->bbox.y2));
+		csch_sheet_bbox_update(sheet);
 
+		sheet->hidlib.dwg.X1 = C2P(sheet->bbox.x1);
+		sheet->hidlib.dwg.Y1 = C2P(sheet->bbox.y1);
+		sheet->hidlib.dwg.X2 = C2P(RND_MAX(min_x, sheet->bbox.x2));
+		sheet->hidlib.dwg.Y2 = C2P(RND_MAX(min_y, sheet->bbox.y2));
+
+		sch_rnd_sheet_warn_size(sheet, sheet->bbox.x1, sheet->bbox.y1, RND_MAX(min_x, sheet->bbox.x2), RND_MAX(min_y, sheet->bbox.y2));
+	}
 
 	if (sheet->hidlib.fullpath != NULL) {
 		sheet->design_dir = rnd_dirname(sheet->hidlib.fullpath);
@@ -120,9 +122,11 @@ void sch_rnd_sheet_postproc(csch_sheet_t *sheet)
 	}
 	rnd_conf_ro("rc/path/design");
 
-	/* This works from load only because the conf state is already set up for
-	   the new sheet, even tho librnd's current sheet is not yet set */
-	csch_lib_add_all(sheet, csch_lib_get_master("symbol", 1), &conf_core.rc.library_search_paths);
+	if (!sheet->non_graphical) {
+		/* This works from load only because the conf state is already set up for
+		   the new sheet, even tho librnd's current sheet is not yet set */
+		csch_lib_add_all(sheet, csch_lib_get_master("symbol", 1), &conf_core.rc.library_search_paths);
+	}
 }
 
 static csch_sheet_t *sch_rnd_sheet_new_(csch_project_t *prj, csch_sheet_t *dst_sheet, int emit_ev)
@@ -132,9 +136,9 @@ static csch_sheet_t *sch_rnd_sheet_new_(csch_project_t *prj, csch_sheet_t *dst_s
 
 	rnd_hid_menu_merge_inhibit_inc();
 	if (dst_sheet == NULL)
-		rnd_conf_list_foreach_path_first(NULL, dsch, &conf_core.rc.default_sheet_file, csch_project_load_sheet(prj, __path__, NULL, &sheet, 1));
+		rnd_conf_list_foreach_path_first(NULL, dsch, &conf_core.rc.default_sheet_file, csch_project_load_sheet(prj, __path__, NULL, &sheet, 1, NULL));
 	else
-		rnd_conf_list_foreach_path_first(NULL, dsch, &conf_core.rc.default_sheet_file, ((sheet = csch_load_sheet_io(NULL, dst_sheet, __path__, __path__, NULL, 0)) == NULL));
+		rnd_conf_list_foreach_path_first(NULL, dsch, &conf_core.rc.default_sheet_file, ((sheet = csch_load_sheet_io(NULL, dst_sheet, __path__, __path__, NULL, 0, NULL)) == NULL));
 	rnd_hid_menu_merge_inhibit_dec();
 
 	if (dsch != 0) { /* no default sheet file found, use embedded version */
@@ -148,14 +152,14 @@ static csch_sheet_t *sch_rnd_sheet_new_(csch_project_t *prj, csch_sheet_t *dst_s
 			fwrite(default_sheet_internal, strlen(default_sheet_internal), 1, f);
 			fclose(f);
 			if (dst_sheet != NULL) {
-				sheet = csch_load_sheet_io(NULL, dst_sheet, efn, efn, NULL, 0);
+				sheet = csch_load_sheet_io(NULL, dst_sheet, efn, efn, NULL, 0, NULL);
 				if (sheet != NULL)
 					dsch = 0;
 				else
 					dsch = 1;
 			}
 			else
-				dsch = csch_project_load_sheet(prj, efn, NULL, &sheet, 0);
+				dsch = csch_project_load_sheet(prj, efn, NULL, &sheet, rnd_conf.rc.quiet, NULL);
 
 			if (dsch == 0)
 				rnd_message(RND_MSG_WARNING, "Couldn't find default sheet - using the embedded fallback\n");
